@@ -8,26 +8,12 @@
 
 #include "skeleton/admin.h"
 
+#include "sign.h"
+
 #include <list>
 #include <string>
 #include <set>
 
-#define ARTICLE_SIGN "_ARTICLE_"
-#define BOARD_SIGN "_BOARD_"
-#define RES_SIGN     "_RES_"
-#define NAME_SIGN    "_NAME_"
-#define ID_SIGN      "_ID_"
-#define BOOKMK_SIGN  "_BM_"
-#define POST_SIGN  "_POST_"
-#define URL_SIGN     "_URL_"
-#define REFER_SIGN   "_REF_"
-#define KEYWORD_SIGN "_KW_"
-#define POSTLOG_SIGN "_POST_"
-#define ORMODE_SIGN      "_OR_"
-#define CENTER_SIGN  "_CENTER_"
-#define TIME_SIGN    "_TIME_"
-#define TITLE_SIGN   "_TITLE_"
-
 namespace ARTICLE
 {
     class ArticleToolBar;
@@ -72,6 +58,7 @@ namespace ARTICLE
 
         bool clock_in_smooth_scroll( int timer_number );
 
+        void hide_popup();
         void delete_popup();
         void delete_all_popups();
 
