@@ -13,6 +13,7 @@
 #include "dbtree/articlebase.h"
 
 #include "jdlib/miscutil.h"
+#include "jdlib/misctime.h"
 
 #include "config/globalconf.h"
 
@@ -20,6 +21,8 @@
 
 #include "control/controlid.h"
 
+#include "history/historymanager.h"
+
 #include "command.h"
 #include "global.h"
 #include "httpcode.h"
@@ -41,7 +44,7 @@ enum
 // メインビュー
 
 ArticleViewMain::ArticleViewMain( const std::string& url )
-    :  ArticleViewBase( url ), m_gotonum_reserve( 0 ), m_gotonum_seen( 0 ), m_playsound( false )
+    :  ArticleViewBase( url ), m_gotonum_reserve_to( 0 ), m_gotonum_reserve_from( 0 ), m_gotonum_seen( 0 ), m_playsound( false ), m_reload_reserve( false )
 {
 #ifdef _DEBUG
     std::cout << "ArticleViewMain::ArticleViewMain " << get_url() << " url_article = " << url_article() << std::endl;
@@ -77,7 +80,11 @@ ArticleViewMain::~ArticleViewMain()
     if( seen >= 1 ) get_article()->set_number_seen( seen );
 
     // 閉じたタブ履歴更新
-    CORE::core_set_command( "set_history_close", url_article() );
+    HISTORY::append_history( URL_HISTCLOSEVIEW,
+                             DBTREE::url_dat( get_url() ),
+                             DBTREE::article_subject( get_url() ), TYPE_THREAD );
+
+    CORE::core_set_command( "close_message" ,url_article() );
 
     if( get_live() ) live_stop();
 }
@@ -90,6 +97,17 @@ void ArticleViewMain::clock_in()
 
     // 実況モードでリロード
     if( get_live() && ! is_loading() && inc_autoreload_counter() ) exec_reload();
+
+    // 更新チェック中にshow_view()が呼び出された場合は
+    // チェックが終わってから改めてロードする
+    if( m_reload_reserve ){
+
+        if( ! get_article()->is_checking_update() ){
+
+            m_reload_reserve = false;
+            show_view();
+        }
+    }
 }
 
 
@@ -98,16 +116,18 @@ void ArticleViewMain::clock_in()
 //
 // ローディング中ならジャンプ予約をしてロード後に update_finish() の中で改めて goto_num() を呼び出す
 //
-void ArticleViewMain::goto_num( int num )
+void ArticleViewMain::goto_num( const int num_to, const int num_from )
 {
 #ifdef _DEBUG
-    std::cout << "ArticleViewMain::goto_num num = " << num << " seen = " << m_gotonum_seen << " res = " << m_gotonum_reserve << std::endl;
+    std::cout << "ArticleViewMain::goto_num num = " << num_to << " num_from " << num_from
+              << " gotonum_seen = " << m_gotonum_seen << " gotonum_reserve = " << m_gotonum_reserve_to << std::endl;
 #endif
 
-    m_gotonum_seen = 0; // m_gotonum_reserve を優先させる
-    m_gotonum_reserve = num;
+    m_gotonum_seen = 0; // m_gotonum_reserve_to を優先させる
+    m_gotonum_reserve_to = num_to;
+    m_gotonum_reserve_from = num_from;
 
-    if( get_article()->get_number_load() < num  && is_loading() ){
+    if( get_article()->get_number_load() < num_to  && is_loading() ){
 #ifdef _DEBUG
         std::cout << "reserve\n";
 #endif
@@ -118,7 +138,7 @@ void ArticleViewMain::goto_num( int num )
     std::cout << "jump\n";
 #endif
 
-    ArticleViewBase::goto_num( num );
+    ArticleViewBase::goto_num( num_to, num_from );
 }
 
 
@@ -183,13 +203,7 @@ void ArticleViewMain::exec_reload()
         return;
     }
 
-    // オートリロードのカウンタを0にする
-    View::reset_autoreload_counter();
-
     show_view();
-
-    // スレ履歴更新
-    CORE::core_set_command( "set_history_article", url_article() );
 }
 
 
@@ -199,10 +213,24 @@ void ArticleViewMain::exec_reload()
 //
 void ArticleViewMain::show_view()
 {
-    m_gotonum_reserve = 0;
+    // 更新チェック中の場合はチェックが終わってからclock_in()でロードする
+    if( get_article()->is_checking_update() ){
+        m_reload_reserve = true;
+        return;
+    }
+
+    if( is_loading() ) return;
+
+    m_gotonum_reserve_to = 0;
+    m_gotonum_reserve_from = 0;
     m_gotonum_seen = 0;
+    m_set_history = false;
     m_show_instdialog = false;
     m_playsound = false;
+    m_show_closedialog = false;
+
+    // オートリロードのカウンタを0にする
+    reset_autoreload_counter();
 
 #ifdef _DEBUG
     std::cout << "ArticleViewMain::show_view\n";
@@ -214,11 +242,14 @@ void ArticleViewMain::show_view()
         return;
     }
 
-    // もしarticleクラスがまだキャッシュにあるdatを解析していないときに
-    // drawarea()->append_res()を呼ぶと update_finish() がコールバック
-    // されて2回再描画することになるので、 show_view() の中で update_finish()を
-    // 呼ばないようにする。動作をまとめると次のようになる。
+    // 負荷を減らすため update_view() や update_finish() が呼び出されるまで描画不可にしておく
+    drawarea()->set_enable_draw( false );
 
+    // articleクラスがまだキャッシュにあるdatを解析していないときに
+    // drawarea()->append_res()を呼ぶと、 nodetree が作られて update_finish() が
+    // コールバックされるので、 キャッシュをまだ読み込んでない時は show_view() の中で
+    // update_finish()を呼ばないようにする。動作をまとめると次のようになる。
+    //
     // オフライン　かつ
     //   キャッシュを読み込んでいない場合  -> articleでnodetreeが作られた時に update_finish がコールバックされる
     //   キャッシュを読み込んでいる場合    -> show_viewから直接  update_finish を呼ぶ
@@ -229,11 +260,11 @@ void ArticleViewMain::show_view()
     //   キャッシュを読み込んでいる場合    -> show_viewから直接  update_finish を呼ぶ
     //  　　　　　　　　　　　　　　　　　　　　ロード終了時にもupdate_finish がコールバックされる
 
-    bool call_update_finish = get_article()->is_cache_read();
+    const bool call_update_finish = get_article()->is_cache_read();
 
     // キャッシュに含まれているレスを表示
-    int from_num = drawarea()->max_number() + 1;
-    int to_num = get_article()->get_number_load();
+    const int from_num = drawarea()->max_number() + 1;
+    const int to_num = get_article()->get_number_load();
     if( from_num <= to_num ){
 
         drawarea()->append_res( from_num, to_num );
@@ -262,6 +293,8 @@ void ArticleViewMain::show_view()
         const bool live = get_live();
         set_live( false );
 
+        if( ! SESSION::is_online() ) m_set_history = true;
+
         update_finish();
 
         CONFIG::set_jump_after_reload( jump_bottom );
@@ -275,6 +308,7 @@ void ArticleViewMain::show_view()
         if( ! SESSION::is_online() ) update_finish();
     }
 
+    m_set_history = true;
 
     // オフラインならダウンロードを開始しない
     if( ! SESSION::is_online() ) return;
@@ -284,6 +318,8 @@ void ArticleViewMain::show_view()
         m_show_instdialog = true;
     }
 
+    m_show_closedialog = true;
+
     clear_highlight();
     if( ! get_live() && SESSION::is_online() ) m_playsound = true;
 
@@ -350,7 +386,13 @@ void ArticleViewMain::update_view()
 
     if( num_from > num_to ) return;
 
+#ifdef _DEBUG
+    std::cout << "append " << num_from << " to " << num_to << std::endl;
+#endif
+
     drawarea()->append_res( num_from, num_to );
+
+    drawarea()->set_enable_draw( true );
     drawarea()->redraw_view();
 }
 
@@ -377,7 +419,6 @@ void ArticleViewMain::update_finish()
     // タブのアイコン状態を更新
     ARTICLE::get_admin()->set_command( "toggle_icon", get_url() );
 
-
 #ifdef _DEBUG
     const int code = DBTREE::article_code( url_article() );
     std::cout << "ArticleViewMain::update_finish " << str_label << " code = " << code << std::endl;;
@@ -396,21 +437,25 @@ void ArticleViewMain::update_finish()
     set_title( DBTREE::article_subject( url_article() ) );
     ARTICLE::get_admin()->set_command( "set_title", get_url(), get_title() );
 
-    // 全体再描画
-    drawarea()->redraw_view();
+    drawarea()->set_enable_draw( true );
+
+    // ロード中に goto_num() が明示的に呼び出された場合はgoto_num()を呼びつづける
+    if( m_gotonum_reserve_to ){
+#ifdef _DEBUG
+        std::cout << "reserve\n";
+#endif
+        goto_num( m_gotonum_reserve_to, m_gotonum_reserve_from );
+    }
 
     // 前回見ていた所にジャンプ
-    if( m_gotonum_seen && number_load >= m_gotonum_seen ){
+    else if( m_gotonum_seen && number_load >= m_gotonum_seen ){
 #ifdef _DEBUG
         std::cout << "goto_seen\n";
 #endif
-        ArticleViewBase::goto_num( m_gotonum_seen );
+        ArticleViewBase::goto_num( m_gotonum_seen, 0 );
         m_gotonum_seen = 0;
     }
 
-    // ロード中に goto_num() が明示的に呼び出された場合はgoto_num()を呼びつづける
-    if( m_gotonum_reserve ) goto_num( m_gotonum_reserve );
-
     // ロード後に末尾ジャンプ
     else if( CONFIG::get_jump_after_reload() && number_new ){
 #ifdef _DEBUG
@@ -427,6 +472,14 @@ void ArticleViewMain::update_finish()
         goto_new();
     }
 
+    // 全体再描画
+    else{
+#ifdef _DEBUG
+        std::cout << "redraw\n";
+#endif
+        drawarea()->redraw_view();
+    }
+
     // 実況モードで新着がない場合はリロード間隔を空ける
     if( get_live() ){
 
@@ -458,7 +511,20 @@ void ArticleViewMain::update_finish()
         drawarea()->update_live_speed( get_autoreload_sec() );
     }
 
+    // 履歴に登録
+    if( m_set_history ) HISTORY::append_history( URL_HISTTHREADVIEW,
+                                                 DBTREE::url_dat( get_url() ),
+                                                 DBTREE::article_subject( get_url() ), TYPE_THREAD );
+
     if( m_show_instdialog ) show_instruct_diag();
+
+    if( m_show_closedialog && !number_load && is_old() ){
+
+        SKELETON::MsgDiag mdiag( get_parent_win(), "DAT落ちしたためスレッドを取得できませんでした。\n\nタブを閉じますか？",
+                                 false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+        mdiag.set_default_response( Gtk::RESPONSE_YES );
+        if( mdiag.run() == Gtk::RESPONSE_YES ) close_view();
+    }
 }
 
 
@@ -479,7 +545,9 @@ void ArticleViewMain::create_status_message()
            << " [ 全 " << number_load
            << " / 新着 " << number_new;
 
-    if( DBTREE::article_write_time( url_article() ) ) ss_tmp << " / 最終書込 " << DBTREE::article_write_date( url_article() );
+    const time_t wtime = DBTREE::article_write_time( url_article() );
+    if( wtime ) ss_tmp << " / 最終書込 "
+                       << ( MISC::timettostr( wtime, MISC::TIME_WEEK ) + " ( " +  MISC::timettostr( wtime, MISC::TIME_PASSED ) +  " )" );
 
     std::string str_stat;
     if( is_old() ) str_stat = "[ DAT落ち 又は 移転しました ] ";
@@ -489,7 +557,7 @@ void ArticleViewMain::create_status_message()
     if( ! DBTREE::article_ext_err( url_article() ).empty() ) str_stat += "[ " + DBTREE::article_ext_err( url_article() ) + " ] ";
 
     ss_tmp << " / 速度 " << DBTREE::article_get_speed( url_article() )
-           << " / " << DBTREE::article_lng_dat( url_article() )/1024 << " k ] "
+           << " / " << DBTREE::article_lng_dat( url_article() )/1024 << " K ] "
            << str_stat;
 
     set_status( ss_tmp.str() );
@@ -501,6 +569,8 @@ void ArticleViewMain::create_status_message()
 //
 void ArticleViewMain::show_instruct_diag()
 {
+    m_show_instdialog = false;
+
     SKELETON::MsgCheckDiag mdiag( get_parent_win(), 
                                   "スレビューからスレ一覧表示に戻る方法として\n\n(1) マウスジェスチャを使う\n(マウス右ボタンを押しながら左または下にドラッグして右ボタンを離す)\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレ一覧アイコンを押す\n\n(5) 表示メニューからスレ一覧を選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。"
                                   , "今後表示しない(_D)"
@@ -509,7 +579,6 @@ void ArticleViewMain::show_instruct_diag()
     mdiag.run();
 
     if( mdiag.get_chkbutton().get_active() ) CONFIG::set_instruct_tglart( false );
-    m_show_instdialog = false;
 }
 
 
