@@ -16,6 +16,8 @@
 #include "cssmanager.h"
 
 #include <gtkmm.h>
+#include <sys/time.h>
+#include <ctime>
 
 namespace ARTICLE
 {
@@ -35,7 +37,13 @@ namespace ARTICLE
 
     typedef sigc::signal< void, std::string, int > SIG_ON_URL;
     typedef sigc::signal< void > SIG_LEAVE_URL;
-    
+
+    struct URLINFO
+    {
+        std::string url;
+        int res_number;
+    };
+
     // 範囲選択用
     struct SELECTION
     {
@@ -44,8 +52,16 @@ namespace ARTICLE
         CARET_POSITION caret_to;
         std::string str;      // 現在の選択文字列
         std::string str_pre;  // 一つ前の選択文字列
+        std::vector< URLINFO > imgurls;// 選択範囲に含まれる画像URL
     };
 
+    // 描画情報
+    struct DRAWINFO
+    {
+        bool draw;
+        int y;
+        int height;
+    };
 
     ///////////////////////////////////
 
@@ -88,6 +104,14 @@ namespace ARTICLE
         Glib::RefPtr< Gdk::Pixmap > m_backscreen;
         Glib::RefPtr< Pango::Layout > m_pango_layout;
         Glib::RefPtr< Pango::Context > m_context;
+        RECTANGLE m_rect_backscreen; // バックスクリーンが描画されている範囲
+        bool m_enable_draw;
+        DRAWINFO m_drawinfo;
+
+        // 高速スクロール描画実行
+        // DrawingAreaの領域が全て表示されているときは Gdk::Window::scroll() を使ってスクロール
+        // 一部が隠れている時はバックスクリーン内でスクロール処理してバックスクリーン全体をウィンドウにコピーする
+        bool m_scroll_window; 
 
         // キャレット情報
         CARET_POSITION m_caret_pos;           // 現在のキャレットの位置(クリックやドラッグすると移動)
@@ -99,8 +123,10 @@ namespace ARTICLE
         int m_colorid_back;     // デフォルトの背景色
         std::vector< Gdk::Color > m_color;
 
-        // 枠を描くか
-        bool m_draw_frame;
+        // 枠
+        bool m_draw_frame;  // 枠を描画する
+        Glib::RefPtr< Gdk::Pixmap > m_back_frame; // 枠の背景
+        bool m_ready_back_frame;
 
         // 範囲選択
         SELECTION m_selection;
@@ -130,10 +156,19 @@ namespace ARTICLE
         bool m_goto_bottom_reserve; // 初期化時のジャンプ予約(底)
         int m_pre_pos_y; // ひとつ前のスクロールバーの位置。スクロールした時の差分量計算に使用する
         std::vector< int > m_jump_history;  // ジャンプ履歴
+        bool m_cancel_change_adjust; // adjust の値変更イベントをキャンセル
+        Glib::RefPtr< Gdk::Pixmap > m_back_marker; // オートスクロールマーカの背景
+        RECTANGLE m_clip_marker;
+        bool m_ready_back_marker;
+        time_t m_wait_scroll;  // 処理落ちした時にスクロールにウエイトを入れる
+        struct timeval m_scroll_time;  // ウエイト時に最後にスクロールした時刻
 
         // 状態
         int m_x_pointer, m_y_pointer;  // 現在のマウスポインタの位置
         bool m_key_press; // キーを押している
+        bool m_key_locked; // 同じキーを押したままにしている
+        guint m_keyval;
+        bool m_clicked;
         bool m_drugging;  // ドラッグ中
         bool m_r_drugging; // 右ドラッグ中
         std::string m_link_current; // 現在マウスポインタの下にあるリンクの文字列
@@ -179,6 +214,8 @@ namespace ARTICLE
         void focus_view();
         void focus_out();
 
+        void set_enable_draw( const bool enable ){ m_enable_draw = enable; }
+
         // フォントID( fontid.h にある ID を指定)
         const int get_fontid() const { return m_fontid; }
         void set_fontid( int id ){ m_fontid = id; }
@@ -204,6 +241,9 @@ namespace ARTICLE
         // 範囲選択を終了したレス番号
         const int get_selection_resnum_to();
 
+        // 範囲選択に含まれる画像URLのリスト
+        const std::vector< URLINFO >& get_selection_imgurls() const { return m_selection.imgurls; }
+
         const int get_seen_current() const { return m_seen_current; } // 現在見ているレスの番号
         const int get_goto_num_reserve() const { return m_goto_num_reserve; } // 初期化時のジャンプ予約(レス番号)
 
@@ -228,8 +268,10 @@ namespace ARTICLE
         // 全画面消去
         void clear_screen();
 
-        // バックスクリーンを描き直して再描画予約(queue_draw())する。再レイアウトはしない
-        void redraw_view();  
+        // 再描画
+        // 再レイアウトはしないが configureの予約がある場合は再レイアウトしてから再描画する
+        void redraw_view_force();
+        void redraw_view();
 
         // スクロール方向指定
         const bool set_scroll( const int control );
@@ -238,7 +280,7 @@ namespace ARTICLE
         void wheelscroll( GdkEventScroll* event );
 
         // ジャンプ
-        void set_jump_history(); // ジャンプ履歴に現在のスレを登録
+        void set_jump_history( const int num ); // ジャンプ履歴にスレ番号を登録
         void goto_num( int num );
         void goto_next_res();
         void goto_pre_res();
@@ -259,8 +301,9 @@ namespace ARTICLE
 
       protected:
 
-        // バックスクリーン描画
-        bool draw_backscreen( const bool redraw_all = false );
+        // リアライズしたか
+        // Gtk::Widget::is_realized() はうまく動作しない
+        const bool is_drawarea_realized(){ return m_window; }
 
         // 文字色のID( colorid.h にある ID を指定)
         const int get_colorid_text() const{ return m_colorid_text; }
@@ -275,18 +318,17 @@ namespace ARTICLE
 
         // レイアウト処理
         virtual bool exec_layout();
-        bool exec_layout_impl( const bool init_popupwin, const int offset_y, const int right_mrg );
+        const bool exec_layout_impl( const bool is_popup, const int offset_y );
 
-        // バックスクリーンをDrawAreaにコピー
-        bool draw_drawarea( int x = 0, int y = 0, int width = 0, int height = 0 );
-
-        // DrawAreaに枠を描画
+        // DrawAreaに枠を描画する
         void set_draw_frame( bool draw_frame ){ m_draw_frame = draw_frame; }
-        void draw_frame();
 
         // リサイズした
         virtual bool slot_configure_event( GdkEventConfigure* event );
 
+        Gtk::DrawingArea* get_view(){ return &m_view; }
+        Gtk::VScrollbar* get_vscrbar(){ return m_vscrbar; }
+
       private:
 
         // 初期化関係
@@ -307,7 +349,12 @@ namespace ARTICLE
         bool set_init_wide_mode( const char* str, const int pos_start, const int pos_to );
         bool is_wrapped( const int x, const int border, const char* str );
 
-        // 描画
+        // スクリーン描画
+        // y から height の高さ分だけ描画する
+        // height == 0 ならスクロールした分だけ描画( y は無視 )
+        const bool draw_screen( const int y, const int height );
+        void exec_draw_screen( const int y_redraw, const int height_redraw );
+
         bool draw_one_node( LAYOUT* layout, const int width_win, const int pos_y, const int upper, const int lower );
         void draw_div( LAYOUT* layout_div, const int pos_y, const int upper, const int lower );
         void draw_one_text_node( LAYOUT* layout, const int width_win, const int pos_y );
@@ -322,7 +369,7 @@ namespace ARTICLE
         int set_num_id( LAYOUT* layout );
 
         // スクロール関係
-        void exec_scroll( bool redraw_all ); // スクロールやジャンプを実行して再描画
+        void exec_scroll(); // スクロールやジャンプを実行して再描画
         int get_vscr_val();
         int get_vscr_maxval();
 
@@ -334,9 +381,10 @@ namespace ARTICLE
         const bool set_carets_dclick( CARET_POSITION& caret_left, CARET_POSITION& caret_right,  const int x, const int y, const bool triple );
 
         // 範囲選択関係
-        bool set_selection( CARET_POSITION& caret_left, CARET_POSITION& caret_right, const bool redraw = true );
-        bool set_selection( CARET_POSITION& caret_pos, const bool redraw = true );
-        bool set_selection_str();
+        const bool set_selection( const CARET_POSITION& caret_left, const CARET_POSITION& caret_right );
+        const bool set_selection( const CARET_POSITION& caret_pos );
+        const bool set_selection( const CARET_POSITION& caret_pos, RECTANGLE* rect );
+        const bool set_selection_str();
         const bool is_caret_on_selection( const CARET_POSITION& caret_pos );
         std::string get_selection_as_url( const CARET_POSITION& caret_pos );
 
@@ -349,11 +397,18 @@ namespace ARTICLE
         // カーソルの形状の変更
         void change_cursor( const Gdk::CursorType type );
 
+        // スクロールマーカの描画
+        void draw_marker();
+
+        // 枠の描画
+        void draw_frame();
+
         // スロット
         void slot_change_adjust();
         bool slot_expose_event( GdkEventExpose* event );
         bool slot_scroll_event( GdkEventScroll* event );
         bool slot_leave_notify_event( GdkEventCrossing* event );
+        bool slot_visibility_notify_event( GdkEventVisibility* event );
         void slot_realize();
 
         bool slot_button_press_event( GdkEventButton* event );
