@@ -19,16 +19,17 @@
 
 using namespace ARTICLE;
 
-Preferences::Preferences( Gtk::Window* parent, const std::string& url )
+Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std::string command )
     : SKELETON::PrefDiag( parent, url )
     ,m_label_name( false, "スレタイトル : ", DBTREE::article_subject( get_url() ) )
     ,m_label_url( false, "スレのURL : ", DBTREE:: url_readcgi( get_url(),0,0 ) )
     ,m_label_url_dat( false, "DATファイルのURL : ", DBTREE:: url_dat( get_url() ) )
     ,m_label_cache( false, "ローカルキャッシュパス : ", std::string() )
-    ,m_label_size( false, "サイズ( byte / kb ) : ", std::string() )
+    ,m_label_size( false, "サイズ( byte / Kbyte ) : ", std::string() )
     ,m_check_transpabone( "透明あぼ〜ん" )
     ,m_check_chainabone( "連鎖あぼ〜ん" )
-    ,m_label_since( false, "スレ立て日時 : ", DBTREE::article_since_date( get_url() ) )
+    ,m_check_ageabone( "sage以外をあぼ〜ん" )
+    ,m_label_since( false, "スレ立て日時 : ", std::string() )
     ,m_label_modified( false, "最終更新日時 : ", std::string() )
     ,m_button_clearmodified( "日時クリア" )
     ,m_label_write( false, "最終書き込み日時 : ", std::string() )
@@ -45,11 +46,22 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
         m_label_size.set_text( MISC::itostr( size )  + " / " + MISC::itostr( size/1024 ) );
 
         if( DBTREE::article_date_modified( get_url() ).empty() ) m_label_modified.set_text( "未取得" );
-        else m_label_modified.set_text( MISC::timettostr( DBTREE::article_time_modified( get_url() ) ) );
+        else m_label_modified.set_text(
+            MISC::timettostr( DBTREE::article_time_modified( get_url() ), MISC::TIME_WEEK )
+            + " ( " + MISC::timettostr( DBTREE::article_time_modified( get_url() ), MISC::TIME_PASSED ) + " )"
+            );
 
-        if( DBTREE::article_write_time( get_url() ) ) m_label_write.set_text( DBTREE::article_write_date( get_url() ) );
+        if( DBTREE::article_write_time( get_url() ) ) m_label_write.set_text(
+            MISC::timettostr( DBTREE::article_write_time( get_url() ), MISC::TIME_WEEK )
+            + " ( " + MISC::timettostr( DBTREE::article_write_time( get_url() ), MISC::TIME_PASSED ) + " )"
+            );
     }
 
+    m_label_since.set_text(
+            MISC::timettostr( DBTREE::article_since_time( get_url() ), MISC::TIME_WEEK )
+            + " ( " + MISC::timettostr( DBTREE::article_since_time( get_url() ), MISC::TIME_PASSED ) + " )"
+        );
+
     m_button_clearmodified.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_clear_modified ) );
     m_hbox_modified.pack_start( m_label_modified );
     m_hbox_modified.pack_start( m_button_clearmodified, Gtk::PACK_SHRINK );    
@@ -86,11 +98,15 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     // 連鎖あぼーん
     m_check_chainabone.set_active( DBTREE::get_abone_chain( get_url() ) );
 
+    // ageあぼーん
+    m_check_ageabone.set_active( DBTREE::get_abone_age( get_url() ) );
+
     if( CONFIG::get_abone_transparent() ) m_check_transpabone.set_sensitive( false );
     if( CONFIG::get_abone_chain() ) m_check_chainabone.set_sensitive( false );
 
     m_vbox_abone.pack_start( m_check_transpabone, Gtk::PACK_SHRINK );
     m_vbox_abone.pack_start( m_check_chainabone, Gtk::PACK_SHRINK );
+    m_vbox_abone.pack_start( m_check_ageabone, Gtk::PACK_SHRINK );
 
     if( CONFIG::get_abone_transparent() || CONFIG::get_abone_chain() ){
         m_label_abone.set_text( "チェック出来ない場合は設定メニューから「デフォルトで透明/連鎖あぼ〜ん」を解除して下さい" );
@@ -175,12 +191,15 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_notebook_abone.append_page( m_edit_regex, "NG 正規表現" );
 
     m_notebook.append_page( m_vbox_info, "一般" );
-    m_notebook.append_page( m_notebook_abone, "あぼーん設定" );
+    const int page_abone = 1;
+    m_notebook.append_page( m_notebook_abone, "あぼ〜ん設定" );
 
     get_vbox()->pack_start( m_notebook );
     set_title( "「" + DBTREE::article_subject( get_url() ) + "」のプロパティ" );
     resize( 600, 400 );
     show_all_children();
+
+    if( command == "show_abone" ) m_notebook.set_current_page( page_abone );
 }
 
 Preferences::~Preferences()
@@ -210,13 +229,13 @@ void Preferences::slot_ok_clicked()
         if( number >= 1 ){
             int number_end = number;
             size_t pos = num_str.find( "-" );
-            if( pos != std::string::npos ) number_end = MAX( number, atoi( num_str.substr( pos + 1 ).c_str() ) );
+            if( pos != std::string::npos ) number_end = MIN( (int)vec_abone_res.size(), MAX( number, atoi( num_str.substr( pos + 1 ).c_str() ) ) );
             for( int i = number; i <= number_end; ++i ) vec_abone_res[ i ] = true;
         }
     }
 
     DBTREE::reset_abone( get_url(), list_id, list_name, list_word, list_regex, vec_abone_res
-                         , m_check_transpabone.get_active(), m_check_chainabone.get_active() );
+                         , m_check_transpabone.get_active(), m_check_chainabone.get_active(), m_check_ageabone.get_active() );
 
     // viewの再レイアウト
     CORE::core_set_command( "relayout_article", get_url() );
@@ -228,7 +247,11 @@ void Preferences::slot_clear_modified()
     DBTREE::article_set_date_modified( get_url(), "" );
 
     if( DBTREE::article_date_modified( get_url() ).empty() ) m_label_modified.set_text( "未取得" );
-    else m_label_modified.set_text( MISC::timettostr( DBTREE::article_time_modified( get_url() ) ) );
+    else m_label_modified.set_text(
+        MISC::timettostr( DBTREE::article_time_modified( get_url() ), MISC::TIME_WEEK )
+        + " ( " + MISC::timettostr( DBTREE::article_time_modified( get_url() ), MISC::TIME_PASSED ) + " )"
+        );
+
 }
 
 
