@@ -36,22 +36,34 @@ namespace ARTICLE
         // 連鎖あぼーん
         Gtk::CheckButton m_check_chainabone;
 
+        // ageあぼーん
+        Gtk::CheckButton m_check_ageabone;
+
         SKELETON::LabelEntry m_label_since;
 
+        // 最終更新日時
         Gtk::HBox m_hbox_modified;
         SKELETON::LabelEntry m_label_modified;
         Gtk::Button m_button_clearmodified;
 
+        // 書き込み日時
+        Gtk::HBox m_hbox_write;
         SKELETON::LabelEntry m_label_write;
+        Gtk::Button m_bt_clear_post_history;
+
+        // 名前とメール
+        SKELETON::LabelEntry m_label_write_name;
+        SKELETON::LabelEntry m_label_write_mail;
 
       public:
 
-        Preferences( Gtk::Window* parent, const std::string& url );
+        Preferences( Gtk::Window* parent, const std::string& url, const std::string command );
         virtual ~Preferences();
 
       private:
         virtual void slot_ok_clicked();
         void slot_clear_modified();
+        void slot_clear_post_history();
     };
 }
 
