@@ -12,6 +12,8 @@
 
 #include "xml/document.h"
 
+#include "jdlib/hash_set.h"
+
 #include "columns.h"
 
 #include <gtkmm.h>
@@ -40,8 +42,11 @@ namespace BBSLIST
 
         Gtk::ScrolledWindow m_scrwin;
 
+        // クリック状態
+        bool m_clicked;
+
         // ダブルクリック状態
-        bool m_dblclick;
+        bool m_dblclicked;
 
         // ポップアップメニュー用
         Gtk::TreeModel::Path m_path_selected;
@@ -58,8 +63,19 @@ namespace BBSLIST
         bool m_cancel_expand; // signal_row_expanded() をキャンセルする
         bool m_expanding; // 行を開いている最中にtrueにしてsignal_row_collapsed()をキャンセルする
 
+        // ツリーに含まれているスレのURLを入れる hash_set
+        // toggle_articleicon() で使用する
+        JDLIB::hash_set_thread m_set_thread;
+
+        // ツリーに含まれている板のURLを入れる set
+        // toggle_boardicon() で使用する
+        std::set< std::string > m_set_board;
+
         EditListWin* m_editlistwin;
 
+        // スレを追加したときにそのスレにしおりを付ける
+        bool m_set_bookmark;
+
       protected:
 
         // Viewが所属するAdminクラス
@@ -70,6 +86,9 @@ namespace BBSLIST
 
         void set_search_invert( const bool invert ){ m_search_invert = invert; }
 
+        // スレを追加したときにそのスレにしおりを付ける
+        void set_bookmark( const bool set ){ m_set_bookmark = set; }
+
         // DOM共有オブジェクト
         XML::Document m_document;
 
@@ -104,21 +123,35 @@ namespace BBSLIST
         void replace_thread( const std::string& url, const std::string& url_new );
 
         // path からその行のタイプを取得
-        int path2type( const Gtk::TreePath& path );
+        const int path2type( const Gtk::TreePath& path );
 
         // row からタイプを取得
-        int row2type( const Gtk::TreeModel::Row& row );
+        const int row2type( const Gtk::TreeModel::Row& row );
+
+        // row -> name 変換
+        const Glib::ustring row2name( const Gtk::TreeModel::Row& row );
+
+        // row -> url 変換
+        // 板の場合は boardbase
+        // スレの場合は dat 型のアドレスを返す
+        const Glib::ustring row2url( const Gtk::TreeModel::Row& row );
+
+        // row -> dirid 変換
+        const size_t row2dirid( const Gtk::TreeModel::Row& row );
 
         // path からその行の名前を取得
-        Glib::ustring path2name( const Gtk::TreePath& path );
+        const Glib::ustring path2name( const Gtk::TreePath& path );
 
         // path からその行のURLを取得
-        Glib::ustring path2rawurl( const Gtk::TreePath& path );
-        Glib::ustring path2url( const Gtk::TreePath& path ); // 移転をチェックするバージョン
+        const Glib::ustring path2rawurl( const Gtk::TreePath& path );
+        const Glib::ustring path2url( const Gtk::TreePath& path ); // 移転をチェックするバージョン
 
-        // アイテム削除
+        // url で指定した項目を削除
         void remove_item( const std::string& url );
 
+        // 全項目を削除
+        void remove_allitems();
+
         // ツリーの編集ウィンドウを開く
         void edit_tree();
 
@@ -153,12 +186,21 @@ namespace BBSLIST
         virtual void shutdown();
 
         virtual void clock_in();
-        virtual void relayout();
+
+        // キーを押した
+        virtual const bool slot_key_press( GdkEventKey* event );
+
+        virtual void stop();
+        virtual void redraw_view();
+        virtual void relayout();  // 色やフォントなどの変更
         virtual void focus_view();
         virtual void focus_out();
         virtual void close_view();
         virtual void delete_view();
+
+        // ツリー内の全ての項目をURLを新しいアドレスに変更 ( id は未使用 )
         virtual void update_item( const std::string& url, const std::string& id );
+
         virtual const bool operate_view( const int control );
         virtual void goto_top();
         virtual void goto_bottom();
@@ -173,6 +215,20 @@ namespace BBSLIST
         // あらかじめ共有バッファに追加するデータをセットしておくこと
         void append_item();
 
+        // 履歴のセット
+        // 先頭にアイテムを追加する。ツリーにアイテムが含まれている場合は移動する
+        // あらかじめ共有バッファに追加するデータをセットしておくこと
+        void append_history();
+
+        // 履歴を DATA_INFO_LIST 型で取得
+        void get_history( CORE::DATA_INFO_LIST& info_list );
+
+        // 指定したidのディレクトリに含まれるスレのアドレスを取得
+        void get_threads( const size_t dirid, std::vector< std::string >& list_url );
+
+        // 指定したidのディレクトリの名前を取得
+        const std::string get_dirname( const int dirid );
+
         // selectdialogで使う
         Gtk::TreePath get_current_path() { return m_treeview.get_current_path(); }
         void copy_treestore( Glib::RefPtr< Gtk::TreeStore >& store );
@@ -190,14 +246,16 @@ namespace BBSLIST
         void page_up();
         void page_down();
         void expand_all_dir( Gtk::TreeModel::Path path );
-        void check_update_dir( Gtk::TreeModel::Path path, const bool open );
-        void check_update_root( const Gtk::TreeModel::Children& children, const bool open );
-        void check_update_root( const bool open );
+
+        // ディレクトリ以下を更新チェック
+        // root : true ならルートから検索する。falseの場合は m_path_selected にパスをセットしておくこと
+        // open : チェック後に更新していたら開く
+        void check_update_dir( const bool root, const bool open );
+
 
         bool slot_button_press( GdkEventButton* event );
         bool slot_button_release( GdkEventButton* event );
         bool slot_motion_notify( GdkEventMotion* event );
-        bool slot_key_press( GdkEventKey* event );
         bool slot_key_release( GdkEventKey* event );
         bool slot_scroll_event( GdkEventScroll* event );
         void slot_dropped_from_other( const CORE::DATA_INFO_LIST& list_info );
@@ -216,7 +274,8 @@ namespace BBSLIST
         void slot_select_all();
         void slot_check_update_dir();
         void slot_check_update_open_dir();
-        void slot_cancel_check_update();
+        void slot_opendir_as_board();
+        void slot_create_vboard();
         void slot_search_cache_board();
         void slot_import_dat();
         void slot_preferences_board();
@@ -239,7 +298,6 @@ namespace BBSLIST
         virtual void switch_rightview();
         void open_selected_rows();
         void checkupdate_selected_rows( const bool open );
-        Glib::ustring row2url( const Gtk::TreeModel::Row& row );
 
         void show_status();
 
