@@ -15,6 +15,7 @@
 
 #include "jdlib/miscutil.h"
 #include "jdlib/jdregex.h"
+#include "jdlib/miscmsg.h"
 
 #include "global.h"
 #include "type.h"
@@ -24,6 +25,8 @@
 #include "command.h"
 #include "dndmanager.h"
 
+
+
 BOARD::BoardAdmin *instance_boardadmin = NULL;
 
 BOARD::BoardAdmin* BOARD::get_admin()
@@ -79,8 +82,8 @@ void BoardAdmin::restore( const bool only_locked )
     const bool online = SESSION::is_online();
     SESSION::set_online( false );
 
-    std::list< std::string >& list_url = SESSION::get_board_URLs();
-    std::list< std::string >::iterator it_url = list_url.begin();
+    const std::list< std::string >& list_url = SESSION::get_board_URLs();
+    std::list< std::string >::const_iterator it_url = list_url.begin();
 
     std::list< bool > list_locked = SESSION::get_board_locked();
     std::list< bool >::iterator it_locked = list_locked.begin();
@@ -100,7 +103,15 @@ void BoardAdmin::restore( const bool only_locked )
         if( page == SESSION::board_page() ) set_page_num = get_tab_nums();
 
         COMMAND_ARGS command_arg = url_to_openarg( *it_url, true, lock );
-        if( ! command_arg.url.empty() ) open_view( command_arg );
+
+        // 板がDBに登録されていない場合は表示しない
+        if( command_arg.url != URL_ALLLOG && command_arg.arg4 != "SIDEBAR"
+            && DBTREE::url_boardbase( command_arg.url ).empty() ){
+            MISC::ERRMSG(  *it_url + " is not registered" );
+            continue;
+        }
+
+        open_view( command_arg );
     }
 
     SESSION::set_online( online );
@@ -124,12 +135,37 @@ COMMAND_ARGS BoardAdmin::url_to_openarg( const std::string& url, const bool tab,
 #endif    
 
     // 次スレ検索
-    if( regex.exec( std::string( "(.*)" ) + NEXT_SIGN + ARTICLE_SIGN + "(.*)" + TIME_SIGN, url )){
+    if( regex.exec( std::string( "(.*)" ) + NEXT_SIGN + ARTICLE_SIGN + "(.*)", url )){
 
         command_arg.url = regex.str( 1 );
 
         command_arg.arg4 = "NEXT";
-        command_arg.arg5 = regex.str( 2 );
+        command_arg.arg5 = regex.str( 2 ); // 前スレのアドレス
+    }
+
+    // 全ログ一覧
+    else if( url == URL_ALLLOG ){
+
+        command_arg.url = URL_ALLLOG;
+
+        command_arg.arg4 = "LOG";
+    }
+
+    // ログ一覧
+    else if( regex.exec( std::string( "(.*)" ) + LOG_SIGN, url )){
+
+        command_arg.url = regex.str( 1 );
+
+        command_arg.arg4 = "LOG";
+    }
+
+    // サイドバー
+    else if( regex.exec( std::string( "(.*)" ) + SIDEBAR_SIGN + "(.*)", url )){
+
+        command_arg.url = regex.str( 1 );
+
+        command_arg.arg4 = "SIDEBAR";
+        command_arg.arg5 = regex.str( 2 ); // ディレクトリID
     }
 
     // スレビュー
@@ -140,10 +176,33 @@ COMMAND_ARGS BoardAdmin::url_to_openarg( const std::string& url, const bool tab,
         command_arg.arg4 = "MAIN";
     }
 
+#ifdef _DEBUG
+    std::cout << "open " << command_arg.arg4 << std::endl;
+#endif    
+
     return command_arg;
 }
 
 
+const std::string BoardAdmin::command_to_url( const COMMAND_ARGS& command )
+{
+    if( command.arg4 == "NEXT" ) return command.url + NEXT_SIGN + ARTICLE_SIGN + command.arg5;
+
+    else if( command.arg4 == "LOG" ){
+
+        if( command.url == URL_ALLLOG ) return URL_ALLLOG;
+        else return command.url + LOG_SIGN;
+    }
+
+    else if( command.arg4 == "SIDEBAR" ){
+        if( command.arg5.empty() ) return command.url;
+        return command.url + SIDEBAR_SIGN + command.arg5;
+    }
+
+    return command.url;
+}
+
+
 void BoardAdmin::switch_admin()
 {
     if( ! has_focus() ) CORE::core_set_command( "switch_board" );
@@ -158,8 +217,6 @@ COMMAND_ARGS BoardAdmin::get_open_list_args( const std::string& url, const COMMA
     COMMAND_ARGS command_arg;
     command_arg.arg4 = "MAIN";
 
-    CORE::core_set_command( "set_history_board", url );
-
     return command_arg;
 }
 
@@ -182,17 +239,52 @@ void BoardAdmin::show_toolbar()
 
 
 //
-// ツールバー表示切り替え
+// ツールバー表示/非表示切り替え
 //
 void BoardAdmin::toggle_toolbar()
 {
     if( ! m_toolbar ) return;
 
-    if( SESSION::get_show_board_toolbar() ){
-        m_toolbar->open_buttonbar();
+#ifdef _DEBUG    
+    std::cout << "BoardAdmin::toggle_toolbar\n";
+#endif
+
+    // 検索関係の wiget の位置を変更
+    m_toolbar->unpack_pack();
+
+    if( SESSION::get_show_board_toolbar() ) m_toolbar->open_buttonbar();
+    else m_toolbar->close_buttonbar();
+
+    m_toolbar->close_searchbar();
+    m_toolbar->show_toolbar();
+}
+
+
+//
+// 検索バー表示
+//
+void BoardAdmin::open_searchbar()
+{
+    if( ! m_toolbar ) return;
+
+    // ツールバー表示時は検索関係の wiget はツールバーに表示されている
+    if( ! SESSION::get_show_board_toolbar() ){
+        m_toolbar->open_searchbar();
         m_toolbar->show_toolbar();
     }
-    else m_toolbar->close_buttonbar();
+
+    m_toolbar->focus_entry_search();
+}
+
+
+//
+// 検索バー非表示
+//
+void BoardAdmin::close_searchbar()
+{
+    if( ! m_toolbar ) return;
+
+    if( ! SESSION::get_show_board_toolbar() ) m_toolbar->close_searchbar();
 }
 
 
@@ -205,13 +297,27 @@ SKELETON::View* BoardAdmin::create_view( const COMMAND_ARGS& command )
     if( command.arg4 == "MAIN" ){
         type = CORE::VIEW_BOARDVIEW;
     }
+
+    // 次スレ検索
     else if( command.arg4 == "NEXT" ){
         type = CORE::VIEW_BOARDNEXT;
-        view_args.arg1 = command.arg5;
+        view_args.arg1 = command.arg5;  // 前スレのアドレス
     }
+
+    // ログ
+    else if( command.arg4 == "LOG" ){
+        type = CORE::VIEW_BOARDLOG;
+    }
+
+    // サイドバー
+    else if( command.arg4 == "SIDEBAR" ){
+        type = CORE::VIEW_BOARDSIDEBAR;
+        view_args.arg1 = command.arg6; // "set_history" の時は板の履歴に登録する
+    }
+
     else return NULL;
 
-    SKELETON::View* view = CORE::ViewFactory( type, command.url, view_args );
+    SKELETON::View* view = CORE::ViewFactory( type, command_to_url( command ), view_args );
     assert( view != NULL );
 
     return view;
@@ -244,7 +350,7 @@ void BoardAdmin::command_local( const COMMAND_ARGS& command )
 
 
 //
-// タブをお気に入りにドロップした時にお気に入りがデータ送信を要求してきた
+// タブをサイドバーにドロップした時にお気に入りがデータ送信を要求してきた
 //
 void BoardAdmin::slot_drag_data_get( Gtk::SelectionData& selection_data, const int page )
 {
@@ -261,7 +367,6 @@ void BoardAdmin::slot_drag_data_get( Gtk::SelectionData& selection_data, const i
     info.type = TYPE_BOARD;
     info.url = DBTREE::url_boardbase( url );
     info.name = DBTREE::board_name( info.url );
-    info.data = std::string();
     info.path = Gtk::TreePath( "0" ).to_string();
 
     if( info.url.empty() ) return;
