@@ -172,116 +172,10 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
     m_treeview.signal_drag_data_get().connect( sigc::mem_fun(*this, &BoardViewBase::slot_drag_data_get ) );
     m_treeview.sig_dropped_uri_list().connect( sigc::mem_fun(*this, &BoardViewBase::slot_dropped_url_list ) );
 
-    // ポップアップメニューの設定
-    // アクショングループを作ってUIマネージャに登録
-    action_group() = Gtk::ActionGroup::create();
-    action_group()->add( Gtk::Action::create( "BookMark", "しおりを設定/解除(_B)" ),
-                         sigc::bind< int >( sigc::mem_fun( *this, &BoardViewBase::slot_bookmark ), BOOKMARK_AUTO ) );
-    action_group()->add( Gtk::Action::create( "SetBookMark", "しおりを設定(_S)" ),  // 未使用
-                         sigc::bind< int >( sigc::mem_fun( *this, &BoardViewBase::slot_bookmark ), BOOKMARK_SET ) );
-    action_group()->add( Gtk::Action::create( "UnsetBookMark", "しおりを解除(_U)" ),    // 未使用
-                         sigc::bind< int >( sigc::mem_fun( *this, &BoardViewBase::slot_bookmark ), BOOKMARK_UNSET ) );
-    action_group()->add( Gtk::Action::create( "OpenTab", "OpenArticleTab" ), sigc::mem_fun( *this, &BoardViewBase::slot_open_tab ) );
-    action_group()->add( Gtk::Action::create( "Favorite_Article", "スレをお気に入りに追加(_F)..." ), sigc::mem_fun( *this, &BoardViewBase::slot_favorite_thread ) );
-    action_group()->add( Gtk::Action::create( "Favorite_Board", "板をお気に入りに追加(_A)" ), sigc::mem_fun( *this, &BoardViewBase::slot_favorite_board ) );
-    action_group()->add( Gtk::Action::create( "GotoTop", "一番上に移動(_T)" ), sigc::mem_fun( *this, &BoardViewBase::goto_top ) );
-    action_group()->add( Gtk::Action::create( "GotoBottom", "一番下に移動(_M)" ), sigc::mem_fun( *this, &BoardViewBase::goto_bottom ) );
-    action_group()->add( Gtk::Action::create( "Delete_Menu", "Delete" ) );
-    action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する(_D)" ), sigc::mem_fun( *this, &BoardViewBase::slot_delete_logs ) );
-    action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く(_O)" ), sigc::mem_fun( *this, &BoardViewBase::open_selected_rows ) );
-    action_group()->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL + std::string( "(_U)" ) ), sigc::mem_fun( *this, &BoardViewBase::slot_copy_url ) );
-    action_group()->add( Gtk::Action::create( "CopyTitleURL", ITEM_NAME_COPY_TITLE_URL + std::string( "(_L)" ) ),
-                         sigc::mem_fun( *this, &BoardViewBase::slot_copy_title_url ) );
-    action_group()->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER + std::string( "(_W)" ) ),
-                         sigc::mem_fun( *this, &BoardViewBase::slot_open_browser ) );
-    action_group()->add( Gtk::Action::create( "AboneThread", "スレをあぼ〜んする(_N)" ), sigc::mem_fun( *this, &BoardViewBase::slot_abone_thread ) );
-    action_group()->add( Gtk::Action::create( "PreferenceArticle", ITEM_NAME_PREF_THREAD + std::string( "(_P)..." ) ),
-                         sigc::mem_fun( *this, &BoardViewBase::slot_preferences_article ) );
-    action_group()->add( Gtk::Action::create( "PreferenceBoard", "板のプロパティ(_O)..." ), sigc::mem_fun( *this, &BoardViewBase::show_preference ) );
-    action_group()->add( Gtk::Action::create( "SaveDat", ITEM_NAME_SAVE_DAT + std::string( "(_S)..." ) ),
-                         sigc::mem_fun( *this, &BoardViewBase::slot_save_dat ) );
-    action_group()->add( Gtk::Action::create( "SearchNextArticle", "次スレ検索"), sigc::mem_fun( *this, &BoardViewBase::slot_search_next ) );
+    // アクション初期化
+    setup_action();
 
-    ui_manager() = Gtk::UIManager::create();    
-    ui_manager()->insert_action_group( action_group() );
-
-    Glib::ustring str_ui = 
-    "<ui>"
-
-    // 通常
-    "<popup name='popup_menu'>"
-    "<menuitem action='BookMark'/>"
-    "<separator/>"
-    "<menuitem action='OpenTab'/>"
-    "<menuitem action='OpenBrowser'/>"
-    "<separator/>"
-    "<menuitem action='CopyURL'/>"
-    "<menuitem action='CopyTitleURL'/>"
-    "<separator/>"
-    "<menuitem action='SaveDat'/>"
-    "<menuitem action='Favorite_Article'/>"
-    "<menuitem action='SearchNextArticle'/>"
-    "<separator/>"
-    "<menuitem action='AboneThread'/>"
-    "<separator/>"
-    "<menu action='Delete_Menu'>"
-    "<menuitem action='Delete'/>"
-    "</menu>"
-    "<separator/>"
-    "<menuitem action='PreferenceArticle'/>"
-    "<menuitem action='PreferenceBoard'/>"
-    "</popup>"
-
-
-    // 通常 + 複数
-    "<popup name='popup_menu_mul'>"
-    "<menuitem action='OpenRows'/>"
-    "<separator/>"
-    "<menuitem action='SetBookMark'/>"
-    "<menuitem action='UnsetBookMark'/>"
-    "<separator/>"
-    "<menuitem action='SaveDat'/>"
-    "<separator/>"
-    "<menuitem action='Favorite_Article'/>"
-    "<separator/>"
-    "<menuitem action='AboneThread'/>"
-    "<separator/>"
-    "<menu action='Delete_Menu'>"
-    "<menuitem action='Delete'/>"
-    "</menu>"
-    "</popup>"
-
-
-    // お気に入りボタン押した時のメニュー
-    "<popup name='popup_menu_favorite'>"
-    "<menuitem action='Favorite_Article'/>"
-    "<menuitem action='Favorite_Board'/>"
-    "</popup>"
-
-    // お気に入りボタン押した時のメニュー( スレのみ )
-    "<popup name='popup_menu_favorite_article'>"
-    "<menuitem action='Favorite_Article'/>"
-    "</popup>"
-
-
-    // 削除ボタン押した時のメニュー
-    "<popup name='popup_menu_delete'>"
-    "<menuitem action='Delete'/>"
-    "</popup>"
-
-
-    "</ui>";
-
-    ui_manager()->add_ui_from_string( str_ui );
-
-    // ポップアップメニューにキーアクセレータを表示
-    Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu" ) );
-    CONTROL::set_menu_motion( popupmenu );
-
-    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_mul" ) );
-    CONTROL::set_menu_motion( popupmenu );
-
-    // マウスジェスチォ可能
+    // マウスジェスチャ可能
     set_enable_mg( true );
 
     // コントロールモード設定
@@ -344,6 +238,234 @@ const std::string BoardViewBase::url_for_copy()
 }
 
 
+//
+// アクション初期化
+//
+void BoardViewBase::setup_action()
+{
+#ifdef _DEBUG    
+    std::cout << "BoardViewBase::setup_action\n";
+#endif
+
+    // アクショングループを作ってUIマネージャに登録
+    action_group() = Gtk::ActionGroup::create();
+    action_group()->add( Gtk::Action::create( "BookMark", ITEM_NAME_BOOKMARK + std::string( "(_B)" ) ),
+                         sigc::bind< int >( sigc::mem_fun( *this, &BoardViewBase::slot_bookmark ), BOOKMARK_AUTO ) );
+    action_group()->add( Gtk::Action::create( "SetBookMark", "しおりを設定(_S)" ),  // 未使用
+                         sigc::bind< int >( sigc::mem_fun( *this, &BoardViewBase::slot_bookmark ), BOOKMARK_SET ) );
+    action_group()->add( Gtk::Action::create( "UnsetBookMark", "しおりを解除(_U)" ),    // 未使用
+                         sigc::bind< int >( sigc::mem_fun( *this, &BoardViewBase::slot_bookmark ), BOOKMARK_UNSET ) );
+    action_group()->add( Gtk::Action::create( "OpenTab", "OpenArticleTab" ), sigc::mem_fun( *this, &BoardViewBase::slot_open_tab ) );
+    action_group()->add( Gtk::Action::create( "Favorite_Article", ITEM_NAME_FAVORITE_ARTICLE + std::string( "(_F)..." ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_favorite_thread ) );
+    action_group()->add( Gtk::Action::create( "Favorite_Board", "板をお気に入りに追加(_A)" ), sigc::mem_fun( *this, &BoardViewBase::slot_favorite_board ) );
+    action_group()->add( Gtk::Action::create( "GotoTop", "一番上に移動(_T)" ), sigc::mem_fun( *this, &BoardViewBase::goto_top ) );
+    action_group()->add( Gtk::Action::create( "GotoBottom", "一番下に移動(_M)" ), sigc::mem_fun( *this, &BoardViewBase::goto_bottom ) );
+    action_group()->add( Gtk::Action::create( "Delete_Menu", "Delete" ) );
+    action_group()->add( Gtk::Action::create( "Delete", "選択した行のログを削除する(_D)" ), sigc::mem_fun( *this, &BoardViewBase::slot_delete_logs ) );
+    action_group()->add( Gtk::Action::create( "OpenRows", "選択した行を開く(_O)" ), sigc::mem_fun( *this, &BoardViewBase::open_selected_rows ) );
+    action_group()->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL + std::string( "(_U)" ) ), sigc::mem_fun( *this, &BoardViewBase::slot_copy_url ) );
+    action_group()->add( Gtk::Action::create( "CopyTitleURL", ITEM_NAME_COPY_TITLE_URL + std::string( "(_L)" ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_copy_title_url ) );
+    action_group()->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER + std::string( "(_W)" ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_open_browser ) );
+    action_group()->add( Gtk::Action::create( "AboneThread", ITEM_NAME_ABONE_ARTICLE + std::string( "(_N)" ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_abone_thread ) );
+    action_group()->add( Gtk::Action::create( "PreferenceArticle", ITEM_NAME_PREF_THREAD + std::string( "(_P)..." ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_preferences_article ) );
+    action_group()->add( Gtk::Action::create( "PreferenceBoard", ITEM_NAME_PREF_BOARD + std::string( "(_O)..." ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::show_preference ) );
+    action_group()->add( Gtk::Action::create( "SaveDat", ITEM_NAME_SAVE_DAT + std::string( "(_S)..." ) ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_save_dat ) );
+    action_group()->add( Gtk::Action::create( "SearchNextArticle", ITEM_NAME_NEXTARTICLE ),
+                         sigc::mem_fun( *this, &BoardViewBase::slot_search_next ) );
+
+    // その他
+    action_group()->add( Gtk::Action::create( "Etc_Menu", ITEM_NAME_ETC + std::string( "(_O)" ) ) );
+
+    ui_manager().clear();
+    ui_manager() = Gtk::UIManager::create();    
+    ui_manager()->insert_action_group( action_group() );
+
+    // 通常 + 複数
+    const std::string menu_mul =
+    "<popup name='popup_menu_mul'>"
+    "<menuitem action='OpenRows'/>"
+    "<separator/>"
+    "<menuitem action='SetBookMark'/>"
+    "<menuitem action='UnsetBookMark'/>"
+    "<separator/>"
+    "<menuitem action='SaveDat'/>"
+    "<separator/>"
+    "<menuitem action='Favorite_Article'/>"
+    "<separator/>"
+    "<menuitem action='AboneThread'/>"
+    "<separator/>"
+    "<menu action='Delete_Menu'>"
+    "<menuitem action='Delete'/>"
+    "</menu>"
+    "</popup>";
+
+    // お気に入りボタン押した時のメニュー
+    const std::string menu_favorite =
+    "<popup name='popup_menu_favorite'>"
+    "<menuitem action='Favorite_Article'/>"
+    "<menuitem action='Favorite_Board'/>"
+    "</popup>";
+
+    // お気に入りボタン押した時のメニュー( スレのみ )
+    const std::string menu_favorite_article =
+    "<popup name='popup_menu_favorite_article'>"
+    "<menuitem action='Favorite_Article'/>"
+    "</popup>";
+
+    // 削除ボタン押した時のメニュー
+    const std::string menu_delete = 
+    "<popup name='popup_menu_delete'>"
+    "<menuitem action='Delete'/>"
+    "</popup>";
+
+    ui_manager()->add_ui_from_string(
+        "<ui>"
+        + menu_mul
+        + menu_favorite
+        + menu_favorite_article
+        + menu_delete
+        + create_context_menu()
+        + "</ui>"
+        );
+
+    // ポップアップメニューにキーアクセレータを表示
+    Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu" ) );
+    CONTROL::set_menu_motion( popupmenu );
+
+    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_mul" ) );
+    CONTROL::set_menu_motion( popupmenu );
+}
+
+
+//
+// 通常の右クリックメニューの作成
+//
+const std::string BoardViewBase::create_context_menu()
+{
+    std::list< int > list_menu;
+
+    list_menu.push_back( ITEM_BOOKMARK );
+    list_menu.push_back( ITEM_OPENARTICLETAB );
+    list_menu.push_back( ITEM_OPEN_BROWSER );
+    list_menu.push_back( ITEM_COPY_URL );
+    list_menu.push_back( ITEM_COPY_TITLE_URL_THREAD );
+    list_menu.push_back( ITEM_SAVE_DAT );
+    list_menu.push_back( ITEM_FAVORITE_ARTICLE );
+    list_menu.push_back( ITEM_NEXTARTICLE );
+    list_menu.push_back( ITEM_ABONE_ARTICLE );
+    list_menu.push_back( ITEM_DELETE );
+    list_menu.push_back( ITEM_PREF_THREAD );
+    list_menu.push_back( ITEM_PREF_BOARD );
+
+    // メニューに含まれていない項目を抜き出して「その他」に含める
+    int num = 0;
+    for(;;){
+
+        const int item = SESSION::get_item_board_menu( num );
+
+        if( item == ITEM_END ) break;
+        list_menu.remove( item );
+
+        ++num;
+    }
+
+    std::string menu;
+    num = 0;
+    for(;;){
+
+        const int item = SESSION::get_item_board_menu( num );
+
+        if( item == ITEM_END ) break;
+        else if( item == ITEM_ETC && list_menu.size() ){
+            menu += std::string( "<menu action='Etc_Menu'>" );
+            std::list< int >::iterator it = list_menu.begin();
+            for( ; it != list_menu.end(); ++it ) menu += get_menu_item( *it );
+            menu += std::string( "</menu>" );
+        }
+        else menu += get_menu_item( item );
+
+        ++num;
+    }
+
+#ifdef _DEBUG
+    std::cout << "menu = " << menu << std::endl;
+#endif
+
+    return "<popup name='popup_menu'>" + menu + "</popup>";
+}
+
+
+const char* BoardViewBase::get_menu_item( const int item )
+{
+    switch( item ){
+
+        // しおりを設定/解除
+        case ITEM_BOOKMARK:
+            return "<menuitem action='BookMark'/>";
+
+            // タブでスレを開く
+        case ITEM_OPENARTICLETAB:
+            return "<menuitem action='OpenTab'/>";
+
+            // リンクをブラウザで開く
+        case ITEM_OPEN_BROWSER:
+            return "<menuitem action='OpenBrowser'/>";
+
+            // リンクのURLをコピー
+        case ITEM_COPY_URL:
+            return "<menuitem action='CopyURL'/>";
+
+            // スレのタイトルとURLをコピー
+        case ITEM_COPY_TITLE_URL_THREAD:
+            return "<menuitem action='CopyTitleURL'/>";
+
+            // dat 保存
+        case ITEM_SAVE_DAT:
+            return "<menuitem action='SaveDat'/>";
+
+            // スレをお気に入りに追加
+        case ITEM_FAVORITE_ARTICLE:
+            return "<menuitem action='Favorite_Article'/>";
+
+            // 次スレ検索
+        case ITEM_NEXTARTICLE:
+            return "<menuitem action='SearchNextArticle'/>";
+
+            // スレをあぼ〜んする"
+        case ITEM_ABONE_ARTICLE:
+            return "<menuitem action='AboneThread'/>";
+
+            // 削除
+        case ITEM_DELETE:
+            return
+            "<menu action='Delete_Menu'>"
+            "<menuitem action='Delete'/>"
+            "</menu>";
+
+            // スレのプロパティ
+        case ITEM_PREF_THREAD:
+            return "<menuitem action='PreferenceArticle'/>";
+
+            // 板のプロパティ
+        case ITEM_PREF_BOARD:
+            return "<menuitem action='PreferenceBoard'/>";
+
+            // 区切り
+        case ITEM_SEPARATOR:
+            return "<separator/>";
+    }
+
+    return "";
+}
+
+
 //
 // 行数
 //
@@ -711,20 +833,11 @@ void BoardViewBase::restore_sort()
 {
     m_search_invert = false;
 
-    m_col = DBTREE::board_view_sort_column( get_url_board() );
-    m_sortmode = DBTREE::board_view_sort_mode( get_url_board() );
+    m_col = get_default_sort_column();
+    m_sortmode = get_default_view_sort_mode();
 
-    m_previous_col = DBTREE::board_view_sort_pre_column( get_url_board() );
-    m_previous_sortmode = DBTREE::board_view_sort_pre_mode( get_url_board() );
-
-    if( m_show_col_board ){
-
-        m_previous_col = m_col;
-        m_previous_sortmode = m_sortmode;
-
-        m_col = COL_BOARD;
-        m_sortmode = SORTMODE_ASCEND;
-    }
+    m_previous_col = get_default_view_sort_pre_column();
+    m_previous_sortmode = get_default_view_sort_pre_mode();
 
     if( get_row_size() ){
         exec_sort();
@@ -733,6 +846,30 @@ void BoardViewBase::restore_sort()
 }
 
 
+//
+// デフォルトのソート状態
+//
+const int BoardViewBase::get_default_sort_column()
+{
+    return DBTREE::board_view_sort_column( get_url_board() );
+}
+
+const int BoardViewBase::get_default_view_sort_mode()
+{
+    return DBTREE::board_view_sort_mode( get_url_board() );
+}
+
+const int BoardViewBase::get_default_view_sort_pre_column()
+{
+    return DBTREE::board_view_sort_pre_column( get_url_board() );
+}
+
+const int BoardViewBase::get_default_view_sort_pre_mode()
+{
+    return DBTREE::board_view_sort_pre_mode( get_url_board() );
+}
+
+
 //
 // ヘッダをクリックしたときのslot関数
 //
@@ -1073,13 +1210,15 @@ void BoardViewBase::relayout()
 //
 // view更新
 //
-void BoardViewBase::update_view_impl( const std::vector< DBTREE::ArticleBase* >& list_subject, const bool loading_fin )
+// loading_fin : ロードが完了したら true をセットして呼び出す
+//
+void BoardViewBase::update_view_impl( const std::vector< DBTREE::ArticleBase* >& list_article, const bool loading_fin )
 {
 #ifdef _DEBUG
     const int code = DBTREE::board_code( get_url_board() );
     std::cout << "BoardViewBase::update_view_impl " << get_url()
               << " code = " << code
-              << " size = " << list_subject.size()
+              << " size = " << list_article.size()
               << std::endl;
 #endif    
 
@@ -1088,16 +1227,16 @@ void BoardViewBase::update_view_impl( const std::vector< DBTREE::ArticleBase* >&
     m_treeview.unset_model();
 #endif
 
-    if( list_subject.size() ){
+    if( list_article.size() ){
 
         m_liststore->clear();
 
         unsorted_column();
 
         // 行の追加
-        for( int i = list_subject.size()-1; i >= 0;  --i ){
+        for( int i = list_article.size()-1; i >= 0;  --i ){
 
-            DBTREE::ArticleBase* art = list_subject[ i ];
+            DBTREE::ArticleBase* art = list_article[ i ];
             prepend_row( art, i + 1 );
         }
 
@@ -1598,9 +1737,7 @@ Gtk::Menu* BoardViewBase::get_popupmenu( const std::string& url )
 // 特定の行だけの表示内容更新
 //
 // url : subject.txt のアドレス
-// id : DAT の ID(拡張子付き)
-//
-// もし ID が empty() なら全ての行の表示内容を更新する
+// id : DAT の ID(拡張子付き), empty なら全ての行の表示内容を更新する
 //
 void BoardViewBase::update_item( const std::string& url, const std::string& id )
 {
@@ -1622,7 +1759,7 @@ void BoardViewBase::update_item( const std::string& url, const std::string& id )
 
     unsorted_column();
    
-    Gtk::TreeModel::Row row = get_row_from_url( url_dat );
+    const Gtk::TreeModel::Row row = get_row_from_url( url_dat );
     if( row ) update_row_common( row );
 }
 
@@ -1661,7 +1798,7 @@ void BoardViewBase::update_item_all()
 //
 // 行を作って内容をセット
 //
-Gtk::TreeModel::Row BoardViewBase::prepend_row( DBTREE::ArticleBase* art, const int id )
+const Gtk::TreeModel::Row BoardViewBase::prepend_row( DBTREE::ArticleBase* art, const int id )
 {
     Gtk::TreeModel::Row row = *( m_liststore->prepend() ); // append より prepend の方が速いらしい
 
@@ -1685,7 +1822,7 @@ Gtk::TreeModel::Row BoardViewBase::prepend_row( DBTREE::ArticleBase* art, const
 //
 // prepend_row() と update_item() で共通に更新する列
 //
-void BoardViewBase::update_row_common( Gtk::TreeModel::Row& row )
+void BoardViewBase::update_row_common( const Gtk::TreeModel::Row& row )
 {
     DBTREE::ArticleBase* art = row[ m_columns.m_col_article ];
     if( art->empty() ) return;
@@ -2073,7 +2210,6 @@ void BoardViewBase::slot_dropped_url_list( const std::list< std::string >& url_l
 
         CORE::DATA_INFO info;
         info.type = TYPE_FILE;
-        info.parent = NULL;
         info.url = MISC::remove_str( ( *it ), "file://" );
         list_info.push_back( info );
 
@@ -2101,7 +2237,7 @@ void BoardViewBase::slot_bookmark( const int bookmark )
             bool set = bookmark;
             if( bookmark == BOOKMARK_AUTO ) set = ! art->is_bookmarked_thread();
 #ifdef _DEBUG
-            std::cout << "BoardViewBase::slot_bookmark url = " << url << " set = " << set << std::endl;
+            std::cout << "BoardViewBase::slot_bookmark url = " << art->get_url() << " set = " << set << std::endl;
 #endif
             art->set_bookmarked_thread( set );
         }
@@ -2668,12 +2804,14 @@ void BoardViewBase::slot_abone_thread()
     }
 
     // あぼーん情報更新
-    // 板の再描画も行われる
     std::list< std::string > words = DBTREE::get_abone_list_word_thread( get_url_board() );
     std::list< std::string > regexs = DBTREE::get_abone_list_regex_thread( get_url_board() );
     const int number = DBTREE::get_abone_number_thread( get_url_board() );
     const int hour = DBTREE::get_abone_hour_thread( get_url_board() );
-    DBTREE::reset_abone_thread( get_url_board(), threads, words, regexs, number, hour );
+    const bool redraw = false; // 板の再描画はしない
+    DBTREE::reset_abone_thread( get_url_board(), threads, words, regexs, number, hour, redraw );
+
+    m_treeview.delete_selected_rows( true );
 }
 
 
@@ -2715,7 +2853,6 @@ void BoardViewBase::set_article_to_buffer()
             info.parent = BOARD::get_admin()->get_win();
             info.url = art->get_url();
             info.name = name.raw();
-            info.data = std::string();
             info.path = path.to_string();
 
             list_info.push_back( info );
@@ -2747,7 +2884,6 @@ void BoardViewBase::set_board_to_buffer()
     info.parent = BOARD::get_admin()->get_win();
     info.url = DBTREE::url_boardbase( url_board );
     info.name = DBTREE::board_name( url_board );
-    info.data = std::string();
     info.path = Gtk::TreePath( "0" ).to_string();
 
     list_info.push_back( info );
