@@ -20,7 +20,7 @@
 
 using namespace BOARD;
 
-Preferences::Preferences( Gtk::Window* parent, const std::string& url )
+Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std::string command )
     : SKELETON::PrefDiag( parent, url ),
       m_frame_write( "書き込み設定" ),
       m_entry_writename( true, "名前：" ),
@@ -44,12 +44,12 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
       m_label_noname( false, "デフォルト名無し：", DBTREE::default_noname( get_url() ) ),
       m_label_max_line( false, "1レスの最大改行数：" ),
       m_label_max_byte( false, "1レスの最大バイト数：" ),
-      m_entry_max_res( false, "最大レス数：" ),
       m_label_last_access( false, "最終アクセス日時 ：" ),
       m_label_modified( false, "最終更新日時 ：" ),
       m_button_clearmodified( "日時クリア" ),
       m_label_samba( false, "書き込み規制秒数 (Samba24) ：" ),
       m_button_clearsamba( "秒数クリア" ),
+      m_button_remove_old_title( "dat落ちしたスレのタイトルを削除する" ),
       m_localrule( NULL )
 {
     m_edit_cookies.set_editable( false );
@@ -78,6 +78,8 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
 
     m_frame_write.add( m_vbox_write );
 
+    set_activate_entry( m_entry_writename );
+    set_activate_entry( m_entry_writemail );
 
     // cookie と 書き込みキーワード の設定
     std::string str_cookies;
@@ -125,23 +127,38 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_hbox_live.pack_start( m_spin_live, Gtk::PACK_SHRINK );
     m_hbox_live.pack_start( m_check_live, Gtk::PACK_SHRINK );
 
+    set_activate_entry( m_spin_live );
+
     // 一般ページのパッキング
     m_label_max_line.set_text( MISC::itostr( DBTREE::line_number( get_url() ) * 2 ) );
     m_label_max_byte.set_text( MISC::itostr( DBTREE::message_count( get_url() ) ) );
-
-    int max_res = DBTREE::board_get_number_max_res( get_url() );
-    if( ! max_res ) m_entry_max_res.set_text( "未設定 " );
-    else m_entry_max_res.set_text( MISC::itostr( max_res ) );
-
     m_hbox_max.pack_start( m_label_max_line );
     m_hbox_max.pack_start( m_label_max_byte );
-    m_hbox_max.pack_start( m_entry_max_res );
+
+    // 最大レス数
+    const int max_res = DBTREE::board_get_number_max_res( get_url() );
+    m_label_maxres.set_text( "最大レス数 (0 : 未設定)：" );
+    m_spin_maxres.set_range( 0, MAX_RESNUMBER );
+    m_spin_maxres.set_increments( 1, 1 );
+    m_spin_maxres.set_value( max_res );
+    m_spin_maxres.set_sensitive( true );
+
+    m_hbox_max.pack_start( m_label_maxres, Gtk::PACK_SHRINK );
+    m_hbox_max.pack_start( m_spin_maxres, Gtk::PACK_SHRINK );
+
+    set_activate_entry( m_spin_maxres );
 
     const time_t last_access = DBTREE::board_last_access_time( get_url() );
-    if( last_access ) m_label_last_access.set_text( MISC::timettostr( last_access ) );
+    if( last_access ) m_label_last_access.set_text(
+        MISC::timettostr( last_access, MISC::TIME_WEEK )
+        + " ( " + MISC::timettostr( last_access, MISC::TIME_PASSED ) + " )"
+        );
 
     if( DBTREE::board_date_modified( get_url() ).empty() ) m_label_modified.set_text( "未取得" );
-    else m_label_modified.set_text( MISC::timettostr( DBTREE::board_time_modified( get_url() ) ) );
+    else m_label_modified.set_text(
+        MISC::timettostr( DBTREE::board_time_modified( get_url() ), MISC::TIME_WEEK )
+        + " ( " + MISC::timettostr( DBTREE::board_time_modified( get_url() ), MISC::TIME_PASSED ) + " )"
+        );
 
     m_button_clearmodified.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_clear_modified ) );
     m_hbox_modified.pack_start( m_label_modified );
@@ -204,6 +221,11 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_vbox_proxy.pack_start( m_proxy_frame, Gtk::PACK_SHRINK );
     m_vbox_proxy.pack_start( m_proxy_frame_w, Gtk::PACK_SHRINK );
 
+    set_activate_entry( m_proxy_frame.entry_host );
+    set_activate_entry( m_proxy_frame.entry_port );
+    set_activate_entry( m_proxy_frame_w.entry_host );
+    set_activate_entry( m_proxy_frame_w.entry_port );
+
     // あぼーん
     std::string str_id, str_name, str_word, str_regex;
     std::string str_thread, str_word_thread, str_regex_thread;
@@ -243,7 +265,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_label_abone_thread.set_text( "以下の数字が0の時は、設定メニューの全体あぼ〜ん設定で指定した数字が用いられます。\nまたキャッシュにログがあるスレはあぼ〜んされません。\n\n" );
 
     m_label_number.set_text( "レス以上のスレをあぼ〜ん" );
-    m_spin_number.set_range( 0, 1001 );
+    m_spin_number.set_range( 0, 9999 );
     m_spin_number.set_increments( 1, 1 );
     m_spin_number.set_value( DBTREE::get_abone_number_thread( get_url() ) );
             
@@ -251,8 +273,10 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_hbox_number.pack_start( m_spin_number, Gtk::PACK_SHRINK );
     m_hbox_number.pack_start( m_label_number, Gtk::PACK_SHRINK );
 
+    set_activate_entry( m_spin_number );
+
     m_label_hour.set_text( "時間以上スレ立てから経過したスレをあぼ〜ん" );
-    m_spin_hour.set_range( 0, 1000 );
+    m_spin_hour.set_range( 0, 9999 );
     m_spin_hour.set_increments( 1, 1 );
     m_spin_hour.set_value( DBTREE::get_abone_hour_thread( get_url() ) );
             
@@ -260,6 +284,8 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_hbox_hour.pack_start( m_spin_hour, Gtk::PACK_SHRINK );
     m_hbox_hour.pack_start( m_label_hour, Gtk::PACK_SHRINK );
 
+    set_activate_entry( m_spin_hour );
+
     m_vbox_abone_thread.set_border_width( 16 );
     m_vbox_abone_thread.set_spacing( 8 );
     m_vbox_abone_thread.pack_start( m_label_abone_thread, Gtk::PACK_SHRINK );
@@ -271,6 +297,10 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     for( it = list_thread.begin(); it != list_thread.end(); ++it ) if( ! ( *it ).empty() ) str_thread += ( *it ) + "\n";
     m_edit_thread.set_text( str_thread );
 
+    m_button_remove_old_title.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_remove_old_title ) );
+    m_vbox_abone_title.pack_start( m_edit_thread );
+    m_vbox_abone_title.pack_start( m_button_remove_old_title, Gtk::PACK_SHRINK );
+
     // スレwordあぼーん
     std::list< std::string > list_word_thread = DBTREE::get_abone_list_word_thread( get_url() );
     for( it = list_word_thread.begin(); it != list_word_thread.end(); ++it ) if( ! ( *it ).empty() ) str_word_thread += ( *it ) + "\n";
@@ -282,7 +312,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_edit_regex_thread.set_text( str_regex_thread );
 
     m_notebook_abone_thread.append_page( m_vbox_abone_thread, "一般" );
-    m_notebook_abone_thread.append_page( m_edit_thread, "NG スレタイトル" );
+    m_notebook_abone_thread.append_page( m_vbox_abone_title, "NG スレタイトル" );
     m_notebook_abone_thread.append_page( m_edit_word_thread, "NG ワード" );
     m_notebook_abone_thread.append_page( m_edit_regex_thread, "NG 正規表現" );
 
@@ -293,8 +323,9 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     m_notebook.append_page( m_vbox, "一般" );
     m_notebook.append_page( *m_localrule, "ローカルルール" );
     m_notebook.append_page( m_vbox_proxy, "プロキシ設定" );
-    m_notebook.append_page( m_notebook_abone, "あぼーん設定(スレビュー)" );
-    m_notebook.append_page( m_notebook_abone_thread, "あぼーん設定(スレ一覧)" );
+    const int page_abone_article = 3;
+    m_notebook.append_page( m_notebook_abone, "あぼ〜ん設定(スレビュー)" );
+    m_notebook.append_page( m_notebook_abone_thread, "あぼ〜ん設定(スレ一覧)" );
     m_notebook.append_page( m_edit_settingtxt, "SETTING.TXT" );
     m_notebook.signal_switch_page().connect( sigc::mem_fun( *this, &Preferences::slot_switch_page ) );
 
@@ -302,6 +333,8 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url )
     set_title( "「" + DBTREE::board_name( get_url() ) + "」のプロパティ" );
     resize( 600, 400 );
     show_all_children();
+
+    if( command == "show_abone_article" ) m_notebook.set_current_page( page_abone_article );
 }
 
 
@@ -317,7 +350,10 @@ void Preferences::slot_clear_modified()
     DBTREE::board_set_date_modified( get_url(), "" );
 
     if( DBTREE::board_date_modified( get_url() ).empty() ) m_label_modified.set_text( "未取得" );
-    else m_label_modified.set_text( MISC::timettostr( DBTREE::board_time_modified( get_url() ) ) );
+    else m_label_modified.set_text(
+        MISC::timettostr( DBTREE::board_time_modified( get_url() ), MISC::TIME_WEEK )
+        + " ( " + MISC::timettostr( DBTREE::board_time_modified( get_url() ), MISC::TIME_PASSED ) + " )"
+        );
 }
 
 
@@ -366,6 +402,23 @@ void Preferences::slot_check_live()
 }
 
 
+void Preferences::slot_remove_old_title()
+{
+
+    if( ! DBTREE::board_list_subject( get_url() ).size() ){
+        SKELETON::MsgDiag mdiag( NULL, "再読み込みしてスレ一覧を更新して下さい。", false, Gtk::MESSAGE_WARNING );
+        mdiag.run();
+        return;
+    }
+
+    const std::list< std::string > list_thread = DBTREE::get_abone_list_thread_remove( get_url() );
+    std::list< std::string >::const_iterator it = list_thread.begin();
+    std::string str;
+    for( ; it != list_thread.end(); ++it ) if( ! ( *it ).empty() ) str += ( *it ) + "\n";
+    m_edit_thread.set_text( str );
+}
+
+
 void Preferences::slot_switch_page( GtkNotebookPage*, guint page )
 {
     if( m_notebook.get_nth_page( page ) == m_localrule ){
@@ -409,7 +462,8 @@ void Preferences::slot_ok_clicked()
     std::list< std::string > list_regex_thread = MISC::get_lines( m_edit_regex_thread.get_text() );
     const int number = m_spin_number.get_value_as_int();
     const int hour = m_spin_hour.get_value_as_int();
-    DBTREE::reset_abone_thread( get_url(), list_thread, list_word_thread, list_regex_thread, number, hour );  // 板の再描画も行われる
+    const bool redraw = true; // スレ一覧を再描画
+    DBTREE::reset_abone_thread( get_url(), list_thread, list_word_thread, list_regex_thread, number, hour, redraw );  
 
     // 書き込み設定
     DBTREE::board_set_check_noname( get_url(), m_check_noname.get_active() );
@@ -425,6 +479,10 @@ void Preferences::slot_ok_clicked()
     DBTREE::board_set_live_sec( get_url(), live_sec );
     CORE::core_set_command( "redraw_article_toolbar" );
 
+    // 最大レス数
+    const int number_max_res = m_spin_maxres.get_value_as_int();
+    DBTREE::board_set_number_max_res( get_url(), number_max_res );
+
     DBTREE::board_save_info( get_url() );
 }
 
