@@ -24,7 +24,8 @@ namespace CONFIG
         CONF_PROXY_PORT_FOR2CH_W = 8080, // 2ch 書き込み用プロクシポート番号
         CONF_USE_PROXY_FOR_DATA = 0, // 2ch 以外にアクセスするときにプロクシを使用するか
         CONF_PROXY_PORT_FOR_DATA = 8080, // 2ch 以外にアクセスするときのプロクシポート番号
-        CONF_LOADER_BUFSIZE = 32,   // ローダのバッファサイズ
+        CONF_LOADER_BUFSIZE = 32,   // ローダのバッファサイズ (一般)
+        CONF_LOADER_BUFSIZE_BOARD = 2,   // ローダのバッファサイズ (スレ一覧用)
         CONF_LOADER_TIMEOUT = 10,   // ローダのタイムアウト値        
         CONF_LOADER_TIMEOUT_POST = 30, // ポストローダのタイムアウト値        
         CONF_LOADER_TIMEOUT_IMG = 30,  // 画像ローダのタイムアウト値
@@ -34,12 +35,16 @@ namespace CONFIG
         CONF_NAMEPOPUP_BY_MO = 0,   // 名前の上にマウスオーバーしたときにポップアップ表示する
         CONF_IDPOPUP_BY_MO = 0,     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
         CONF_USE_TREE_GTKRC = 0,    // ツリービューでgtkrcの設定を使用するか
+        CONF_USE_SELECT_GTKRC = 0,  // スレビューの選択色でgtkrcの設定を使用するか
         CONF_TREE_YPAD = 1,         // ツリービューの行間スペース
+        CONF_SCROLL_TREE = 1,       // カテゴリを開いたときにツリービューをスクロールする
         CONF_VIEW_MARGIN = 0,       // 各ビューと枠との間の余白
         CONF_SHOW_OLDARTICLE = 0,   // スレ一覧で古いスレも表示
         CONF_NEWTHREAD_HOUR = 24,   // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
         CONF_INC_SEARCH_BOARD = 0,  // スレ一覧でインクリメント検索をする
         CONF_SHOW_DELDIAG = 1 ,     // スレ一覧でdeleteを押したときに確認ダイアログを表示する
+        CONF_SHOW_CACHED_BOARD = 1, // スレ一覧をロードする前にキャッシュにある一覧を表示
+        CONF_SHOW_924 = 1,          // スレ一覧でお知らせスレ(924)のアイコンを表示する
         CONF_TREE_SCROLL_SIZE = 4,  // ツリービューのスクロール量(行数)
         CONF_SCROLL_SIZE = 3,       // スレビューのスクロール量
         CONF_KEY_SCROLL_SIZE = 2,   // スレビューのスクロール量(キー上下)
@@ -52,13 +57,16 @@ namespace CONFIG
         CONF_OPEN_ONE_FAVORITE = 0, // お気に入りでカテゴリを常にひとつだけ開く
         CONF_ALWAYS_WRITE_OK = 0,   // 書き込み時に書き込み確認ダイアログを出さない
         CONF_SAVE_POSTLOG = 0,      //書き込みログを保存
+        CONF_SAVE_POSTHIST = 1,      //書き込み履歴を保存
         CONF_MAXSIZE_POSTLOG = ( 256 * 1024 ), // 書き込みログの最大サイズ
         CONF_HIDE_WRITING_DIALOG = 0, // 「書き込み中」のダイアログを表示しない
         CONF_FOLD_MESSAGE = 0,      // 非アクティブ時に書き込みビューを折りたたむ
+        CONF_KEEP_IM_STATUS = 0,    // 書き込み欄の日本語のON/OFF状態を保存
         CONF_MARGIN_POPUP = 30,     // レスアンカーとポップアップの間のマージン
         CONF_MARGIN_IMGPOPUP = CONF_MARGIN_POPUP,  // レスアンカーと画像ポップアップの間のマージン
         CONF_MOUSE_RADIUS = 25,     // マウスジェスチャの判定開始半径
-        CONF_HISTORY = 20,          // 履歴の保持数
+        CONF_HISTORY_SIZE = 20,      // 履歴メニューの表示数
+        CONF_HISTORYVIEW_SIZE = 100, // 履歴ビューの表示数
         CONF_AAHISTORY = 7,         // AA履歴の保持数
         CONF_INSTRUCT_POPUP = 100,  // 0以上なら多重ポップアップの説明を表示する
         CONF_INSTRUCT_TGLART = 1, // スレビューを開いたときにスレ一覧との切り替え方法を説明する
@@ -79,25 +87,43 @@ namespace CONFIG
         CONF_SHOW_TAB_ICON = 1, // タブにアイコンを表示するか
         CONF_SHOW_POST_MARK = 1, // スレビューに書き込みマークを表示するか
         CONF_FLAT_BUTTON = 1,    // ボタンをフラットにするか
+        CONF_DRAW_TOOLBARBACK = 0, // ツールバーの背景描画
+        CONF_IMGEMB_INTERP = 0,   // 埋め込み画像のスムージングレベル(0-2, 2が最も高画質かつ低速)
+        CONF_IMGMAIN_INTERP = 0,   // 画像ビューのスムージングレベル(0-2, 2が最も高画質かつ低速)
+        CONF_IMGPOPUP_INTERP = 0,   // 画像ポップアップのスムージングレベル(0-2, 2が最も高画質かつ低速)
         CONF_IMGPOPUP_WIDTH = 320,  // 画像ポップアップ幅
         CONF_IMGPOPUP_HEIGHT = 240, // 画像ポップアップ高さ
         CONF_USE_IMAGE_POPUP = 1,    // 画像ポップアップを使用する
         CONF_USE_IMAGE_VIEW = 1,    // 画像ビューを使用する
         CONF_INLINE_IMG = 0,        // インライン画像を表示する
+        CONF_SHOW_SSSPICON = 1,     // sssp アイコン表示
         CONF_USE_MOSAIC = 1,        // 画像にモザイクをかける
+        CONF_MOSAIC_SIZE = 60,        // モザイクの大きさ
         CONF_ZOOM_TO_FIT = 1,       // 画像をデフォルトでウィンドウサイズに合わせる
         CONF_DEL_IMG_DAY = 20,      // 画像キャッシュ削除の日数
         CONF_DEL_IMGABONE_DAY = 20, // 画像あぼーん削除の日数
         CONF_MAX_IMG_SIZE = 16,     // ダウンロードする画像の最大サイズ(Mbyte)
         CONF_MAX_IMG_PIXEL = 20,     // 画像の最大サイズ(Mピクセル)
+        CONF_IMGCACHE_SIZE = 3,      // 画像のメモリキャッシュ枚数
         CONF_USE_LINK_AS_BOARD = 0,     // bbsmenu.html内にあるリンクは全て板とみなす
         CONF_SHOW_MOVEDIAG = 1,    // 板移転時に確認ダイアログを表示する
+        CONF_REMOVE_OLD_ABONE_THREAD = 0, // dat落ちしたスレをNGスレタイトルリストから取り除くか( 0: ダイアログ表示 1: 取り除く 2: 除かない )
         CONF_ABONE_NUMBER_THREAD = 0, // スレあぼーん( レス数 )
         CONF_ABONE_HOUR_THREAD = 0,   // スレあぼーん( スレ立てからの経過時間 )
         CONF_ABONE_TRANSPARENT = 0, // デフォルトで透明あぼーんをする
         CONF_ABONE_CHAIN = 0,       // デフォルトで連鎖あぼーんをする
         CONF_EXPAND_SIDEBAR = 0,      // 右ペーンが空の時にサイドバーを閉じる
-        CONF_EXPAND_RPANE = 1         // 3ペーン時にスレ一覧やスレビューを最大化する
+        CONF_EXPAND_RPANE = 1,        // 3ペーン時にスレ一覧やスレビューを最大化する
+        CONF_THRESHOLD_NEXT = 5,   // 次スレ検索の類似度のしきい値
+        CONF_REPLACE_FAVORITE_NEXT = 1,  // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
+        CONF_SHOW_DIAG_REPLACE_FAVORITE = 1, // お気に入りの自動更新をするかダイアログを出す
+        CONF_BOOKMARK_DROP = 0, // スレをお気に入りに追加したときにしおりをセットする
+        CONF_CHECK_UPDATE_BOARD = 0,  // お気に入りの更新チェック時に板の更新もチェックする
+        CONF_CHECK_UPDATE_BOOT = 0,  // 起動時にお気に入りを自動でチェックする
+        CONF_DISABLE_CLOSE = 0, // Ctrl+qでウィンドウを閉じない
+        CONF_USE_MACHI_OFFLAW = 0, // まちBBSの取得に offlaw.cgi を使用する
+        CONF_SHOW_DEL_WRITTEN_THREAD_DIAG = 1, // 書き込み履歴のあるスレを削除する時にダイアログを表示
+        CONF_SHOW_DIAG_FIFO_ERROR = 1, // FIFOの作成などにエラーがあったらダイアログを表示する
     };
 
 // browsers.cpp のデフォルトのラベル番号
@@ -135,9 +161,12 @@ namespace CONFIG
 // JD ホームページのアドレス
 #define CONF_URL_JDHP "http://jd4linux.sourceforge.jp/"
 
-// 2chの認証サーバ
+// 2chの認証サーバのアドレス
 #define CONF_LOGIN2CH "https://2chv.tora3.net/futen.cgi"
 
+// p2の認証サーバのアドレス
+#define CONF_LOGINP2 "http://p2.2ch.net/p2/"
+
 // bbsmenu.htmlのURL
 #define CONF_URL_BBSMENU "http://menu.2ch.net/bbsmenu.html"
 
@@ -164,41 +193,41 @@ namespace CONFIG
 #define CONF_COLOR_CHAR_NAME_NOMAIL "#000064640000"   //メール無し時の名前欄の文字色
 #define CONF_COLOR_CHAR_AGE "#fde800000000"    // ageの時のメール欄の文字色
 #define CONF_COLOR_CHAR_SELECTION "#ffffffffffff"  // 選択範囲の文字色
-#define CONF_COLOR_CHAR_HIGHLIGHT str_color[ COLOR_CHAR ] // ハイライトの文字色
+#define CONF_COLOR_CHAR_HIGHLIGHT CONF_COLOR_CHAR  // ハイライトの文字色
 #define CONF_COLOR_CHAR_LINK "#00000000ffff" //リンク(通常)の文字色
 #define CONF_COLOR_CHAR_LINK_LOW "#ffff0000ffff" // リンク(複数)の文字色
-#define CONF_COLOR_CHAR_LINK_HIGH str_color[ COLOR_CHAR_AGE ] // リンク(多数)の文字色
-#define CONF_COLOR_CHAR_MESSAGE str_color[ COLOR_CHAR ] // メッセージビューの文字色
-#define CONF_COLOR_CHAR_MESSAGE_SELECTION str_color[ COLOR_CHAR_SELECTION ] // メッセージビュー(選択範囲)の文字色
+#define CONF_COLOR_CHAR_LINK_HIGH CONF_COLOR_CHAR_AGE  // リンク(多数)の文字色
+#define CONF_COLOR_CHAR_MESSAGE CONF_COLOR_CHAR  // メッセージビューの文字色
+#define CONF_COLOR_CHAR_MESSAGE_SELECTION CONF_COLOR_CHAR_SELECTION  // メッセージビュー(選択範囲)の文字色
 
 #define CONF_COLOR_IMG_NOCACHE "#a5a52a2a2a2a" // 画像(キャッシュ無)の色
 #define CONF_COLOR_IMG_CACHED  "#00008b8b8b8b" // 画像(キャッシュ有)の色
 #define CONF_COLOR_IMG_LOADING "#ffff8c8c0000"  // 画像(ロード中)の色
-#define CONF_COLOR_IMG_ERR str_color[ COLOR_CHAR_AGE ] // 画像(エラー)の色
+#define CONF_COLOR_IMG_ERR CONF_COLOR_CHAR_AGE  // 画像(エラー)の色
 
 #define CONF_COLOR_BACK           "#fde8fde8f618" // スレ背景色
-#define CONF_COLOR_BACK_POPUP     str_color[ COLOR_BACK ] // ポップアップ背景色
-#define CONF_COLOR_BACK_SELECTION str_color[ COLOR_CHAR_LINK ] // 選択範囲の背景色
+#define CONF_COLOR_BACK_POPUP     CONF_COLOR_BACK  // ポップアップ背景色
+#define CONF_COLOR_BACK_SELECTION CONF_COLOR_CHAR_LINK  // 選択範囲の背景色
 
-#define CONF_COLOR_HL      "#ffffffff0000"  // ハイライト色
-#define CONF_COLOR_HL_TREE str_color[ COLOR_BACK_HIGHLIGHT ] // ツリーのハイライト色
+#define CONF_COLOR_BACK_HIGHLIGHT      "#ffffffff0000"  // ハイライト色
+#define CONF_COLOR_BACK_HIGHLIGHT_TREE CONF_COLOR_BACK_HIGHLIGHT  // ツリーのハイライト色
 
-#define CONF_COLOR_BACK_MESSAGE str_color[ COLOR_BACK ] // メッセージビューの背景色
-#define CONF_COLOR_BACK_MESSAGE_SELECTION str_color[ COLOR_BACK_SELECTION ] // メッセージビューの選択色
+#define CONF_COLOR_BACK_MESSAGE CONF_COLOR_BACK  // メッセージビューの背景色
+#define CONF_COLOR_BACK_MESSAGE_SELECTION CONF_COLOR_BACK_SELECTION  // メッセージビューの選択色
 
 #define CONF_COLOR_SEPARATOR_NEW "#7d007d007d00" // セパレータ
 
-#define CONF_COLOR_FRAME str_color[ COLOR_CHAR ] // ポップアップフレーム色
-#define CONF_COLOR_MARKER str_color[ COLOR_CHAR ] // オートスクロールマーカー色    
+#define CONF_COLOR_FRAME CONF_COLOR_CHAR  // ポップアップフレーム色
+#define CONF_COLOR_MARKER CONF_COLOR_CHAR  // オートスクロールマーカー色    
 
-#define CONF_COLOR_CHAR_BBS   str_color[ COLOR_CHAR ] // 板一覧の文字
-#define CONF_COLOR_CHAR_BBS_COMENT  str_color[ COLOR_CHAR ] // 板一覧のコメント
-#define CONF_COLOR_CHAR_BOARD str_color[ COLOR_CHAR ] // スレ一覧の文字
+#define CONF_COLOR_CHAR_BBS   CONF_COLOR_CHAR  // 板一覧の文字
+#define CONF_COLOR_CHAR_BBS_COMMENT  CONF_COLOR_CHAR  // 板一覧のコメント
+#define CONF_COLOR_CHAR_BOARD CONF_COLOR_CHAR  // スレ一覧の文字
 
-#define CONF_COLOR_BACK_BBS   str_color[ COLOR_BACK ] // 板一覧の背景色
-#define CONF_COLOR_BACK_BBS_EVEN str_color[ COLOR_BACK_BBS ] // 板一覧の背景色(偶数行)
-#define CONF_COLOR_BACK_BOARD str_color[ COLOR_BACK ] // スレ一覧の背景色
-#define CONF_COLOR_BACK_BOARD_EVEN str_color[ COLOR_BACK_BOARD ] // スレ一覧の背景色(偶数行)
+#define CONF_COLOR_BACK_BBS   CONF_COLOR_BACK  // 板一覧の背景色
+#define CONF_COLOR_BACK_BBS_EVEN CONF_COLOR_BACK_BBS  // 板一覧の背景色(偶数行)
+#define CONF_COLOR_BACK_BOARD CONF_COLOR_BACK  // スレ一覧の背景色
+#define CONF_COLOR_BACK_BOARD_EVEN CONF_COLOR_BACK_BOARD  // スレ一覧の背景色(偶数行)
 
 // migemo-dictの場所
 #ifdef MIGEMODICT
