@@ -40,22 +40,30 @@ namespace CONFIG
     void set_manage_winpos( const bool manage );
 
     // 色 ( # + 12桁の16進数 の形式 )
-    const std::string& get_color( int id );
-    void set_color( int id, const std::string& color );
+    const std::string& get_color( const int id );
+    void set_color( const int id, const std::string& color );
     void reset_colors();
 
     // ツリービューでgtkrcの設定を使用するか
     const bool get_use_tree_gtkrc();
+    void set_use_tree_gtkrc( const bool use );
+
+    // スレビューの選択色でgtkrcの設定を使用するか
+    const bool get_use_select_gtkrc();
+    void set_use_select_gtkrc( const bool use );
 
     // ツリービューの行間スペース
     const int get_tree_ypad();
 
+    // カテゴリを開いたときにツリービューをスクロールする
+    const bool get_scroll_tree();
+
     // 各ビューと枠との間の余白
     const int get_view_margin();
 
     // フォント
-    const std::string& get_fontname( int id );
-    void set_fontname( int id, const std::string& fontname );
+    const std::string& get_fontname( const int id );
+    void set_fontname( const int id, const std::string& fontname );
     void reset_fonts();
 
     // レスを参照するときに前に付ける文字
@@ -67,9 +75,12 @@ namespace CONFIG
     // JD ホームページのアドレス
     const std::string& get_url_jdhp();
 
-    // 2chの認証サーバ
+    // 2chの認証サーバのアドレス
     const std::string& get_url_login2ch();
 
+    // p2の認証サーバのアドレス
+    const std::string& get_url_loginp2();
+
     // bbsmenu.htmlのURL
     const std::string& get_url_bbsmenu();    
 
@@ -135,17 +146,18 @@ namespace CONFIG
     void set_proxy_port_for_data( const int port );
 
     // ローダのバッファサイズ
-    const int get_loader_bufsize();
+    const int get_loader_bufsize();  // 一般
+    const int get_loader_bufsize_board();  // スレ一覧読み込み用
 
     // ローダのタイムアウト値
     const int get_loader_timeout();
     const int get_loader_timeout_post();
-    const int get_loader_timeout_img();
+    const int get_loader_timeout_data();
     const int get_loader_timeout_checkupdate();
 
     // ipv6使用
     const bool get_use_ipv6();
-    void set_use_ipv6( bool set );
+    void set_use_ipv6( const bool set );
 
     // リンクをクリックしたときに実行するコマンド
     const std::string& get_command_openurl();
@@ -153,7 +165,7 @@ namespace CONFIG
 
     // ブラウザ設定ダイアログのコンボボックスの番号
     const int get_browsercombo_id();
-    void set_browsercombo_id( int id );
+    void set_browsercombo_id( const int id );
 
     // レス番号の上にマウスオーバーしたときに参照ポップアップ表示する
     const bool get_refpopup_by_mo();
@@ -164,6 +176,11 @@ namespace CONFIG
     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
     const bool get_idpopup_by_mo();
 
+    // 画像のスムージングレベル(0-2, 2が最も高画質かつ低速)
+    const int get_imgemb_interp();
+    const int get_imgmain_interp();
+    const int get_imgpopup_interp();
+
     // 画像ポップアップサイズ
     const int get_imgpopup_width();
     const int get_imgpopup_height();
@@ -209,9 +226,12 @@ namespace CONFIG
     // 画像の最大サイズ(Mピクセル)
     const int get_max_img_pixel();
 
+    // 画像のメモリキャッシュ枚数
+    const int get_imgcache_size();
+
     // スレ一覧にdat落ちしたスレも表示する
     const bool get_show_oldarticle();
-    void set_show_oldarticle( bool showarticle );
+    void set_show_oldarticle( const bool showarticle );
 
     // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
     const int get_newthread_hour();
@@ -223,6 +243,12 @@ namespace CONFIG
     const bool get_show_deldiag();
     void set_show_deldiag( const bool show );
 
+    // スレ一覧をロードする前にキャッシュにある一覧を表示
+    const bool get_show_cached_board();
+
+    // スレ一覧でお知らせスレ(924)のアイコンを表示する
+    const bool get_show_924();
+    
     // ツリービューのスクロール量(マウスホイール上下・行数)
     const int get_tree_scroll_size();
 
@@ -237,11 +263,11 @@ namespace CONFIG
 
     // スレビューでリロード後に一番下までスクロール
     const bool get_jump_after_reload();
-    void set_jump_after_reload( bool set );
+    void set_jump_after_reload( const bool set );
 
     // スレビューでリロード後に新着までスクロール
     const bool get_jump_new_after_reload();
-    void set_jump_new_after_reload( bool set );
+    void set_jump_new_after_reload( const bool set );
 
     // 実況モード
     const int get_live_mode();
@@ -263,29 +289,32 @@ namespace CONFIG
 
     // 書き込み時に書き込み確認ダイアログを出すかどうか
     const bool get_always_write_ok();
-    void set_always_write_ok( bool write_ok );
+    void set_always_write_ok( const bool write_ok );
 
     // 書き込みログを保存
     const bool get_save_post_log();
-    void set_save_post_log( bool save );
+    void set_save_post_log( const bool save );
 
     // 書き込みログの最大サイズ
     const size_t get_maxsize_post_log();
 
     // 書き込み履歴を保存
     const bool get_save_post_history();
-    void set_save_post_history( bool save );
+    void set_save_post_history( const bool save );
 
     // 書き込み中のダイアログを表示しない
     const bool get_hide_writing_dialog();
 
     // 非アクティブ時に書き込みビューを折りたたむ
     const bool get_fold_message();
-    void set_fold_message( bool fold );
+    void set_fold_message( const bool fold );
+
+    // 書き込み欄の日本語のON/OFF状態を保存
+    const bool get_keep_im_status();
 
     // ポップアップとカーソルの間のマージン
     const int get_margin_popup();
-    void set_margin_popup( int margin );
+    void set_margin_popup( const int margin );
 
     // 画像ポップアップとカーソルの間のマージン
     const int get_margin_imgpopup();
@@ -293,9 +322,12 @@ namespace CONFIG
     // マウスジェスチャの判定開始半径
     const int get_mouse_radius();
 
-    // 履歴の保持数
+    // 履歴メニューの表示数
     const int get_history_size();
 
+    // 履歴ビューの表示数
+    const int get_historyview_size();
+
     // AA履歴の保持数
     const int get_aahistory_size();
 
@@ -304,26 +336,26 @@ namespace CONFIG
 
     // スレビューを開いたときにスレ一覧との切り替え方法を説明する
     const bool get_instruct_tglart();
-    void set_instruct_tglart( bool set );
+    void set_instruct_tglart( const bool set );
 
     // 画像ビューを開いたときにスレビューとの切り替え方法を説明する
     const bool get_instruct_tglimg();
-    void set_instruct_tglimg( bool set );
+    void set_instruct_tglimg( const bool set );
 
     // 下線位置調整
     const double get_adjust_underline_pos();
-    void set_adjust_underline_pos( double pos );
+    void set_adjust_underline_pos( const double pos );
 
     // スレ表示の行間調整
     const double get_adjust_line_space();
-    void set_adjust_line_space( double space );
+    void set_adjust_line_space( const double space );
 
     // スレ表示でリンクの下に下線を引く
     const bool get_draw_underline();
 
     // スレビューで文字幅の近似を厳密にする
     const bool get_strict_char_width();
-    void set_strict_char_width( bool strictwidth );
+    void set_strict_char_width( const bool strictwidth );
 
     // スレビューで発言数(ID)をカウントする
     const bool get_check_id();
@@ -341,7 +373,7 @@ namespace CONFIG
 
     // ユーザーコマンドで選択できない項目を非表示にする
     const bool get_hide_usrcmd();
-    void set_hide_usrcmd( bool hide );
+    void set_hide_usrcmd( const bool hide );
 
     // スレビューで再読み込みボタンを押したときに全タブを更新する
     const bool get_reload_allthreads();
@@ -360,6 +392,10 @@ namespace CONFIG
     const bool get_flat_button();
     void set_flat_button( const bool set );
 
+    // ツールバーの背景描画
+    const bool get_draw_toolbarback();
+    void set_draw_toolbarback( const bool set );
+
     // boardviewでのスレの全体あぼーん
     std::list< std::string >& get_list_abone_word_thread(); // ワード
     std::list< std::string >& get_list_abone_regex_thread(); // 正規表現
@@ -367,6 +403,9 @@ namespace CONFIG
     void set_list_abone_word_thread( std::list< std::string >& word );
     void set_list_abone_regex_thread( std::list< std::string >& regex );
 
+    const int get_remove_old_abone_thread(); // dat落ちしたスレをNGスレタイトルリストから取り除くか( 0: ダイアログ表示 1: 取り除く 2: 除かない )
+    void set_remove_old_abone_thread( const int remove ); 
+
     const int get_abone_number_thread();
     void set_abone_number_thread( const int number );
 
@@ -374,20 +413,20 @@ namespace CONFIG
     void set_abone_hour_thread( const int hour );
 
     // articleviewでのレスの全体あぼーん
-    std::list< std::string >& get_list_abone_name(); // 名前
-    std::list< std::string >& get_list_abone_word(); // ワード
-    std::list< std::string >& get_list_abone_regex(); // 正規表現
+    const std::list< std::string >& get_list_abone_name(); // 名前
+    const std::list< std::string >& get_list_abone_word(); // ワード
+    const std::list< std::string >& get_list_abone_regex(); // 正規表現
 
-    void set_list_abone_name( std::list< std::string >& name );
-    void set_list_abone_word( std::list< std::string >& word );
-    void set_list_abone_regex( std::list< std::string >& regex );
+    void set_list_abone_name( const std::list< std::string >& name );
+    void set_list_abone_word( const std::list< std::string >& word );
+    void set_list_abone_regex( const std::list< std::string >& regex );
 
     // デフォルトで透明、連鎖あぼーんをするか
     const bool get_abone_transparent();
-    void set_abone_transparent( bool set );
+    void set_abone_transparent( const bool set );
 
     const bool get_abone_chain();
-    void set_abone_chain( bool set );
+    void set_abone_chain( const bool set );
 
     // 右ペーンが空の時にサイドバーを閉じるか
     const bool get_expand_sidebar();
@@ -399,14 +438,37 @@ namespace CONFIG
     const int get_threshold_next();
 
     // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
-    const bool get_replace_favorite_next();
+    const int get_replace_favorite_next();
+    void set_replace_favorite_next( const int mode );
+
+    // お気に入りの自動更新をするかダイアログを出す
+    const bool show_diag_replace_favorite();
+    void set_show_diag_replace_favorite( const bool show );
 
     // スレをお気に入りに追加したときにしおりをセットする
     const bool get_bookmark_drop();
 
+    // お気に入りの更新チェック時に板の更新もチェックする
+    const bool get_check_update_board();
+
+    // 起動時にお気に入りを自動でチェックする
+    const bool get_check_update_boot();
+
     // Ctrl+qでウィンドウを閉じない
     const bool get_disable_close();
 
+    // まちBBSの取得に offlaw.cgi を使用する
+    const bool get_use_machi_offlaw();
+    void set_use_machi_offlaw( const bool set );
+
+    // 書き込み履歴のあるスレを削除する時にダイアログを表示
+    const bool get_show_del_written_thread_diag();
+    void set_del_written_thread_diag( const bool set );
+
+    // FIFOの作成などにエラーがあったらダイアログを表示する
+    const bool get_show_diag_fifo_error();
+    void set_show_diag_fifo_error( const bool set );
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     const std::string& get_migemodict_path();
