@@ -8,7 +8,7 @@
 
 #include "jdlib/miscutil.h"
 #include "jdlib/miscmsg.h"
-#include "jdlib/miscgtk.h"
+#include "jdlib/imgloader.h"
 #include "jdlib/confloader.h"
 #include "jdlib/loaderdata.h"
 
@@ -18,6 +18,7 @@
 #include "httpcode.h"
 #include "cache.h"
 #include "session.h"
+#include "global.h"
 
 #include <sstream>
 #include <cstring>
@@ -68,6 +69,8 @@ Img::Img( const std::string& url )
     std::cout << "Img::Img url = " << m_url <<  std::endl;
 #endif
 
+    set_priority_low();
+
     reset();
 }
 
@@ -85,6 +88,17 @@ Img::~Img()
 }
 
 
+void Img::clock_in()
+{
+    // ロード待ち
+    if( m_wait ){
+
+        --m_wait_counter;
+        if( m_wait_counter <= 0 ) download_img( m_refurl, m_mosaic, 0 );
+    }
+}
+
+
 //
 // リセット( 情報をクリアしてinfoファイル再読み込み )
 //
@@ -114,6 +128,53 @@ void Img::clear()
     m_width_mosaic = 0;
     m_height_mosaic = 0;
     m_abone = false;
+    m_wait = false;
+    m_wait_counter = 0;
+}
+
+
+//
+// ロード待ち状態セット/リセット
+//
+const bool Img::set_wait( const std::string& refurl, const bool mosaic, const int waitsec )
+{
+    if( waitsec && ! m_wait ){
+
+#ifdef _DEBUG
+        std::cout << "Img::set_wait url = " << m_url << std::endl;
+#endif
+        m_wait = true;
+        m_wait_counter = (1000/TIMER_TIMEOUT) * waitsec;
+        DBIMG::set_clock_in( this );
+
+        m_refurl = refurl;
+        m_mosaic = mosaic;
+
+        CORE::core_set_command( "redraw", m_url );
+        CORE::core_set_command( "redraw_article" );
+        CORE::core_set_command( "redraw_message" );
+
+        return true;
+    }
+
+    return false;
+}
+
+
+void Img::reset_wait()
+{
+    if( m_wait ){
+#ifdef _DEBUG
+        std::cout << "Img::reset_wait url = " << m_url << std::endl;
+#endif
+        m_wait = false;
+        m_wait_counter = 0;
+        DBIMG::reset_clock_in( this );
+
+        CORE::core_set_command( "redraw", m_url );
+        CORE::core_set_command( "redraw_article" );
+        CORE::core_set_command( "redraw_message" );
+    }
 }
 
 
@@ -191,9 +252,10 @@ const std::string Img::get_cache_path()
 // receive_data()　と receive_finish() がコールバックされる
 //
 // refurl : 参照元のスレのアドレス
-// nomosaic : trueの時はモザイク解除
+// mosaic : モザイク表示するか
+// waitsec: 指定した秒数経過後にロード開始
 //
-void Img::download_img( const std::string& refurl, const bool nomosaic )
+void Img::download_img( const std::string refurl, const bool mosaic, const int waitsec )
 {
     // ダウンロード初回(リダイレクトでは無い)
     if( ! m_count_redirect ) m_url_alt = std::string();
@@ -202,17 +264,28 @@ void Img::download_img( const std::string& refurl, const bool nomosaic )
     std::cout << "Img::download_img url = ";
     if( ! m_url_alt.empty() ) std::cout << m_url_alt << "  count = " << m_count_redirect << std::endl;
     else std::cout << m_url << std::endl;
-    std::cout << "refurl = " << refurl <<  std::endl;
+    std::cout << "refurl = " << refurl <<  " wait = " << m_wait << " waitsec = " << waitsec << std::endl;
 #endif
 
     if( is_loading() ) return;
     if( is_cached() ) return;
     if( ! CACHE::mkdir_imgroot() ) return;
     if( get_type() == T_LARGE ) return;
+    if( is_wait() && waitsec ) return;
+
+    // ロード待ち状態にセット
+    if( set_wait( refurl, mosaic, waitsec ) ) return;
+
+    // ロード待ち状態解除
+    reset_wait();
+
+#ifdef _DEBUG
+    std::cout << "start...\n";
+#endif
 
     // ダウンロード開始
     std::string path = get_cache_path();
-    m_fout = fopen( path.c_str(), "wb" );
+    m_fout = fopen( to_locale_cstr( path ), "wb" );
     if( m_fout == NULL ){
         m_type = T_OPENFAILED;
         receive_finish();
@@ -221,8 +294,8 @@ void Img::download_img( const std::string& refurl, const bool nomosaic )
 
     clear();
     m_refurl = refurl;
-    if( nomosaic ) m_mosaic = false;
-               
+    m_mosaic = mosaic;
+
     JDLIB::LOADERDATA data;
     data.init_for_data();
 
@@ -234,6 +307,26 @@ void Img::download_img( const std::string& refurl, const bool nomosaic )
 }
 
 
+//
+// ロード停止
+//
+void Img::stop_load()
+{
+#ifdef _DEBUG
+    std::cout << "Img::stop_load url = " << m_url << std::endl;
+#endif
+
+    SKELETON::Loadable::stop_load();
+
+    if( m_wait ){
+
+        set_code( HTTP_TIMEOUT );
+        set_str_code( "stop loading" );
+
+        reset_wait();
+    }
+}
+
 
 //
 // キャッシュ保存
@@ -264,7 +357,7 @@ const bool Img::save( Gtk::Window* parent, const std::string& path_to )
 //
 // モザイクon/off
 //
-void Img::set_mosaic( bool mosaic )
+void Img::set_mosaic( const bool mosaic )
 {
     if( ! is_cached() ) return;
 
@@ -272,6 +365,7 @@ void Img::set_mosaic( bool mosaic )
     save_info();
 
     // 再描画
+    CORE::core_set_command( "redraw_bbslist" );
     CORE::core_set_command( "redraw_article" );
     CORE::core_set_command( "redraw_message" );
 }
@@ -353,6 +447,9 @@ void Img::receive_data( const char* data, size_t size )
               << "size / total = " << current_length() << " / " << total_length() << std::endl;
 #endif
 
+    // Created は OK にしておく
+    if( get_code() == HTTP_CREATED ) set_code( HTTP_OK );
+
     // 先頭のシグネチャを見て画像かどうかをチェック
     if( m_type == T_UNKNOWN && get_code() == HTTP_OK ){
 
@@ -422,6 +519,9 @@ void Img::receive_finish()
     if( m_fout ) fclose( m_fout );
     m_fout = NULL;
 
+    // Created は OK にしておく
+    if( get_code() == HTTP_CREATED ) set_code( HTTP_OK );
+
     // データが無い
     if( get_code() == HTTP_OK && ! current_length() ) m_type = T_NODATA;
 
@@ -441,7 +541,7 @@ void Img::receive_finish()
 #endif
             ++m_count_redirect;
             m_url_alt = location();
-            download_img( m_refurl, false );
+            download_img( m_refurl, m_mosaic, 0 );
             return;
         }
         else m_type = T_NODATA;
@@ -452,8 +552,7 @@ void Img::receive_finish()
 
     // 画像サイズ取得
     if( get_code() == HTTP_OK && current_length() ){
-
-        MISC::get_img_size( get_cache_path(), m_width, m_height );
+        JDLIB::ImgLoader::get_loader( get_cache_path() )->get_size( m_width, m_height );
         if( ! m_width || ! m_height ) m_type = T_NOSIZE;
     }
 
@@ -523,7 +622,7 @@ void Img::receive_finish()
     // 読み込み失敗の場合はファイルを消しておく
     if( ! total_length() ){
         std::string path = get_cache_path();
-        if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ) unlink( path.c_str() );
+        if( CACHE::file_exists( path ) == CACHE::EXIST_FILE ) unlink( to_locale_cstr( path ) );
 #ifdef _DEBUG
         std::cout << "unlink cache\n";
 #endif
@@ -753,7 +852,7 @@ void Img::save_info()
 #ifdef _DEBUG
             std::cout << "unlink " << path_info << std::endl;
 #endif 
-            unlink( path_info.c_str() );
+            unlink( to_locale_cstr( path_info ) );
         }
 
         if( get_code() == HTTP_INIT ) return;
