@@ -13,6 +13,7 @@
 #include <sys/time.h>
 #include <list>
 #include <vector>
+#include <ctime>
 
 #include "skeleton/lockable.h"
 
@@ -56,7 +57,7 @@ namespace DBTREE
         int m_number_load;           // キャッシュにあるレスの数
         int m_number_before_load;    // ロード前のレスの数( m_number_new を計算するのに使う )
         int m_number_seen;           // どこまで読んだか
-        int m_number_max;            // 規定の最大レス数
+        int m_number_max;            // 規定の最大レス数(0:未設定)
         struct timeval m_access_time;  // ユーザが最後にロードした時間
         struct timeval m_check_update_time;  // 最終更新チェック時間
         struct timeval m_write_time;   // 最終書き込み時間
@@ -99,10 +100,14 @@ namespace DBTREE
         // ロード終了時に次スレ移行チェックと前スレの情報のコピーをする
         std::string m_url_pre_article;
 
+        // スレッド924か
+        bool m_924;
+
       protected:
+
         void set_key( const std::string& key ){ m_key = key; }
-        void set_since_time( time_t since ){ m_since_time = since; }
-        void set_since_date( std::string since ){ m_since_date = since; }
+        void set_since_time( const time_t since ){ m_since_time = since; }
+        void set_is_924( const bool is924 ){ m_924 = is924; }
         
       public:
 
@@ -133,9 +138,8 @@ namespace DBTREE
         const int get_number_new() const { return m_number_new; }
         const int get_number_load() const { return m_number_load; }
         const int get_number_seen() const{  return m_number_seen; }
-        const int get_number_max() const { return m_number_max; }
 
-        void set_number_max( const int number ){ if( number > 0 ) m_number_max = number; }
+        void set_number_max( const int number ){ m_number_max = number; }
 
         // スレ速度
         const int get_speed();
@@ -184,7 +188,10 @@ namespace DBTREE
         std::list< int > get_res_posted();
 
         // number番のレスを参照しているレス番号をリストにして取得
-        std::list< int > get_res_reference( int number );
+        std::list< int > get_res_reference( const int number );
+
+        // res_num に含まれるレスを参照しているレス番号をリストにして取得
+        std::list< int > get_res_reference( const std::list< int >& res_num );
 
         // URL を含むレス番号をリストにして取得
         std::list< int > get_res_with_url();
@@ -226,7 +233,8 @@ namespace DBTREE
 
         // 最終書き込み時間
         const time_t& get_write_time() const { return m_write_time.tv_sec; } // 秒
-        const std::string& get_write_date() const { return m_write_time_date; } // string型
+        const std::string& get_write_date(); // string型
+        void reset_write_date(){ m_write_time_date = std::string(); }
 
         // 書き込み数
         const int get_num_posted();
@@ -242,7 +250,8 @@ namespace DBTREE
 
         // スレ立て時刻
         const time_t& get_since_time() const { return m_since_time; };
-        const std::string& get_since_date() const { return m_since_date; }
+        const std::string& get_since_date();
+        void reset_since_date(){ m_since_date = std::string(); }
 
         // 更新時間
         time_t get_time_modified();
@@ -264,7 +273,7 @@ namespace DBTREE
         void set_status( const int status ){ m_status = status; }
         
         void set_subject( const std::string& subject );
-        void set_number( const int number );
+        void set_number( const int number, const bool is_online );
         void set_number_load( const int number_load );
         void set_number_seen( const int number_seen );
         void update_writetime();
@@ -323,7 +332,7 @@ namespace DBTREE
         void add_abone_id( const std::string& id );
         void add_abone_name( const std::string& name );
         void add_abone_word( const std::string& word );
-        void set_abone_res( const int number, const bool set );
+        void set_abone_res( const int num_from, const int num_to, const bool set );
         void set_abone_transparent( const bool set ); // 透明
         void set_abone_chain( const bool set ); // 連鎖
         void set_abone_age( const bool set ); // age
@@ -344,8 +353,10 @@ namespace DBTREE
         // キャッシュがあって、force = true の時は強制書き込み
         virtual void save_info( const bool force );
 
-        // スレッドのロード開始
-        const bool is_loading();
+        const bool is_loading(); // ロード中か
+        const bool is_checking_update();  // 更新チェック中か
+
+        // スレッドのロード停止
         void stop_load();
 
         // スレッドのロード開始
@@ -362,8 +373,14 @@ namespace DBTREE
         // url_src で示されるスレの情報をコピー
         void copy_article_info( const std::string& url_src );
 
+        // スレッド924か
+        const bool is_924() const{ return m_924; }
+
       private:
 
+        // 更新チェック可能
+        virtual const bool enable_check_update(){ return true; }
+
         // NodeTree作成
         // もしNodeTreeが作られていなかったら作成
         JDLIB::ConstPtr< NodeTreeBase >& get_nodetree();
