@@ -25,6 +25,7 @@
 #include "cache.h"
 #include "config/globalconf.h"
 #include "session.h"
+#include "boardcolumnsid.h"
 
 #include <sstream>
 #include <cstring>
@@ -48,6 +49,10 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     : SKELETON::Loadable()
     , m_status( STATUS_UNKNOWN )
     , m_list_subject_created( false )
+    , m_view_sort_column( -1 )
+    , m_view_sort_mode( -1 )
+    , m_view_sort_pre_column( -1 )
+    , m_view_sort_pre_mode( -1 )
     , m_root( root )
     , m_path_board( path_board )
     , m_name( name )
@@ -55,10 +60,13 @@ BoardBase::BoardBase( const std::string& root, const std::string& path_board, co
     , m_live_sec( 0 )
     , m_last_access_time( 0 )
     , m_number_max_res( 0 )
-    , m_rawdata( 0 )
+    , m_iconv( NULL )
+    , m_rawdata( NULL )
+    , m_rawdata_left( NULL )
     , m_read_info( 0 )
     , m_append_articles( false )
     , m_get_article( NULL )
+    , m_cancel_remove_abone_thread( false )
     , m_article_null( 0 )
 {
     clear();
@@ -273,9 +281,19 @@ void BoardBase::clear()
 {
     if( m_rawdata ) free( m_rawdata );
     m_rawdata = NULL;
+
+    if( m_rawdata_left ) free( m_rawdata_left );
+    m_rawdata_left = NULL;
+
     m_lng_rawdata = 0;
+    m_lng_rawdata_left = 0;
 
     m_get_article_url = std::string();
+
+    if( m_iconv ) delete m_iconv;
+    m_iconv = NULL;
+
+    m_list_artinfo.clear();
 }
 
 
@@ -288,6 +306,17 @@ void BoardBase::send_update_board()
     std::cout << "BoardBase::send_update_board\n";
 #endif
 
+    // ダウンロードを開始したビュー以外のビューの内容を更新する
+    //
+    // "update_board" コマンドの後に"update_board_item"を送ると
+    // ローディングが終了しているため行を二回更新してしまうので注意
+    // 詳しくは BoardViewBase::update_item() を参照
+    CORE::core_set_command( "update_board_item", url_subject(),
+                            std::string() // IDとして空文字を送る
+        );
+
+
+    // ダウンロードを開始したビューの内容を更新する
     std::list< std::string >::iterator it = m_url_update_views.begin();
     for( ; it != m_url_update_views.end(); ++it ){
 #ifdef _DEBUG
@@ -373,6 +402,24 @@ void BoardBase::clear_all_post_history()
 }
 
 
+
+//
+// 最大レス数をセット
+//
+void BoardBase::set_number_max_res( const int number )
+{
+#ifdef _DEBUG
+    std::cout << "BoardBase::set_number_max_res " << m_number_max_res << " -> " << number << std::endl;
+#endif
+
+    m_number_max_res = MAX( 0, MIN( MAX_RESNUMBER, number ) );
+
+    ArticleHashIterator it = m_hash_article->begin();
+    for( ; it != m_hash_article->end(); ++it ) ( *it )->set_number_max( m_number_max_res );
+}
+
+
+
 //
 // 板情報の取得
 //
@@ -497,6 +544,21 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
     // どちらでもない(スレのURLでない)場合
     else{
 
+        // 過去ログかどうか
+        const std::string pathboard = MISC::replace_str( m_path_board, "?", "\\?" );
+        const std::string query_kako = "^ *(http://.+)" + pathboard  + "/kako(/[1234567890]+)?/[1234567890]+/([1234567890]+).html *$";
+#ifdef _DEBUG
+        std::cout << "query_kako = " << query_kako << std::endl;
+#endif
+        if( regex.exec( query_kako , url ) ){
+
+            std::string url_tmp = regex.str( 1 ) + url_datpath() + regex.str( 3 ) + get_ext();
+#ifdef _DEBUG
+            std::cout << "kako log -> " << url_tmp << std::endl;
+#endif
+            return url_dat( url_tmp, num_from, num_to, num_str );
+        }
+
         // 外部板の移転の場合は path_board も変わるときがあるので
         // 移転した場合はurlを置換してからもう一度試す
         std::string old_root;
@@ -521,6 +583,7 @@ const std::string BoardBase::url_dat( const std::string& url, int& num_from, int
             return url_dat( url_tmp, num_from, num_to, num_str );
         }
 
+
 #ifdef _DEBUG
         std::cout << "not found\n";
 #endif
@@ -852,19 +915,27 @@ void BoardBase::download_subject( const std::string& url_update_view, const bool
     if( read_from_cache && m_list_subject_created ) return;
 
     clear();
-    m_rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
     m_read_url_boardbase = false;
 
     if( read_from_cache ) m_is_online = false;
     else m_is_online = SESSION::is_online();
 
+    m_is_booting = SESSION::is_booting();
+
     // オフライン
     if( ! m_is_online  ){
 
-        set_str_code( "" );
-
+        // まだスレ一覧を開いていないときはディスパッチャを通さないで直接subject.txtを読み込む
         if( read_from_cache ) receive_finish();
-        else finish(); // ディスパッチャ経由で receive_finish() を呼び出す
+
+        // 一度でもスレ一覧を開いている場合はディスパッチャ経由で receive_finish() を呼び出す
+        else{
+
+            // HTTP コードは Loadable::callback_dispatch() の中で HTTP_INIT にセットされる
+            set_str_code( "" );
+
+            finish();
+        }
 
         return;
     }
@@ -895,7 +966,7 @@ void BoardBase::create_loaderdata( JDLIB::LOADERDATA& data )
     data.host_proxy = get_proxy_host();
     data.port_proxy = get_proxy_port();
     data.basicauth_proxy = get_proxy_basicauth();
-    data.size_buf = CONFIG::get_loader_bufsize();
+    data.size_buf = CONFIG::get_loader_bufsize_board();
     data.timeout = CONFIG::get_loader_timeout();
     data.basicauth = get_basicauth();
     data.modified = get_date_modified();
@@ -907,8 +978,45 @@ void BoardBase::create_loaderdata( JDLIB::LOADERDATA& data )
 //
 void BoardBase::receive_data( const char* data, size_t size )
 {
+    if( ! size ) return;
+
+    if( ! m_rawdata ) m_rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
+
     memcpy( m_rawdata + m_lng_rawdata , data, size );
     m_lng_rawdata += size;
+    m_rawdata[ m_lng_rawdata ] = '\0';
+
+    if( m_read_url_boardbase ) return; // url_boardbase をロードして移転が起きたかチェック中
+
+
+    //
+    // 改行ごとに区切ってUTF8に文字コード変換して解析
+    //
+
+    if( ! m_rawdata_left ) m_rawdata_left = ( char* )malloc( SIZE_OF_RAWDATA );
+    if( ! m_iconv ) m_iconv = new JDLIB::Iconv( m_charset, "UTF-8" );
+
+    memcpy( m_rawdata_left + m_lng_rawdata_left, data, size );
+
+    size_t byte_in = size + m_lng_rawdata_left;
+    m_lng_rawdata_left = byte_in;
+    while( byte_in && m_rawdata_left[ byte_in -1 ] != '\n' ) --byte_in;
+    if( byte_in ){
+
+        int byte_out;
+        const char* rawdata_utf8 = m_iconv->convert( m_rawdata_left,  byte_in,  byte_out );
+
+        parse_subject( rawdata_utf8 );
+
+        // 残りを先頭に移動
+        m_lng_rawdata_left -= byte_in;
+        memmove( m_rawdata_left, m_rawdata_left + byte_in, m_lng_rawdata_left );
+
+#ifdef _DEBUG
+        std::cout << "BoardBase::receive_data lng_rawdata = " << m_lng_rawdata << " size = " << size
+                  << " byte_in = " << byte_in << " byte_out = " << byte_out << " lng_rawdata_left = " << m_lng_rawdata_left << std::endl;
+#endif
+    }
 }
 
 
@@ -925,25 +1033,26 @@ void BoardBase::receive_finish()
     m_status &= ~STATUS_UPDATED;
 
     bool read_from_cache = false;
-    std::string path_subject = CACHE::path_board_root_fast( url_boardbase() ) + m_subjecttxt;
-    std::string path_oldsubject = CACHE::path_board_root_fast( url_boardbase() ) + "old-" + m_subjecttxt;
+    const std::string path_subject = CACHE::path_board_root_fast( url_boardbase() ) + m_subjecttxt;
+    const std::string path_oldsubject = CACHE::path_board_root_fast( url_boardbase() ) + "old-" + m_subjecttxt;
 
 #ifdef _DEBUG
     std::cout << "----------------------------------\nBoardBase::receive_finish code = " << get_str_code() << std::endl;
-    std::cout << "size = " << m_lng_rawdata << std::endl;
+    std::cout << "lng_rawdata = " << m_lng_rawdata << std::endl;
 #endif
 
+    ///////////////////////////////////////////////////////
+    //
     // url_boardbase をロードして移転が起きたかチェック
     if( m_read_url_boardbase ){
 
 #ifdef _DEBUG
         std::cout << "move check\n";
 #endif
-        m_rawdata[ m_lng_rawdata ] = '\0';
         set_date_modified( std::string() );
         send_update_board();
 
-        if( get_code() == HTTP_OK && std::string( m_rawdata ).find( "window.location.href" ) != std::string::npos ){
+        if( m_lng_rawdata && get_code() == HTTP_OK && std::string( m_rawdata ).find( "window.location.href" ) != std::string::npos ){
 
 #ifdef _DEBUG
             std::cout << m_rawdata << std::endl;
@@ -989,14 +1098,16 @@ void BoardBase::receive_finish()
         clear();
         return;
     }
+    // 移転チェック終わり
+    // 
+    ///////////////////////////////////////////////////////
+
 
     // サーバーからtimeoutなどのエラーが返った or 移転
     if( get_code() != HTTP_ERR // HTTP_ERR はローダでの内部のエラー
         && get_code() != HTTP_OK
         && get_code() != HTTP_NOT_MODIFIED ){
 
-        m_lng_rawdata = 0;
-
         //
         // リダイレクト(302)の場合は移転確認
         //
@@ -1026,19 +1137,24 @@ void BoardBase::receive_finish()
     // キャッシュから読み込み
     if( read_from_cache ){
 
-        m_lng_rawdata = CACHE::load_rawdata( path_subject, m_rawdata, SIZE_OF_RAWDATA );
-
 #ifdef _DEBUG
         std::cout << "read from cache " << path_subject << std::endl;
 #endif
+        m_lng_rawdata = 0;
+        m_lng_rawdata_left = 0;
+
+        char* rawdata = ( char* )malloc( SIZE_OF_RAWDATA );
+        size_t lng = CACHE::load_rawdata( path_subject, rawdata, SIZE_OF_RAWDATA );
+        receive_data( rawdata, lng );
+        free( rawdata );
     }
 
 #ifdef _DEBUG
-        std::cout << "size(final) = " << m_lng_rawdata << std::endl;
+    std::cout << "size = " << m_list_artinfo.size() << " lng_rawdata = " << m_lng_rawdata << " left = " << m_lng_rawdata_left << std::endl;
 #endif
 
     // データが無い
-    if( m_lng_rawdata == 0 ){
+    if( ! m_list_artinfo.size() ){
 
         set_date_modified( std::string() );
 
@@ -1052,12 +1168,6 @@ void BoardBase::receive_finish()
         return;
     }
 
-    // UTF-8に変換しておく
-    JDLIB::Iconv* libiconv = new JDLIB::Iconv( m_charset, "UTF-8" );
-    int byte_out;
-    const char* rawdata_utf8 = libiconv->convert( m_rawdata , m_lng_rawdata,  byte_out );
-
-
     //////////////////////////////
     // データベース更新
     // subject.txtを解析して現行スレだけsubjectリスト(m_list_subject)に加える
@@ -1066,9 +1176,10 @@ void BoardBase::receive_finish()
     append_all_article_in_cache();
 
     // 一度全てのarticleをdat落ち状態にして subject.txt に
-    // 含まれているものだけ parse_subject()の中で通常状態にする
-    // オフラインの場合は状態を変えない
-    if( m_is_online ){
+    // 含まれているものだけ regist_article()の中で通常状態にする
+    if( m_is_online
+        || m_is_booting // ブート中の時も状態を変えないと起動直後にスレ一覧を復元した時にdat落ちしたスレが表示されない
+        ){  
 
         ArticleHashIterator it = m_hash_article->begin();
         for( ; it != m_hash_article->end(); ++it ){
@@ -1080,8 +1191,9 @@ void BoardBase::receive_finish()
         }
     }
 
-    // subject.txtをパースしながらデータベース更新
-    parse_subject( rawdata_utf8 );
+    m_is_booting = false;
+
+    regist_article( m_is_online );
 
     // list_subject 更新
     if( ! m_list_subject.empty() ){
@@ -1093,7 +1205,7 @@ void BoardBase::receive_finish()
         if( m_is_online ){
 
             // 既読スレに更新があったかチェック
-            std::list< ArticleBase* >::iterator it_art;
+            std::vector< ArticleBase* >::iterator it_art;
             for( it_art = m_list_subject.begin(); it_art != m_list_subject.end(); ++it_art ){
 
                 if( ( *it_art )->is_cached() && ( *it_art )->get_number() > ( *it_art )->get_number_load() ){
@@ -1107,8 +1219,6 @@ void BoardBase::receive_finish()
         }
 
         // DAT落ちなどでsubject.txtに無いスレもsubjectリストに加える
-        // サブジェクトやロード数などの情報が無いのでスレのinfoファイルから
-        // 取得する必要がある
         if( CONFIG::get_show_oldarticle() ){
 
             ArticleHashIterator it = m_hash_article->begin();
@@ -1118,23 +1228,15 @@ void BoardBase::receive_finish()
                     && ( ( *it )->get_status() & STATUS_OLD )
                     ){
 
-                    // info 読み込み
+
+                    // サブジェクトやロード数などの情報が無いのでスレのinfoファイルから
+                    // 取得する必要がある
                     // TODO : 数が多いとboardビューを開くまで時間がかかるのをなんとかする
 #ifdef _DEBUG
                     std::cout << "read article_info : " << ( *it )->get_url() << std::endl;
 #endif                
                     ( *it )->read_info();
 
-                    // ↑のread_info()で状態が変わる時があるのでDAT落ちに戻してからsubjectリスト(m_list_subject)に加える
-                    int status = ( *it )->get_status();
-
-                    if( status & STATUS_NORMAL ){
-                        status &= ~STATUS_NORMAL;
-                        status |= STATUS_OLD;
-                        ( *it )->set_status( status );
-                        ( *it )->save_info( true );
-                    }
-
                     if( ! is_abone_thread( *it ) ) m_list_subject.push_back( *it );
                 }
             }
@@ -1168,6 +1270,12 @@ void BoardBase::receive_finish()
 
                 // 古いファイルをrename
                 if( CACHE::file_exists( path_subject ) == CACHE::EXIST_FILE ){
+#ifdef _WIN32
+                    // not overwrite by rename() on windows
+                    if (CACHE::file_exists( path_oldsubject ) == CACHE::EXIST_FILE ){
+                        remove( path_oldsubject.c_str() );
+                    }
+#endif
                     if( rename( path_subject.c_str(), path_oldsubject.c_str() ) != 0 ){
                         MISC::ERRMSG( "rename failed " + path_subject );
                     }
@@ -1195,7 +1303,6 @@ void BoardBase::receive_finish()
     // コアにデータベース更新を知らせる
     send_update_board();
 
-    delete libiconv;
     clear();
 }
 
@@ -1215,6 +1322,8 @@ bool BoardBase::start_checkking_if_board_moved()
     std::cout << "BoardBase::start_checkking_if_board_moved " << url_boardbase() << std::endl;
 #endif
 
+    m_lng_rawdata = 0;
+
     JDLIB::LOADERDATA data;
     data.init_for_data();
     data.url = url_boardbase();
@@ -1269,7 +1378,7 @@ void BoardBase::append_all_article_in_cache()
     const std::string datbase = url_datbase();
 
 #ifdef _DEBUG
-    std::cout << "BoardBase::append_all_article_in_cache\n";
+    std::cout << "BoardBase::append_all_article_in_cache url = " << datbase << std::endl;
 #endif
     
     std::list< std::string >list_file = get_filelist_in_cache();
@@ -1387,6 +1496,8 @@ const bool BoardBase::is_abone_thread( ArticleBase* article )
 //
 void BoardBase::remove_old_abone_thread()
 {
+    if( m_cancel_remove_abone_thread ) return;
+    if( CONFIG::get_remove_old_abone_thread() == 2 ) return;
     if( m_list_abone_thread.empty() ) return;
     if( m_list_abone_thread.size() == m_list_abone_thread_remove.size() ) return;
 
@@ -1399,10 +1510,30 @@ void BoardBase::remove_old_abone_thread()
     for( ; it2 != m_list_abone_thread_remove.end(); ++it2 ) std::cout << ( *it2 ) << std::endl;
 #endif
 
-    SKELETON::MsgDiag mdiag( NULL, "NGスレタイトルに登録したスレがdat落ちしました。\n\nNGスレタイトルから除外しますか？",
-                             false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-    mdiag.set_default_response( Gtk::RESPONSE_YES );
-    if( mdiag.run() == Gtk::RESPONSE_YES ) m_list_abone_thread = m_list_abone_thread_remove;
+    if( CONFIG::get_remove_old_abone_thread() == 1 ){
+        m_list_abone_thread = m_list_abone_thread_remove;
+        return;
+    }
+
+    SKELETON::MsgCheckDiag mdiag( NULL,
+                             "NGスレタイトルに登録したスレがdat落ちしました。\n\nNGスレタイトルから除外しますか？\n後で板のプロパティから削除する事も可能です。",
+                             "今後表示しない(_D)",
+                                  Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
+
+    mdiag.add_default_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
+    mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+
+    const int ret = mdiag.run();
+    if( ret == Gtk::RESPONSE_YES ) m_list_abone_thread = m_list_abone_thread_remove;
+
+    // 一度いいえを選択したらあとは再起動するまでダイアログを表示しない
+    else m_cancel_remove_abone_thread = true; 
+
+    if( mdiag.get_chkbutton().get_active() ){
+
+        if( ret == Gtk::RESPONSE_YES ) CONFIG::set_remove_old_abone_thread( 1 );
+        else CONFIG::set_remove_old_abone_thread( 2 );
+    }
 }
 
 
@@ -1411,7 +1542,9 @@ void BoardBase::remove_old_abone_thread()
 //
 // CONFIG::set_abone_number_thread() などでグローバル設定をした後などに呼び出す
 //
-void BoardBase::update_abone_thread()
+// redraw : スレ一覧の表示更新を行う
+//
+void BoardBase::update_abone_thread( const bool redraw )
 {
 #ifdef _DEBUG
     std::cout << "BoardBase::update_abone_thread\n";
@@ -1424,7 +1557,7 @@ void BoardBase::update_abone_thread()
     const bool online = SESSION::is_online();
     SESSION::set_online( false );
 
-    download_subject( url_subject(), false );
+    download_subject( ( redraw ? url_subject() : std::string() ), false );
 
     SESSION::set_online( online );
 }
@@ -1498,13 +1631,17 @@ void BoardBase::add_abone_word_board( const std::string& word )
 
 
 //
-// スレあぼーん状態のリセット(情報セットとスレ一覧の表示更新を同時におこなう)
+// スレあぼーん状態のリセット
+//
+// redraw : スレ一覧の表示更新を行う
 //
 void BoardBase::reset_abone_thread( const std::list< std::string >& threads,
                                     const std::list< std::string >& words,
                                     const std::list< std::string >& regexs,
                                     const int number,
-                                    const int hour )
+                                    const int hour,
+                                    const bool redraw
+    )
 {
     if( empty() ) return;
 
@@ -1526,7 +1663,7 @@ void BoardBase::reset_abone_thread( const std::list< std::string >& threads,
     m_abone_number_thread = number;
     m_abone_hour_thread = hour;
 
-    update_abone_thread();
+    update_abone_thread( redraw );
 }
 
 
@@ -1571,37 +1708,51 @@ void BoardBase::set_local_proxy_w( const std::string& proxy )
 //
 // キャッシュ内のログ検索
 //
-// datファイルのURL(read.cgi型)を返す
+// ArticleBase のアドレスをリスト(list_article)にセットして返す
+// query が空の時はキャッシュにあるログを全てヒットさせる
+// 
 //
-std::list< std::string > BoardBase::search_cache( const std::string& query,
-                                                  bool mode_or, // 今のところ無視
-                                                  bool& stop // 呼出元のスレッドで true にセットすると検索を停止する
+void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
+                              const std::string& query,
+                              const bool mode_or, // 今のところ無視
+                              const bool& stop // 呼出元のスレッドで true にセットすると検索を停止する
     )
 {
 #ifdef _DEBUG
     std::cout << "BoardBase::search_cache " << query << std::endl;
 #endif
 
-    std::list< std::string >list_out;
-
-    if( empty() ) return list_out;
+    if( empty() ) return;
 
     // キャッシュにあるレスをデータベースに登録
     append_all_article_in_cache();
-    if( m_hash_article->size() == 0 ) return list_out;
+    if( m_hash_article->size() == 0 ) return;
 
-    std::string query_local = MISC::Iconv( query, "UTF-8", get_charset() );
-    std::list< std::string > list_query = MISC::split_line( query_local );
+    const bool append_all = query.empty();
+    const std::string query_local = MISC::Iconv( query, "UTF-8", get_charset() );
+    const std::list< std::string > list_query = MISC::split_line( query_local );
 
-    std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
+    const std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
 
     ArticleHashIterator it = m_hash_article->begin();
     for( ; it != m_hash_article->end(); ++it ){
 
+        if( stop ) break;
+
         ArticleBase* article = ( *it );
         if( ! article->is_cached() ) continue;
 
-        std::string path = path_board_root + article->get_id();
+        if( append_all ){
+
+#ifdef _DEBUG
+            std::cout << "append " << article->get_subject() << std::endl;
+#endif
+            article->read_info();
+            list_article.push_back( article );
+            continue;
+        }
+
+        const std::string path = path_board_root + article->get_id();
         std::string rawdata;
 
         if( CACHE::load_rawdata( path, rawdata ) > 0 ){
@@ -1612,7 +1763,7 @@ std::list< std::string > BoardBase::search_cache( const std::string& query,
             std::cout << "load " << path << " size = " << rawdata.size() << " byte" << std::endl;
 #endif
 
-            std::list< std::string >::iterator it_query = list_query.begin();
+            std::list< std::string >::const_iterator it_query = list_query.begin();
             for( ; it_query != list_query.end(); ++it_query ){
 
                 if( rawdata.find( *it_query ) == std::string::npos ){
@@ -1626,15 +1777,11 @@ std::list< std::string > BoardBase::search_cache( const std::string& query,
                 std::cout << "found word in " << url_readcgi( article->get_url(), 0, 0 ) << std::endl
                           << article->get_subject() << std::endl;
 #endif
-                std::string readcgi = url_readcgi( article->get_url(), 0, 0 );
-                list_out.push_back( readcgi );
+                article->read_info();
+                list_article.push_back( article );
             }
         }
-
-        if( stop ) break;
     }
-
-    return list_out;
 }
 
 
@@ -1700,81 +1847,84 @@ void BoardBase::read_board_info()
 
     JDLIB::ConfLoader cf( path_info, std::string() );
 
-    std::string modified = cf.get_option( "modified", "" );
+    std::string modified = cf.get_option_str( "modified", "" );
     set_date_modified( modified );
 
-    m_modified_localrule = cf.get_option( "modified_localrule", "" );
-    m_modified_setting = cf.get_option( "modified_setting", "" );
+    m_modified_localrule = cf.get_option_str( "modified_localrule", std::string() );
+    m_modified_setting = cf.get_option_str( "modified_setting", std::string() );
 
-    m_view_sort_column = cf.get_option( "view_sort_column", -1 );
-    m_view_sort_mode = cf.get_option( "view_sort_mode", 0 );
-    m_view_sort_pre_column = cf.get_option( "view_sort_pre_column", -1 );
-    m_view_sort_pre_mode = cf.get_option( "view_sort_pre_mode", 0 );
+    m_view_sort_column = cf.get_option_int( "view_sort_column", -1, -1, COL_VISIBLE_END-1 );
+    m_view_sort_mode = cf.get_option_int( "view_sort_mode", SORTMODE_ASCEND, 0, SORTMODE_NUM -1 );
+    m_view_sort_pre_column = cf.get_option_int( "view_sort_pre_column", -1, -1, COL_VISIBLE_END-1 );
+    m_view_sort_pre_mode = cf.get_option_int( "view_sort_pre_mode", SORTMODE_ASCEND, 0, SORTMODE_NUM -1 );
 
-    m_check_noname = cf.get_option( "check_noname", false );
+    m_check_noname = cf.get_option_bool( "check_noname", false );
 
     std::string str_tmp;
 
     // あぼーん id は再起動ごとにリセット
-//    str_tmp = cf.get_option( "aboneid", "" );
+//    str_tmp = cf.get_option( "aboneid", std::string() );
 //    if( ! str_tmp.empty() ) m_list_abone_id = MISC::strtolist( str_tmp );
 
     // あぼーん name
-    str_tmp = cf.get_option( "abonename", "" );
+    str_tmp = cf.get_option_str( "abonename", "" );
     if( ! str_tmp.empty() ) m_list_abone_name = MISC::strtolist( str_tmp );
 
     // あぼーん word
-    str_tmp = cf.get_option( "aboneword", "" );
+    str_tmp = cf.get_option_str( "aboneword", "" );
     if( ! str_tmp.empty() ) m_list_abone_word = MISC::strtolist( str_tmp );
 
     // あぼーん regex
-    str_tmp = cf.get_option( "aboneregex", "" );
+    str_tmp = cf.get_option_str( "aboneregex", "" );
     if( ! str_tmp.empty() ) m_list_abone_regex = MISC::strtolist( str_tmp );
 
     // スレ あぼーん
-    str_tmp = cf.get_option( "abonethread", "" );
+    str_tmp = cf.get_option_str( "abonethread", "" );
     if( ! str_tmp.empty() ) m_list_abone_thread = MISC::strtolist( str_tmp );
 
     // スレ あぼーん word
-    str_tmp = cf.get_option( "abonewordthread", "" );
+    str_tmp = cf.get_option_str( "abonewordthread", "" );
     if( ! str_tmp.empty() ) m_list_abone_word_thread = MISC::strtolist( str_tmp );
 
     // スレ あぼーん regex
-    str_tmp = cf.get_option( "aboneregexthread", "" );
+    str_tmp = cf.get_option_str( "aboneregexthread", "" );
     if( ! str_tmp.empty() ) m_list_abone_regex_thread = MISC::strtolist( str_tmp );
 
     // レス数であぼーん
-    m_abone_number_thread = cf.get_option( "abonenumberthread", 0 );
+    m_abone_number_thread = cf.get_option_int( "abonenumberthread", 0, 0, 9999 );
 
     // スレ立てからの経過時間であぼーん
-    m_abone_hour_thread = cf.get_option( "abonehourthread", 0 );
+    m_abone_hour_thread = cf.get_option_int( "abonehourthread", 0, 0, 9999 );
 
     // ローカルプロキシ
-    m_mode_local_proxy = cf.get_option( "mode_local_proxy", 0 );
-    str_tmp = cf.get_option( "local_proxy", "" );
+    m_mode_local_proxy = cf.get_option_int( "mode_local_proxy", PROXY_GLOBAL, 0, PROXY_NUM -1 );
+    str_tmp = cf.get_option_str( "local_proxy", "" );
     set_local_proxy( str_tmp );
-    m_local_proxy_port = cf.get_option( "local_proxy_port", 8080 );
+    m_local_proxy_port = cf.get_option_int( "local_proxy_port", 8080, 1, 65535 );
  
-    m_mode_local_proxy_w = cf.get_option( "mode_local_proxy_w", 0 );
-    str_tmp = cf.get_option( "local_proxy_w", "" );
+    m_mode_local_proxy_w = cf.get_option_int( "mode_local_proxy_w", PROXY_GLOBAL, 0, PROXY_NUM -1 );
+    str_tmp = cf.get_option_str( "local_proxy_w", "" );
     set_local_proxy_w( str_tmp );
-    m_local_proxy_port_w = cf.get_option( "local_proxy_port_w", 8080 );
+    m_local_proxy_port_w = cf.get_option_int( "local_proxy_port_w", 8080, 1, 65535 );
 
     // 書き込み時のデフォルトの名前とメアド
-    m_write_name = cf.get_option( "write_name", "" );
-    m_write_mail = cf.get_option( "write_mail", "" );
+    m_write_name = cf.get_option_str( "write_name", "" );
+    m_write_mail = cf.get_option_str( "write_mail", "" );
 
     // samba24
-    m_samba_sec = cf.get_option( "samba_sec", 0 );
+    m_samba_sec = cf.get_option_int( "samba_sec", 0, 0, 65535 );
 
     // 実況の秒数
-    m_live_sec = cf.get_option( "live_sec", 0 );
+    m_live_sec = cf.get_option_int( "live_sec", 0, 0, 65535 );
 
     // 最終アクセス時刻
-    m_last_access_time = cf.get_option( "last_access_time", 0 );
+    m_last_access_time = cf.get_option_int( "last_access_time", 0, 0, 2147483647 );
 
     // ステータス
-    m_status = cf.get_option( "status", STATUS_UNKNOWN );
+    m_status = cf.get_option_int( "status", STATUS_UNKNOWN, 0, 8192 );
+
+    // 最大レス数
+    m_number_max_res = cf.get_option_int( "max_res", get_default_number_max_res(), 0, MAX_RESNUMBER );
 
 #ifdef _DEBUG
     std::cout << "modified = " << get_date_modified() << std::endl;
@@ -1862,7 +2012,8 @@ void BoardBase::save_jdboard_info()
          << "samba_sec = " << m_samba_sec << std::endl
          << "live_sec = " << m_live_sec << std::endl
          << "last_access_time = " << m_last_access_time << std::endl
-         << "status = " << m_status
+         << "status = " << m_status << std::endl
+         << "max_res = " << m_number_max_res << std::endl
     ;
 
     CACHE::save_rawdata( path_info, sstr.str() );
@@ -1887,7 +2038,7 @@ void BoardBase::save_summary()
     std::ostringstream sstr_out;
     sstr_out << "(";
 
-    std::list< ArticleBase* >::iterator it;
+    std::vector< ArticleBase* >::iterator it;
     for( it = m_list_subject.begin(); it != m_list_subject.end(); ++it ){
 
         ArticleBase* art = *( it );
@@ -1987,8 +2138,8 @@ void BoardBase::show_updateicon( const bool update )
             // スレ一覧のタブのアイコン表示を更新
             CORE::core_set_command( "toggle_board_icon", url_subject() );
 
-            // お気に入りのアイコン表示を更新
-            CORE::core_set_command( "toggle_favorite_boardicon", url_datbase() );
+            // サイドバーのアイコン表示を更新
+            CORE::core_set_command( "toggle_sidebar_boardicon", url_datbase() );
 
             save_info();
         }
@@ -2003,9 +2154,9 @@ void BoardBase::show_updateicon( const bool update )
 
             m_status &= ~STATUS_UPDATE;
 
-            // お気に入りのアイコン表示を戻す
+            // サイドバーのアイコン表示を戻す
             // スレ一覧のタブのアイコンはBoardViewがロード終了時に自動的に戻す
-            CORE::core_set_command( "toggle_favorite_boardicon", url_subject() );
+            CORE::core_set_command( "toggle_sidebar_boardicon", url_subject() );
 
             save_info();
         }
