@@ -10,10 +10,17 @@
 
 #include <string>
 #include <list>
+#include <vector>
+#include <ctime>
+
+#ifdef _WIN32
+#include <sys/time.h>
+#endif
 
 namespace JDLIB
 {
     class LOADERDATA;
+    class Iconv;
 }
 
 
@@ -22,23 +29,42 @@ namespace DBTREE
     // ローカルプロキシ設定
     enum
     {
-        PROXY_GLOBAL,  // 全体設定使用
+        PROXY_GLOBAL = 0,  // 全体設定使用
         PROXY_DISABLE, // 全体設定無効
-        PROXY_LOCAL    // ローカル設定使用
+        PROXY_LOCAL,     // ローカル設定使用
+
+        PROXY_NUM
     };
 
+    struct ARTICLE_INFO
+    {
+        std::string id;
+        std::string subject;
+        int number;
+    };
+
+    typedef std::vector< ARTICLE_INFO > ARTICLE_INFO_LIST;
+
     class Root;
     class ArticleBase;
+    class ArticleHash;
 
     class BoardBase : public SKELETON::Loadable
     {
         // ArticleBaseクラス のキャッシュ
         // ArticleBaseクラスは一度作ったら~BoardBase()以外ではdeleteしないこと
-        std::list< ArticleBase* > m_list_article;
+        ArticleHash* m_hash_article;
 
         // subject.txt から作ったArticleBaseクラスのポインタのリスト
         // subject.txt と同じ順番で、ロードされるたびに更新される
-        std::list< ArticleBase* > m_list_subject; 
+        std::vector< ArticleBase* > m_list_subject; 
+
+        // ダウンロード中に parse_subject() でsubject.txtを解析して結果を入れておく
+        // ダウンロード終了後に regist_article() でスレを登録する
+        ARTICLE_INFO_LIST m_list_artinfo; 
+
+        // 状態 ( global.h で定義 )
+        int m_status;                
 
         // 一度でも m_list_subject が作られた(=subject.txtを開いた)らtrue
         bool m_list_subject_created;
@@ -52,6 +78,9 @@ namespace DBTREE
         // subjectダウンロード指示時(BoardBase::download_subject)にオンラインだったか
         bool m_is_online;
 
+        // subjectダウンロード指示時(BoardBase::download_subject)にブート中だったか
+        bool m_is_booting;
+
         // ビュワーでソートをする列番号、ソード順
         int m_view_sort_column;
         int m_view_sort_mode;
@@ -99,6 +128,7 @@ namespace DBTREE
 
         // ローカルスレあぼーん情報
         std::list< std::string > m_list_abone_thread; // あぼーんするスレのタイトル
+        std::list< std::string > m_list_abone_thread_remove; // あぼーんするスレのタイトル( dat 落ち判定用、remove_old_abone_thread()を参照せよ )
         std::list< std::string > m_list_abone_word_thread; // あぼーんする文字列
         std::list< std::string > m_list_abone_regex_thread; // あぼーんする正規表現
         int m_abone_number_thread; // レスの数
@@ -137,8 +167,11 @@ namespace DBTREE
 
         // ダウンロード用変数
         std::list< std::string > m_url_update_views; // CORE::core_set_command( "update_board" ) を送信するビューのアドレス
+        JDLIB::Iconv* m_iconv;
         char* m_rawdata;
-        int m_lng_rawdata;
+        char* m_rawdata_left;
+        size_t m_lng_rawdata;
+        size_t m_lng_rawdata_left;
 
         // 情報ファイルを読みこんだらtrueにして2度読みしないようにする
         bool m_read_info;
@@ -163,14 +196,22 @@ namespace DBTREE
         std::string m_get_article_url;
         ArticleBase* m_get_article;
 
+        // remove_old_abone_thread() をキャンセルするか
+        bool m_cancel_remove_abone_thread;
+
         // NULL artice クラス
         ArticleBase* m_article_null;
 
       protected:
 
-        std::list< ArticleBase* >& get_list_article(){ return m_list_article; }
+        ARTICLE_INFO_LIST& get_list_artinfo(){ return m_list_artinfo; }
+
+        ArticleHash* get_hash_article(){ return m_hash_article; }
+        std::list< std::string >& get_url_update_views(){ return  m_url_update_views; }
 
         ArticleBase* get_article_null();
+        ArticleBase* get_article( const std::string& datbase, const std::string& id );
+        ArticleBase* get_article_create( const std::string& datbase, const std::string& id );
 
         void set_path_dat( const std::string& str ){ m_path_dat = str; }
         void set_path_readcgi( const std::string& str ){ m_path_readcgi = str; }
@@ -184,14 +225,20 @@ namespace DBTREE
         // articleがスレあぼーんされているか
         const bool is_abone_thread( ArticleBase* article );
 
+        // m_url_update_views に登録されている view に update_board コマンドを送る
+        void send_update_board();
+
       public:
 
         BoardBase( const std::string& root, const std::string& path_board, const std::string& name );
         virtual ~BoardBase();
         bool empty();
 
+        // 状態 ( global.hで定義 )
+        const int get_status() const{ return m_status; }
+
         // boardviewに表示するスレッドのリストを取得
-        std::list< ArticleBase* >& get_list_subject(){ return m_list_subject; }
+        std::vector< ArticleBase* >& get_list_subject(){ return m_list_subject; }
 
         // ローカルルールの modified 時刻
         const std::string& get_modified_localrule() const { return m_modified_localrule; }
@@ -273,6 +320,9 @@ namespace DBTREE
         // 確認画面のhtmlから解析する      
         virtual void analyze_keyword_for_write( const std::string& html ){}
 
+        // 書き込み時のリファラ
+        virtual const std::string get_write_referer(){ return url_boardbase(); }
+
         // basic認証
         const std::string& get_basicauth() const { return m_basicauth; }
         void set_basicauth( const std::string& basicauth ){ m_basicauth = basicauth; }
@@ -289,7 +339,7 @@ namespace DBTREE
         // num_from と num_to が 0 で無い時はスレ番号を付ける
         // (例) "http://www.hoge2ch.net/hogeboard/dat/12345.dat",  num_from = 12, num_to = 15 のとき
         // "http://www.hoge2ch.net/test/read.cgi/hogeboard/12345/12-15"
-        const std::string url_readcgi( const std::string& url, int num_from, int num_to );
+        virtual const std::string url_readcgi( const std::string& url, int num_from, int num_to );
 
         // subject.txt の URLを取得
         // (例) "http://www.hoge2ch.net/hogeboard/subject.txt"
@@ -320,20 +370,20 @@ namespace DBTREE
         const std::string url_readcgipath();
 
         // bbscgi のURLのベースアドレス
+        // (例) "http://www.hoge2ch.net/test/bbs.cgi/" ( 最後に '/' がつく )
         const std::string url_bbscgibase();
         
         // subbbscgi のURLのベースアドレス
+        // (例) "http://www.hoge2ch.net/test/subbbs.cgi/"  ( 最後に '/' がつく )
         const std::string url_subbbscgibase();
 
         // article クラスのポインタ取得
-        // それぞれの違いはソースのコメントを参照
-        ArticleBase* get_article( const std::string& id );
-        ArticleBase* get_article_create( const std::string& id );
         ArticleBase* get_article_fromURL( const std::string& url );
 
         // subject.txt ダウンロード
         // url_update_view : CORE::core_set_command( "update_board" ) を送信するビューのアドレス
-        void download_subject( const std::string& url_update_view );
+        // read_from_cache : まだスレ一覧を開いていないときにキャッシュのsubject.txtを読み込む
+        virtual void download_subject( const std::string& url_update_view, const bool read_from_cache );
 
         // 新スレ作成用のメッセージ変換
         virtual const std::string create_newarticle_message( const std::string& subject,
@@ -348,37 +398,51 @@ namespace DBTREE
         // 新スレ作成用のsubbbscgi のURL
         virtual const std::string url_subbbscgi_new() { return std::string(); }
 
-
         // 配下の全articlebaseクラスのあぼーん状態の更新
         void update_abone_all_article();
 
-        // あぼーん情報
-        std::list< std::string > get_abone_list_id(){ return m_list_abone_id; }
-        std::list< std::string > get_abone_list_name(){ return m_list_abone_name; }
-        std::list< std::string > get_abone_list_word(){ return m_list_abone_word; }
-        std::list< std::string > get_abone_list_regex(){ return m_list_abone_regex; }
+        // 板レベルでのあぼーん情報
+        const std::list< std::string >& get_abone_list_id_board(){ return m_list_abone_id; }
+        const std::list< std::string >& get_abone_list_name_board(){ return m_list_abone_name; }
+        const std::list< std::string >& get_abone_list_word_board(){ return m_list_abone_word; }
+        const std::list< std::string >& get_abone_list_regex_board(){ return m_list_abone_regex; }
 
-        // あぼーん状態のリセット(情報セットと状態更新を同時におこなう)
-        void reset_abone( std::list< std::string >& ids, std::list< std::string >& names, std::list< std::string >& words, std::list< std::string >& regexs );
+        // 板レベルでのあぼーん状態のリセット(情報セットとスレビューの表示更新を同時におこなう)
+        void reset_abone_board( const std::list< std::string >& ids,
+                                const std::list< std::string >& names,
+                                const std::list< std::string >& words,
+                                const std::list< std::string >& regexs );
 
-        // あぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう)
-        void add_abone_id( const std::string& id );
-        void add_abone_name( const std::string& name );
-        void add_abone_word( const std::string& word );
+        // 板レベルでのあぼ〜ん状態更新(reset_abone()と違って各項目ごと個別におこなう。スレビューの表示更新も同時におこなう)
+        void add_abone_id_board( const std::string& id );
+        void add_abone_name_board( const std::string& name );
+        void add_abone_word_board( const std::string& word );
 
         // スレあぼーん情報
-        std::list< std::string > get_abone_list_thread(){ return m_list_abone_thread; }
-        std::list< std::string > get_abone_list_word_thread(){ return m_list_abone_word_thread; }
-        std::list< std::string > get_abone_list_regex_thread(){ return m_list_abone_regex_thread; }
+        const std::list< std::string >& get_abone_list_thread(){ return m_list_abone_thread; }
+        const std::list< std::string >& get_abone_list_thread_remove(){ return m_list_abone_thread_remove; }
+        const std::list< std::string >& get_abone_list_word_thread(){ return m_list_abone_word_thread; }
+        const std::list< std::string >& get_abone_list_regex_thread(){ return m_list_abone_regex_thread; }
         const int get_abone_number_thread(){ return m_abone_number_thread; }
         const int get_abone_hour_thread(){ return m_abone_hour_thread; }
 
-        // スレあぼーん状態の更新
-        void update_abone_thread();
+        // subject.txtのロード後にdat落ちしたスレッドをスレあぼーんのリストから取り除く
+        void remove_old_abone_thread();
 
-        // スレあぼーん状態のリセット(情報セットと状態更新を同時におこなう)
-        void reset_abone_thread( std::list< std::string >& threads, std::list< std::string >& words, std::list< std::string >& regexs,
-                                 const int number, const int hour );
+        // スレあぼーん情報を更新した時に対応するスレ一覧の表示を更新する
+        // CONFIG::set_abone_number_thread() などでグローバル設定をした後などに呼び出す
+        // redraw : スレ一覧の表示更新を行う
+        void update_abone_thread( const bool redraw );
+
+        // スレあぼーん状態のリセット(情報セットとスレ一覧の表示更新を同時におこなう)
+        // redraw : スレ一覧の表示更新を行う
+        void reset_abone_thread( const std::list< std::string >& threads,
+                                 const std::list< std::string >& words,
+                                 const std::list< std::string >& regexs,
+                                 const int number,
+                                 const int hour,
+                                 const bool redraw
+            );
 
         // ローカルプロキシ設定
         const int get_mode_local_proxy() const { return m_mode_local_proxy; }
@@ -426,26 +490,44 @@ namespace DBTREE
 
         // 最大レス数
         const int get_number_max_res() const{ return m_number_max_res; }
-        void set_number_max_res( const int number ){ m_number_max_res = number; }
+        void set_number_max_res( const int number );
 
         // 板情報の取得
-        void read_info();
+        virtual void read_info();
 
         // 情報保存
-        void save_info();
+        virtual void save_info();
         
         // キャッシュ内のログ検索
-        std::list< std::string > search_cache( const std::string& query, bool mode_or, bool& stop );
+        // ArticleBase のアドレスをリスト(list_article)にセットして返す
+        // query が空の時はキャッシュにあるログを全てヒットさせる
+        virtual void search_cache( std::vector< ArticleBase* >& list_article,
+                                   const std::string& query,
+                                   const bool mode_or, // 今のところ無視
+                                   const bool& stop // 呼出元のスレッドで true にセットすると検索を停止する
+            );
+
+        // datファイルのインポート
+        // 成功したらdat型のurlを返す
+        virtual const std::string import_dat( const std::string& filename );
+
+        // 更新可能状態にしてお気に入りやスレ一覧のタブのアイコンに更新マークを表示
+        // update == true の時に表示。falseなら戻す
+        void show_updateicon( const bool update );
+
+        // 板の更新チェック時に、更新チェックを行うスレのアドレスのリスト
+        // キャッシュが存在し、かつdat落ちしていないで新着数が0のスレを速度の順でソートして返す
+        const std::list< std::string > get_check_update_articles();
 
       private:
 
         void clear();
 
-        // m_url_update_views に登録されている view に update_board コマンドを送る
-        void send_update_board();
+        // デフォルト最大レス数( 0 : 未設定 )
+        virtual const int get_default_number_max_res(){ return 0; }
 
         // キャッシュのファイル名が正しいかどうか
-        virtual bool is_valid( const std::string& filename ){ return false; }
+        virtual const bool is_valid( const std::string& filename ){ return false; }
 
         virtual void create_loaderdata( JDLIB::LOADERDATA& data );
         virtual void receive_data( const char* data, size_t size );
@@ -454,13 +536,14 @@ namespace DBTREE
         // url_boardbase をロードして移転したかどうか解析開始
         bool start_checkking_if_board_moved();
 
-        virtual ArticleBase* append_article( const std::string& id, bool cached );
+        virtual ArticleBase* append_article( const std::string& datbase, const std::string& id, const bool cached );
         virtual void parse_subject( const char* str_subject_txt ){}
+        virtual void regist_article( const bool is_online ){}
 
         std::list< std::string > get_filelist_in_cache();
 
         void read_board_info();
-        void append_all_article_in_cache();
+        virtual void append_all_article_in_cache();
 
         void save_summary();
         void save_board_info();
