@@ -19,11 +19,6 @@
 
 using namespace DBTREE;
 
-enum
-{
-    DEFAULT_NUMBER_MAX_MACHI = 1000 // 規定の最大レス数
-};
-
 
 BoardMachi::BoardMachi( const std::string& root, const std::string& path_board, const std::string& name )
     : BoardBase( root, path_board, name )
@@ -37,8 +32,6 @@ BoardMachi::BoardMachi( const std::string& root, const std::string& path_board,
     set_ext( "" );
     set_id( path_board.substr( 1 ) ); // 先頭の '/' を除く  
     set_charset( "MS932" );
-
-    set_number_max_res( DEFAULT_NUMBER_MAX_MACHI );
 }
 
 
@@ -62,11 +55,11 @@ bool  BoardMachi::equal( const std::string& url )
 //
 // キャッシュのファイル名が正しいか
 //
-bool BoardMachi::is_valid( const std::string& filename )
+const bool BoardMachi::is_valid( const std::string& filename )
 {
     if( filename.length() != 10 ) return false;
 
-    unsigned int dig, n;
+    size_t dig, n;
     MISC::str_to_uint( filename.c_str(), dig, n );
     if( dig != n ) return false;
     if( dig != 10 ) return false;
@@ -212,14 +205,11 @@ const std::string BoardMachi::url_subbbscgi_new()
 void BoardMachi::parse_subject( const char* str_subject_txt )
 {
 #ifdef _DEBUG
-    std::cout << "BoardMachi::parse_subject\n";
+    std::cout << "BoardMachi::parse_subject is_online = " << is_online << std::endl;
 #endif 
    
     const char* pos = str_subject_txt;
     char str_tmp[ 1024 ];
-    const std::string datbase = url_datbase();
-
-    ArticleBase* article_first = NULL;
 
     while( *pos != '\0' ){
         
@@ -265,38 +255,71 @@ void BoardMachi::parse_subject( const char* str_subject_txt )
         ++pos;
 
         // id, subject, number 取得
+        ARTICLE_INFO artinfo;
+
         memcpy( str_tmp, str_id_dat, lng_id_dat );
         str_tmp[ lng_id_dat ] = '\0';
-        std::string id = MISC::remove_space( str_tmp );
+        artinfo.id = MISC::remove_space( str_tmp );
 
         memcpy( str_tmp, str_subject, lng_subject );
         str_tmp[ lng_subject ] = '\0';
-        std::string subject = MISC::remove_space( str_tmp );
-        subject = MISC::replace_str( subject, "&lt;", "<" );
-        subject = MISC::replace_str( subject, "&gt;", ">" );
+        artinfo.subject = MISC::remove_space( str_tmp );
+        artinfo.subject = MISC::replace_str( artinfo.subject, "&lt;", "<" );
+        artinfo.subject = MISC::replace_str( artinfo.subject, "&gt;", ">" );
         
-        int number = atol( str_num );
+        artinfo.number = atol( str_num );
+
+        get_list_artinfo().push_back( artinfo );        
 
 #ifdef _DEBUG
-//        std::cout << id << " " << number << " " << subject << std::endl;
+        std::cout << "pos = " << ( pos - str_subject_txt ) << " lng = " << lng_subject << " id = " << artinfo.id << " num = " << artinfo.number;
+        std::cout << " : " << artinfo.subject << std::endl;
 #endif
+    }
+}
+
+
+void BoardMachi::regist_article( const bool is_online )
+{
+    if( ! get_list_artinfo().size() ) return;
+
+#ifdef _DEBUG
+    std::cout << "BoardMachii::regist_article size = " << get_list_artinfo().size() << std::endl;
+#endif 
+
+    ArticleBase* article_first = NULL;
+
+    const std::string datbase = url_datbase();
+
+    for( unsigned int i = 0; i < get_list_artinfo().size(); ++i ){
+
+        const ARTICLE_INFO& artinfo = get_list_artinfo()[ i ];
 
         // DBに登録されてるならarticle クラスの情報更新
-        ArticleBase* article = get_article( datbase, id );
+        ArticleBase* article = get_article( datbase, artinfo.id );
 
         // DBにないなら新規に article クラスを追加
         //
         // なお BoardBase::receive_finish() のなかで append_all_article_in_cache() が既に呼び出されているため
         // DBに無いということはキャッシュにも無いということ。よって append_article()で  cached = false
 
-        if( article->empty() ) article = append_article( datbase, id, false );
+        if( article->empty() ) article = append_article( datbase, artinfo.id, false );
 
         // スレ情報更新
         if( article ){
 
+            // ステータスをDAT落ち状態から通常状態に変更
+            int status = article->get_status();
+            status |= STATUS_NORMAL;
+            status &= ~STATUS_OLD;
+            article->set_status( status );
+
+            // 情報ファイル読み込み
             article->read_info();
-            article->set_subject( subject );
-            article->set_number( number );
+
+            // 情報ファイルが無い場合もあるのでsubject.txtから取得したサブジェクト、レス数を指定しておく
+            article->set_subject( artinfo.subject );
+            article->set_number( artinfo.number, is_online );
 
             // boardビューに表示するリスト更新
             // Machiは最初と最後の行が同じになる仕様があるので最後の行を除く
@@ -306,8 +329,9 @@ void BoardMachi::parse_subject( const char* str_subject_txt )
 
             if( pushback ){
 
+                // 情報ファイル読み込み後にステータスが変わることがあるので、もう一度
                 // ステータスをDAT落ち状態から通常状態に変更
-                int status = article->get_status();
+                status = article->get_status();
                 status |= STATUS_NORMAL;
                 status &= ~STATUS_OLD;
                 article->set_status( status );
