@@ -184,8 +184,8 @@ namespace DBTREE
         // URL を含むレス番号をリストにして取得
         std::list< int > get_res_with_url();
 
-        // number番のレスを参照しているレス番号をリストにして取得
-        std::list< int > get_res_reference( int number );
+        // res_num に含まれるレスを参照しているレス番号をリストにして取得
+        std::list< int > get_res_reference( const std::list< int >& res_num );
 
         // query を含むレス番号をリストにして取得
         // mode_or == true なら OR抽出
@@ -300,7 +300,7 @@ namespace DBTREE
         // m_buffer_write に作成した文字列をセットする
         void parse_write( const char* str, const int lng, const int max_lng_write );
 
-        bool check_anchor( int mode, const char* str_in, int& n, char* str_out, char* str_link, int lng_link, ANCINFO* ancinfo );
+        const bool check_anchor( const int mode, const char* str_in, int& n, char* str_out, char* str_link, int lng_link, ANCINFO* ancinfo );
         const int check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link );
 
         // あぼーんのクリア
@@ -331,14 +331,14 @@ namespace DBTREE
         void clear_id_name();
 
         // from_number番から to_number 番までの発言数の更新
-        void update_id_name( int from_number, int to_number );
+        void update_id_name( const int from_number, const int to_number );
 
         // number番のレスの発言数をチェック
-        void check_id_name( int number );
+        void check_id_name( const int number );
 
         // 発言数( num_id_name )の更新
         // IDノードの色も変更する
-        void set_num_id_name( NODE* header, int num_id_name );
+        void set_num_id_name( NODE* header, const int num_id_name, NODE* pre_id_name_header );
 
         // http://ime.nu/ などをリンクから削除
         bool remove_imenu( char* str_link );
