@@ -40,10 +40,6 @@ struct XSMPDATA
 };
 #endif
 
-#ifdef _WIN32
-#include <windows.h>
-#endif
-
 enum
 {
     MAX_SAFE_ARGC = 4,   // 引数の数の制限値
@@ -376,7 +372,9 @@ int main( int argc, char **argv )
                 //break;
 
             case 'm':
+#ifndef _WIN32
                 multi_mode = true;
+#endif
                 break;
 
             case 's':
@@ -508,7 +506,6 @@ int main( int argc, char **argv )
     }
 
     /*--- IOMonitor -------------------------------------------------*/
-#ifndef _WIN32
     CORE::IOMonitor iomonitor;
 
     // FIFOの状態をチェックする
@@ -537,40 +534,33 @@ int main( int argc, char **argv )
             if( ret != Gtk::RESPONSE_YES ) return 0;
         }
     }
-    // FIFOに問題がある
+    // FIFOに問題がある(FATで作成出来ないなど)
     else
     {
-        Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( CACHE::path_lock() + "の作成またはオープンに問題があります。起動しますか？",
-                                                            false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-        int ret = mdiag->run();
-        delete mdiag;
-        if( ret != Gtk::RESPONSE_YES ) return 1;
-    }
-#endif
-
-    /*---------------------------------------------------------------*/
-#ifdef _WIN32
-    // 多重起動の確認
-    HANDLE hJdLock = NULL;
-    hJdLock = CreateSemaphore(NULL, LONG_MAX, LONG_MAX, "JdForWindowsLockObject"); //2147483647
-    if( ! multi_mode )
-    {
-        if( GetLastError() == ERROR_ALREADY_EXISTS )
+        if( CONFIG::get_show_diag_fifo_error() )
         {
-            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDは既に起動しています。起動しますか？",
+            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( CACHE::path_lock() + "の作成またはオープンに問題があります。このまま起動しますか？",
                                                                 false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-            int ret = mdiag->run();
+
+            Gtk::CheckButton chk_button( "今後表示しない" );
+            mdiag->get_vbox()->pack_start( chk_button, Gtk::PACK_SHRINK );
+            chk_button.show();
+
+            const int ret = mdiag->run();
+
+            CONFIG::set_show_diag_fifo_error( ! chk_button.get_active() );
+
             delete mdiag;
+
             if( ret != Gtk::RESPONSE_YES )
             {
-                CloseHandle( hJdLock );
-                return 0;
+                CONFIG::save_conf();
+                return 1;
             }
         }
     }
-#endif
-    /*---------------------------------------------------------------*/
 
+    /*---------------------------------------------------------------*/
     // バックアップファイル復元
     restore_bkup();
 
@@ -586,12 +576,6 @@ int main( int argc, char **argv )
 #ifdef USE_XSMP
     xsmp_session_end( &xsmpdata );
 #endif
-#ifdef _WIN32
-    if( hJdLock != NULL )
-    {
-        CloseHandle( hJdLock );
-    }
-#endif
 
     JDLIB::deinit_ssl();
 
