@@ -16,6 +16,7 @@
 #include "fontid.h"
 #include "colorid.h"
 #include "global.h"
+#include "sharedbuffer.h"
 
 #include "linkfiltermanager.h"
 #include "prefdiagfactory.h"
@@ -47,6 +48,18 @@
 using namespace CORE;
 
 
+
+//
+// URLを開く
+//
+void Core::slot_openurl()
+{
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_OPENURL, "" );
+    pref->run();
+    delete pref;
+}
+
+
 //
 // オンライン、オフライン切替え
 //
@@ -162,10 +175,42 @@ void Core::slot_quit()
 }
 
 
+//
+// スレ一覧のsinceの表示モード
+void Core::slot_toggle_since( const int mode )
+{
+    if( ! m_enable_menuslot ) return;
+    if( SESSION::get_col_since_time() == mode ) return;
+
+#ifdef _DEBUG
+    std::cout << "Core::slot_toggle_since mode = " << mode << std::endl;
+#endif
+
+    SESSION::set_col_since_time( mode );
+    BOARD::get_admin()->set_command( "relayout_all" );    
+}
+
+
+//
+// スレ一覧の最終書込の表示モード
+void Core::slot_toggle_write( const int mode )
+{
+    if( ! m_enable_menuslot ) return;
+    if( SESSION::get_col_write_time() == mode ) return;
+
+#ifdef _DEBUG
+    std::cout << "Core::slot_toggle_write mode = " << mode << std::endl;
+#endif
+
+    SESSION::set_col_write_time( mode );
+    BOARD::get_admin()->set_command( "relayout_all" );    
+}
+
+
 //
 // ツールバーの表示モード
 //
-void Core::slot_toggle_toolbarpos( int pos )
+void Core::slot_toggle_toolbarpos( const int pos )
 {
     if( SESSION::is_booting() ) return;
     if( ! m_enable_menuslot ) return;
@@ -177,8 +222,8 @@ void Core::slot_toggle_toolbarpos( int pos )
     pack_widget( true );
 
     // 表示切り替え
-    if( SESSION::toolbar_pos() == pos ) pos = SESSION::TOOLBAR_POS_NOT;
-    SESSION::set_toolbar_pos( pos );
+    if( SESSION::toolbar_pos() == pos ) SESSION::set_toolbar_pos( SESSION::TOOLBAR_POS_NOT ); // 隠す
+    else SESSION::set_toolbar_pos( pos );
 
     pack_widget( false );
 
@@ -451,6 +496,17 @@ void Core::slot_setup_msgitem()
 }
 
 
+
+//
+// コンテキストメニュー(スレ一覧)の表示項目
+//
+void Core::slot_setup_boarditem_menu()
+{
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARDITEM_MENU, "" );
+    pref->run();
+    delete pref;
+}
+
 //
 // コンテキストメニュー(スレビュー)の表示項目
 //
@@ -988,6 +1044,25 @@ void Core::slot_search_cache()
 }
 
 
+//
+// 現在開いている板のキャッシュ内のログ一覧表示
+//
+void Core::slot_show_cache_board()
+{
+    std::string url = DBTREE::url_subject( BOARD::get_admin()->get_current_url() );
+    if( ! url.empty() ) CORE::core_set_command( "open_board_showlog", url );
+}
+
+
+//
+// キャッシュ内の全ログ一覧表示
+//
+void Core::slot_show_cache()
+{
+    CORE::core_set_command( "open_board_showalllog" );
+}
+
+
 //
 // スレタイ検索
 //
@@ -1057,6 +1132,46 @@ void Core::slot_import_dat()
 }
 
 
+//
+// サイドバーをスレ一覧に表示
+//
+void Core::slot_show_sidebarboard()
+{
+    if( SESSION::get_sidebar_current_url() != URL_BBSLISTVIEW
+        && SESSION::get_sidebar_current_url() != URL_HISTBOARDVIEW
+        ){
+
+        const std::string tab = "left";
+        const std::string mode = "";
+        CORE::core_set_command( "open_sidebar_board", SESSION::get_sidebar_current_url(), tab, mode, "0" );
+    }
+}
+
+
+//
+// サイドバーの仮想板を作成
+//
+void Core::slot_create_vboard()
+{
+    if( SESSION::get_sidebar_current_url() != URL_BBSLISTVIEW
+        && SESSION::get_sidebar_current_url() != URL_HISTBOARDVIEW
+        ){
+
+        CORE::DATA_INFO_LIST list_info;
+        CORE::DATA_INFO info;
+        info.type = TYPE_VBOARD;
+        info.parent = CORE::get_mainwindow();
+        info.url = SESSION::get_sidebar_current_url() + SIDEBAR_SIGN + "0";
+        info.name = SESSION::get_sidebar_dirname( SESSION::get_sidebar_current_url(), 0 );
+        info.path = Gtk::TreePath( "0" ).to_string();
+        list_info.push_back( info );
+        CORE::SBUF_set_list( list_info );
+
+        CORE::core_set_command( "append_favorite", URL_FAVORITEVIEW );
+    }
+}
+
+
 //
 // サポートBBS
 //
