@@ -15,6 +15,8 @@
 
 #include "dndmanager.h"
 
+#include <cstring>
+
 using namespace SKELETON;
 
 DragableNoteBook::DragableNoteBook()
@@ -51,6 +53,8 @@ DragableNoteBook::DragableNoteBook()
     m_show_tabs = true;
     m_show_toolbar = true;
 
+    memset( &m_alloc_old, 0, sizeof( Alloc_NoteBook ) );
+
     show_all_children();
 }
 
@@ -152,7 +156,7 @@ const Alloc_NoteBook DragableNoteBook::get_alloc_notebook()
     alloc.y_toolbar = m_notebook_toolbar.get_allocation().get_y();
     alloc.height_toolbar = m_notebook_toolbar.get_allocation().get_height();
 
-    const int offset_tabbar = ( get_show_tabs() ? alloc.height_tabbar - alloc.height_tab : 0 );
+    const int offset_tabbar = ( get_show_tabs() ? alloc.height_tabbar - ( alloc.y_tab + alloc.height_tab ) : 0 );
     alloc.x_box = m_notebook_view.get_allocation().get_x();
     alloc.y_box = m_notebook_view.get_allocation().get_y() - alloc.height_toolbar - offset_tabbar;
     alloc.width_box =m_notebook_view.get_allocation().get_width();
@@ -187,12 +191,23 @@ void DragableNoteBook::draw_box( Gtk::Widget* widget, GdkEventExpose* event )
 {
     const Glib::RefPtr<Gdk::Window> win = widget->get_window();
     const Gdk::Rectangle rect( &(event->area) );
-    const Alloc_NoteBook alloc = get_alloc_notebook();
+    Alloc_NoteBook alloc = get_alloc_notebook();
 
     if( alloc.height_box > 0 ){
 
         if( get_show_tabs() ){
 
+            // gtk2.18以降？では新しいタブを開くときに一瞬タブが消える場合がある
+            // その場合は保存しておいた座標と高さを利用してboxを描画する
+            if( ! alloc.height_tab ){
+
+                if( ! m_alloc_old.height_tab ) return;
+
+                alloc.y_box = m_alloc_old.y_box;
+                alloc.height_box = m_alloc_old.height_box;
+            }
+            else m_alloc_old = alloc;
+
             widget->get_style()->paint_box_gap( win,
                                                 Gtk::STATE_NORMAL,
                                                 Gtk::SHADOW_OUT,
@@ -323,7 +338,7 @@ int DragableNoteBook::insert_page( const std::string& url, Gtk::Widget& child, i
 //
 // タブの文字列取得
 //
-const std::string DragableNoteBook::get_tab_fulltext( int page )
+const std::string DragableNoteBook::get_tab_fulltext( const int page )
 {
     return m_notebook_tab.get_tab_fulltext( page );
 }
@@ -333,7 +348,7 @@ const std::string DragableNoteBook::get_tab_fulltext( int page )
 //
 // タブに文字列をセットとタブ幅調整
 //
-void DragableNoteBook::set_tab_fulltext( const std::string& str, int page )
+void DragableNoteBook::set_tab_fulltext( const std::string& str, const int page )
 {
     m_notebook_tab.set_tab_fulltext( str, page );
 }
@@ -488,6 +503,18 @@ void DragableNoteBook::update_toolbar_button()
 }
 
 
+//
+// タブのアイコンを取得する
+//
+const int DragableNoteBook::get_tabicon( const int page )
+{
+    SKELETON::TabLabel* tablabel = m_notebook_tab.get_tablabel( page );
+    if( tablabel ) return tablabel->get_id_icon();
+
+    return ICON::NONE;
+}
+
+
 //
 // タブにアイコンをセットする
 //
@@ -680,12 +707,24 @@ void DragableNoteBook::slot_leave_event()
 bool DragableNoteBook::slot_scroll_event( GdkEventScroll* event )
 {
 #ifdef _DEBUG
-    std::cout << "DragableNoteBook::slot_scroll_event\n";
+    std::cout << "DragableNoteBook::slot_scroll_event direction = " << event->direction << " page = " << get_current_page() << std::endl;
 #endif
 
+    bool ret = false;
+
+    // タブの循環
+    if( event->direction == GDK_SCROLL_UP && get_current_page() == 0 ){
+        set_current_page( get_n_pages() -1 );
+        ret = true;
+    }
+    else if( event->direction == GDK_SCROLL_DOWN && get_current_page() == get_n_pages() -1 ){
+        set_current_page( 0 );
+        ret = true;
+    }
+
     m_sig_tab_scrolled.emit( event );
 
-    return true;
+    return ret;
 }
 
 
