@@ -13,6 +13,7 @@
 #include "jdlib/constptr.h"
 
 #include "type.h"
+#include "data_info.h"
 
 #include <gtkmm.h>
 #include <list>
@@ -67,6 +68,9 @@ namespace SKELETON
         // ドラッグがこのツリー上で行われている
         bool m_dragging_on_tree;
 
+        // ディレクトリIDの最大値
+        size_t m_max_dirid;
+
       public:
 
         // ColumnRecord として SKELETON::EditColumns を派生したものを使用すること
@@ -115,6 +119,10 @@ namespace SKELETON
         // 新規ディレクトリ作成
         const Gtk::TreePath create_newdir( const Gtk::TreePath& path );
 
+        // ディレクトリIDとパスを相互変換
+        const Gtk::TreePath dirid_to_path( const size_t dirid );
+        const size_t path_to_dirid( const Gtk::TreePath path );
+
         // コメント挿入
         const Gtk::TreePath create_newcomment( const Gtk::TreePath& path );
 
@@ -139,12 +147,12 @@ namespace SKELETON
             );
 
         // pathをまとめて削除
-        // force = true なら m_editable が false でも追加
+        // force = true なら m_editable が false でも削除
         void delete_path( std::list< Gtk::TreePath >& list_path, const bool force );
 
         // 選択した行をまとめて削除
-        // force = true なら m_editable が false でも追加
-        void delete_selected_rows( const bool force );
+        // force = true なら m_editable が false でも削除
+        virtual void delete_selected_rows( const bool force );
 
         void undo();
         void redo();
@@ -153,6 +161,15 @@ namespace SKELETON
         // dir : true の時はディレクトリが選択されているときはディレクトリ内の行もlist_infoに再帰的にセットする
         void get_info_in_selection( CORE::DATA_INFO_LIST& list_info, const bool dir );
 
+        // 一行追加
+        // 戻り値は追加した行のpath
+        // (1) path_dest が empty なら一番最後に作る
+        // (2) before = true なら前に作る
+        // (3) path_dest がディレクトリかつ sudir == true なら path_dest の下に追加。
+        // (4) そうでなければ path_dest の後に追加
+        const Gtk::TreePath append_one_row( const std::string& url, const std::string& name, int type, const size_t dirid, const std::string& data,
+                                            const Gtk::TreePath& path_dest,const bool before, const bool subdir );
+
       protected:
 
         virtual bool on_drag_motion( const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, guint time );
@@ -175,6 +192,12 @@ namespace SKELETON
 
         void setup();
 
+        // ディレクトリIDの最大値を取得
+        void get_max_dirid();
+
+        // ディレクトリにIDをセットする
+        void set_dirid();
+
         // 全てのツリーに m_columns.m_expand の値をセットする( tree2xml()で使用 )
         void set_expanded_row( Glib::RefPtr< Gtk::TreeStore >& treestore, const Gtk::TreeModel::Children& children );
 
@@ -202,15 +225,6 @@ namespace SKELETON
         // path から info を取得
         void path2info( CORE::DATA_INFO& info, const Gtk::TreePath& path );
 
-        // 一行追加
-        // 戻り値は追加した行のpath
-        // (1) path_dest が empty なら一番最後に作る
-        // (2) before = true なら前に作る
-        // (3) path_dest がディレクトリかつ sudir == true なら path_dest の下に追加。
-        // (4) そうでなければ path_dest の後に追加
-        const Gtk::TreePath append_one_row( const std::string& url, const std::string& name, int type, const std::string& data,
-                                            const Gtk::TreePath& path_dest,const bool before, const bool subdir );
-
         // list_info に示した行の親を再起的にexpandする
         // list_info の各要素の path にあらかじめ値をセットしておくこと
         void expand_rows( const CORE::DATA_INFO_LIST& list_info );
@@ -228,6 +242,35 @@ namespace SKELETON
         void select_info( const CORE::DATA_INFO_LIST& list_info );
 
    };
+
+
+
+    ////////////////////////////////
+
+    // EditTreeViewの項目の反復子
+
+    class EditTreeViewIterator
+    {
+        EditTreeView& m_treeview;
+        EditColumns& m_columns;
+        int m_depth;
+        bool m_end;
+
+        Gtk::TreePath m_path;
+
+      public:
+
+        // path から反復開始
+        // path が empty の時はルートから反復する
+        EditTreeViewIterator( EditTreeView& treeview, EditColumns& columns, const Gtk::TreePath path );
+
+        Gtk::TreeModel::Row operator * ();
+        const Gtk::TreePath get_path() const { return m_path; }
+
+        void operator ++ ();
+
+        const bool end() const { return m_end; }
+    };
 }
 
 #endif
