@@ -294,6 +294,11 @@ void EditTextView::undo()
 }
 
 
+void EditTextView::clear_undo()
+{
+    m_undo_tree.clear();
+}
+
 
 //
 // マウスボタン入力のフック
@@ -329,6 +334,8 @@ bool EditTextView::on_key_press_event( GdkEventKey* event )
         case CONTROL::FocusWrite:
         case CONTROL::TabLeft:
         case CONTROL::TabRight:
+        case CONTROL::TabLeftUpdated:
+        case CONTROL::TabRightUpdated:
         case CONTROL::HomeEdit:
         case CONTROL::EndEdit:
         case CONTROL::UpEdit:
@@ -439,7 +446,7 @@ void EditTextView::on_populate_popup( Gtk::Menu* menu )
 #endif
 
     m_context_menu = menu;
-    SESSION::set_popupmenu_shown( true );
+    menu->signal_map().connect( sigc::mem_fun( *this, &EditTextView::slot_map_popupmenu ) ); 
     menu->signal_hide().connect( sigc::mem_fun( *this, &EditTextView::slot_hide_popupmenu ) );
 
     // セパレータ
@@ -451,6 +458,11 @@ void EditTextView::on_populate_popup( Gtk::Menu* menu )
     menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_write_jdinfo ) );
     menu->prepend( *menuitem );
 
+    // 変換(スペース⇔&nbsp;)
+    menuitem = Gtk::manage( new Gtk::MenuItem( "変換(スペース⇔&nbsp;)" ) );
+    menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_convert_space ) );
+    menu->prepend( *menuitem );
+
     // クリップボードから引用
     menuitem = Gtk::manage( new Gtk::MenuItem( "クリップボードから引用" ) );
     menuitem->signal_button_press_event().connect( sigc::mem_fun( *this, &EditTextView::slot_quote_clipboard ) );
@@ -502,6 +514,49 @@ bool EditTextView::slot_quote_clipboard( GdkEventButton* event )
 }
 
 
+//
+// 変換(スペース⇔&nbsp;)
+//
+bool EditTextView::slot_convert_space( GdkEventButton* event )
+{
+    Glib::RefPtr< Gtk::TextBuffer > buffer = get_buffer();
+    std::string text = buffer->get_text();
+    std::string converted;
+
+    // &nbsp;が含まれていたらスペースに変換する
+    if( text.find( "&nbsp;", 0 ) != std::string::npos )
+    {
+        converted = MISC::replace_str( text, "&nbsp;", " " );
+    }
+    else
+    {
+        size_t rpos = std::string::npos;
+        size_t nlpos = std::string::npos;
+
+        // 改行前のスペースを取り除く
+        while( ( nlpos = text.rfind( "\n", rpos ) ) != std::string::npos )
+        {
+            if( nlpos == 0 ) break;
+            rpos = nlpos;
+            while( text[ rpos - 1 ] == ' ' ) rpos--;
+            text.erase( rpos, nlpos - rpos );
+            rpos--;
+        }
+
+        // 最後のスペースを取り除く
+        rpos = text.length();
+        while( text[ rpos - 1 ] == ' ' ) rpos--;
+        text.erase( rpos, std::string::npos );
+
+        converted = MISC::replace_str( text, " ", "&nbsp;" );
+    }
+
+    buffer->set_text( converted );
+
+    return true;
+}
+
+
 //
 // JDの動作環境を記入
 //
@@ -516,7 +571,20 @@ bool EditTextView::slot_write_jdinfo( GdkEventButton* event )
 
 
 //
-// ポップアップを隠す
+// ポップアップメニューがmapしたときに呼ばれるslot
+//
+void EditTextView::slot_map_popupmenu()
+{
+#ifdef _DEBUG
+    std::cout << "EditTextView::slot_map_popupmenu\n";
+#endif
+
+    SESSION::set_popupmenu_shown( true );
+}
+
+
+//
+// コンテキストメニューが閉じた
 //
 void EditTextView::slot_hide_popupmenu()
 {
@@ -558,14 +626,15 @@ void EditTextView::show_aalist_popup()
     {
         if( m_aapopupmenu ) delete m_aapopupmenu;
 
-        SESSION::set_popupmenu_shown( true );
         m_aapopupmenu = Gtk::manage( new AAMenu( *dynamic_cast< Gtk::Window* >( get_toplevel() ) ) );
+
+        m_aapopupmenu->sig_selected().connect( sigc::mem_fun( *this, &EditTextView::slot_aamenu_selected ) );
+        m_aapopupmenu->signal_map().connect( sigc::mem_fun( *this, &EditTextView::slot_map_aamenu ) ); 
+        m_aapopupmenu->signal_hide().connect( sigc::mem_fun( *this, &EditTextView::slot_hide_aamenu ) );
+
         m_aapopupmenu->popup( Gtk::Menu::SlotPositionCalc(
                             sigc::mem_fun( *this, &EditTextView::slot_popup_aamenu_pos ) ),
                             0, gtk_get_current_event_time() );
-
-        m_aapopupmenu->sig_selected().connect( sigc::mem_fun( *this, &EditTextView::slot_aamenu_selected ) );
-        m_aapopupmenu->signal_hide().connect( sigc::mem_fun( *this, &EditTextView::slot_hide_aamenu ) );
     }
 }
 
@@ -599,9 +668,26 @@ void EditTextView::slot_aamenu_selected( const std::string& aa )
 }
 
 
+//
+// AAポップアップメニューがmapしたときに呼ばれるslot
+//
+void EditTextView::slot_map_aamenu()
+{
+#ifdef _DEBUG
+    std::cout << "EditTextView::slot_map_aamenu\n";
+#endif
+
+    SESSION::set_popupmenu_shown( true );
+}
+
+
 //
 // AAポップアップが閉じた
 void EditTextView::slot_hide_aamenu()
 {
+#ifdef _DEBUG
+    std::cout << "EditTextView::slot_hide_aamenu\n";
+#endif
+
     SESSION::set_popupmenu_shown( false );
 }
