@@ -9,10 +9,18 @@
 
 #include "config/globalconf.h"
 
+#include "dndmanager.h"
+
 using namespace SKELETON;
 
+enum
+{
+    SPACING_LABEL = 3 // アイコンとラベルの間のスペース
+};
+
+
 TabLabel::TabLabel( const std::string& url )
-    : m_url( url ), m_id_icon( ICON::NUM_ICONS ), m_locked( false ), m_image( NULL ), m_image_width( 0 ), m_under_mouse( false )
+    : m_url( url ), m_id_icon( ICON::NUM_ICONS ), m_image( NULL ), m_image_width( 0 )
 {
 #ifdef _DEBUG
     std::cout << "TabLabel::TabLabel " << m_url << std::endl;
@@ -21,7 +29,6 @@ TabLabel::TabLabel( const std::string& url )
     // 背景透過
     set_visible_window( false );
 
-    add_events( Gdk::ENTER_NOTIFY_MASK );
     add_events( Gdk::POINTER_MOTION_MASK );
     add_events( Gdk::LEAVE_NOTIFY_MASK );
 
@@ -42,17 +49,8 @@ TabLabel::~TabLabel()
 }
 
 
-// タブとラベルの間のすき間のサイズ
-// 取得方法が分からないのでとりあえずマジックナンバーを返しておく
-const int TabLabel::get_margin()
-{
-    const int mrg_tab = 12;
-    return mrg_tab;
-}
-
-
 // アイコンセット
-void TabLabel::set_id_icon( int id )
+void TabLabel::set_id_icon( const int id )
 {
     if( ! CONFIG::get_show_tab_icon() ) return;
     if( m_id_icon == id ) return;
@@ -61,6 +59,7 @@ void TabLabel::set_id_icon( int id )
     if( !m_image ){
         m_image = new Gtk::Image();
         m_hbox.remove( m_label );
+        m_hbox.set_spacing( SPACING_LABEL );
         m_hbox.pack_start( *m_image, Gtk::PACK_SHRINK );
         m_hbox.pack_start( m_label, Gtk::PACK_SHRINK );
         show_all_children();
@@ -78,10 +77,12 @@ void TabLabel::set_id_icon( int id )
 
 
 // タブの文字列の文字数がlngになるようにリサイズする
-void TabLabel::resize_tab( int lng )
+void TabLabel::resize_tab( const unsigned int lng )
 {
     Glib::ustring ulabel( m_fulltext );
+    const unsigned int lng_org = ulabel.length();
     ulabel.resize( lng );
+    if( lng < lng_org ) ulabel += "...";
     m_label.set_text( ulabel );
 }
 
@@ -94,9 +95,10 @@ void TabLabel::set_dragable( bool dragable, int button )
     if( dragable ){
 
         std::list< Gtk::TargetEntry > targets;
-        targets.push_back( Gtk::TargetEntry( "text/plain", Gtk::TARGET_SAME_APP, 0 ) );
+        targets.push_back( Gtk::TargetEntry( DNDTARGET_FAVORITE, Gtk::TARGET_SAME_APP, 0 ) );
+        targets.push_back( Gtk::TargetEntry( DNDTARGET_TAB, Gtk::TARGET_SAME_APP, 0 ) );
 
-        // ドラッグ側
+        // ドラッグ開始側にする
         switch( button ){
 
             case 1: drag_source_set( targets, Gdk::BUTTON1_MASK ); break;
@@ -105,9 +107,6 @@ void TabLabel::set_dragable( bool dragable, int button )
 
             default: return;
         }
-
-        // ドロップ側
-        drag_dest_set( targets );
     }
     else{
         drag_source_unset();
@@ -116,30 +115,16 @@ void TabLabel::set_dragable( bool dragable, int button )
 }
 
 
-
-//
-// マウスが入った
-//
-bool TabLabel::on_enter_notify_event( GdkEventCrossing* event )
-{
-#ifdef _DEBUG
-    std::cout << "TabLabel::enter " << m_fulltext << std::endl;
-#endif
-
-    m_under_mouse = true;
-
-    return Gtk::EventBox::on_enter_notify_event( event );
-}
-
-
 //
 // マウスが動いた
 //
 bool TabLabel::on_motion_notify_event( GdkEventMotion* event )
 {
+    const bool ret = Gtk::EventBox::on_motion_notify_event( event );
+
     m_sig_tab_motion_event.emit();
 
-    return Gtk::EventBox::on_motion_notify_event( event );
+    return ret;
 }
 
 
@@ -149,14 +134,14 @@ bool TabLabel::on_motion_notify_event( GdkEventMotion* event )
 bool TabLabel::on_leave_notify_event( GdkEventCrossing* event )
 {
 #ifdef _DEBUG
-    std::cout << "TabLabel::leave " << m_fulltext << std::endl;
+    std::cout << "TabLabel::leave\n";
 #endif
 
-    m_under_mouse = false;
+    const bool ret = Gtk::EventBox::on_leave_notify_event( event );
 
     m_sig_tab_leave_event.emit();
 
-    return Gtk::EventBox::on_leave_notify_event( event );
+    return ret;
 }
 
 
@@ -169,28 +154,26 @@ void TabLabel::on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& context )
     std::cout << "TabLabel::on_drag_begin " << m_fulltext << std::endl;
 #endif
 
-    m_under_mouse = false;
-
     m_sig_tab_drag_begin.emit();
 
-    return Gtk::EventBox::on_drag_begin( context );
+    Gtk::EventBox::on_drag_begin( context );
 }
 
 
 //
-// ドロップされた
+// D&Dで受信側がデータ送信を要求してきた
 //
-bool TabLabel::on_drag_drop( const Glib::RefPtr<Gdk::DragContext>& context, int x, int y, guint time )
+void TabLabel::on_drag_data_get( const Glib::RefPtr<Gdk::DragContext>& context,
+                                 Gtk::SelectionData& selection_data, guint info, guint time )
 {
 #ifdef _DEBUG
-    std::cout << "TabLabel::on_drag_drop " << m_fulltext << std::endl;;
+    std::cout << "TabLabel::on_drag_data_get target = " << selection_data.get_target()
+              << " " << m_fulltext << std::endl;;
 #endif
 
-    m_under_mouse = true;
+    Gtk::EventBox::on_drag_data_get( context, selection_data, info, time );
 
-    m_sig_tab_drag_drop.emit();
-
-    return Gtk::EventBox::on_drag_drop( context, x, y, time );
+    m_sig_tab_drag_data_get( selection_data );
 }
 
 
@@ -203,7 +186,7 @@ void TabLabel::on_drag_end( const Glib::RefPtr< Gdk::DragContext >& context )
     std::cout << "TabLabel::on_drag_end " << m_fulltext << std::endl;;
 #endif
 
-    m_sig_tab_drag_end.emit();
-
     Gtk::EventBox::on_drag_end( context );
+
+    m_sig_tab_drag_end.emit();
 }
