@@ -47,6 +47,9 @@ UsrCmdDiag::UsrCmdDiag( Gtk::Window* parent, const Glib::ustring& name, const Gl
     get_vbox()->set_spacing( 8 );
     get_vbox()->pack_start( m_vbox );
 
+    set_activate_entry( m_entry_name );
+    set_activate_entry( m_entry_cmd );
+
     set_title( "ユーザコマンド設定" );
     show_all_children();
 }
@@ -284,6 +287,7 @@ void UsrCmdPref::slot_newcmd()
         CORE::DATA_INFO_LIST list_info;
         CORE::DATA_INFO info;
         info.type = TYPE_USRCMD;
+        info.parent = NULL;
         info.url = std::string();
         info.name = diag.get_name();
         info.data = diag.get_cmd();
@@ -312,6 +316,7 @@ void UsrCmdPref::slot_newsepa()
     CORE::DATA_INFO_LIST list_info;
     CORE::DATA_INFO info;
     info.type = TYPE_SEPARATOR;
+    info.parent = NULL;
     info.url = std::string();
     info.name = "--- 区切り ---";
     info.data = std::string();
