@@ -22,8 +22,14 @@ namespace CORE
         VIEW_BBSLISTVIEW,
         VIEW_FAVORITELIST,
         VIEW_SELECTLIST,
+        VIEW_HISTTHREAD,
+        VIEW_HISTCLOSE,
+        VIEW_HISTBOARD,
 
         VIEW_BOARDVIEW,
+        VIEW_BOARDNEXT,
+        VIEW_BOARDLOG,
+        VIEW_BOARDSIDEBAR,
 
         VIEW_ARTICLEVIEW,
         VIEW_ARTICLERES,
@@ -66,7 +72,7 @@ namespace CORE
         std::string arg4;
     };
     
-    SKELETON::View* ViewFactory( int type, const std::string& url, VIEWFACTORY_ARGS args = VIEWFACTORY_ARGS() );
+    SKELETON::View* ViewFactory( int type, const std::string& url, VIEWFACTORY_ARGS view_args = VIEWFACTORY_ARGS() );
 }
 
 #endif
